---
title: blend modes
id: blend-modes
weight: 20
draft: false
---

ブレンドモードは、モジュールの入力と出力をどのように混合して（ブレンドして）、最終的にピクセルパイプライン中の次のモジュールに渡す値を生成するのか、を決めるものです。

古典的なブレンドモードは、（0〜100%に制限された）ディスプレイ参照型RGB値のために設計されており、ブレンドモードごとに、「支点」の値を50%（グレー）か100%（白）として暗黙的に定義しています。シーン参照型ではこのような制限はないので、ブレンディングを「RGB（シーン参照）」色空間で行う場合は、支点の値をユーザーが明示的に定義する必要があります。シーン参照色空間でこの種のブレンドモードを使う場合、 _ブレンド支点(blend fulcrum)_ パラメータを設定するところが追加で表示されます。効果はブレンドの種類によります。例えば、支点より上の値なら明るくなり下なら暗くなるとか、その逆とかです。

モジュールの最終的な出力は「ピクセルごとに」次のように計算されます。

```
最終出力 = (1.0 - 不透明度) * モジュール入力 + 不透明度 * ブレンド出力
```

ここで、 `ブレンド出力` というのは入力・出力画像をブレンドモード（下記参照）によって合成した結果で、 `不透明度` はマスクとグローバル不透明度パラメータによって「ピクセルごとに」定義されます。不透明度が0%だと、モジュールに入力された画像と同一の画像が出力されます。

「反転」ボタン ![blend-reverse](./blend-modes/blend-reverse.png#icon) を使うと、「ピクセルごと」の計算における、入力・出力画像の役割が実質的に逆になります。

```
最終出力 = (1.0 - 不透明度) * モジュール出力 + 不透明度 * ブレンド入力
```

ここで、 `ブレンド入力` というのは入力・出力画像をブレンドモード（下記参照）によって合成した結果で、 _出力_ と _入力_ の画像を逆にしたものです。この「反転」ブレンドモードでは、不透明度が0%だと、モジュールから _出力_ された画像と同一の画像が出力されます。

# 通常モード

通常(normal)
: 最もよく使われるブレンドモード「通常」は、入力と出力を不透明度の値に応じて単純に混合します。このモードは、不透明度を下げることで、モジュールの効果を弱めるためによく使われます。また、モジュールの効果をマスクを使って一部分だけに適用する場合にも、たいていこのモードを使います。このモードは、Porter-Duff アルファブレンディング（詳しくは [alpha compositing](https://en.wikipedia.org/wiki/Alpha_compositing) を参照）における "over" 演算としても知られています。

制限つき通常(normal bounded)
: _「RGB（シーン参照）」色空間では使えません_
: このモードは「通常」と同様ですが、入力・出力データを一定の最大・最小値の範囲に制限した状態で適用されます。範囲を越える値は実質的にブロックされ、次のモジュールには渡されません。こうすることで、歪みなどを防ぐ役に立つ場合があります。ですが、たいていの場合（彩度が高くて極端なハイライトがあるとか）、値を制限せずすべてのピクセル値をピクセルパイプラインの次のモジュールにそのまま渡し、あとで適切に処理するほうがよい結果が得られます。そのため、普通は「通常」のほうがおすすめです。

# 算術モード

加算(addition)
: 入力と出力画像のピクセルの値を足し算し、出力は明るくなります。「RGB（シーン参照）」色空間でブレンディングする場合、出力画像のピクセル値は、「ブレンド支点(blend fulcrum)」に比例した値で乗算されます。

減算(subtract)
: _入力_ のピクセル値から _出力_ のピクセル値を引き算します。「RGB（シーン参照）」色空間でブレンディングする場合、出力画像のピクセル値は、「ブレンド支点(blend fulcrum)」に比例した値で乗算されます。計算結果が0以下になったピクセル値は、0になります。

乗算（multiply）
: 入力と出力のピクセル値を掛け算します。ディスプレイ参照色空間でブレンディングする場合、ピクセル値は0から1.0までの間となり、最終的な出力は切りつめられて必ず暗くなります。「RGB（シーン参照）」色空間でブレンディングする場合、ピクセル値はさらに「ブレンド支点(blend fulcrum)」に比例した値で乗算されます。このときは1.0以上の値となる場合もあり、そのときは元の画像より明るくなります。これは、フィルミックモジュールの白の点が変わるというような副作用をともなう場合があります。

: 乗算ブレンディングはNDフィルターと似たような効果を持ち、「光学濃度」はモジュールの出力で決められます。この操作には、（ぼかしやローパスフィルタと合わせて使うことで）ローカルコントラスト強化、（露光と合わせて使うことで）覆い焼きや焼き込みや全体のコントラスト強化、といった様々な使い方があります。支点は、出力の強さが暗くなるか明るくなるかの閾値を決めます（支点より低いRGB値はすべて暗くなる）。

除算(divide)
: 入力のピクセル値を出力の値で割り算します。「RGB（シーン参照）」色空間でブレンディングする場合、出力画像のピクセル値は、「ブレンド支点(blend fulcrum)」に比例した値で乗算されます。

: これは乗算モードの反対なので、乗算で明るくなる場合は暗くなり、逆も同様です。それ以外の点については、だいたい同様に動作します。

スクリーン(screen)
: _「RGB（シーン参照）」色空間では使えません_
: 入力と出力のピクセル値を反転し、それから掛け算して、最後にその結果を反転します。このことで、「乗算」モードのおおむね逆の効果が得られます。最終的に得られる画像はふつう明るくなり、「色あせた」感じの見た目になることもあります。

平均(average)
: 入力と出力のピクセル値の、平均値を返します。

差(difference)
: 入力と出力のピクセル値の、差の絶対値を返します。

幾何平均(geometric mean)
: 入力と出力のピクセル値を掛け算して、その平方根を返します。

調和平均
: 入力と出力のピクセル値を掛け算して、2倍してから2つの和で割ったものを返します。

# 色チャンネルモード

## Labチャンネル

以下はすべて、Lab色空間でブレンディングする場合のみ使えます。

Lab 明るさ(Lab lightness)
: 入力・出力画像の明るさを混合します。色チャンネル（aとb）は入力画像からそのまま取られ、変更されません。「明るさ(lightness)」とは違い、このブレンドモードは色空間の変換を伴なわず、値を切りつめたりすることもありません。こちらを使うほうが、「明るさ」を使うよりも歪みが起きにくい場合があります。

Lab aチャンネル
: 入力・出力画像のLab a色チャンネルを混合します。明るさは入力画像からそのまま取られ、変更されません。

Lab bチャンネル
: 入力・出力画像のLab b色チャンネルを混合します。明るさは入力画像からそのまま取られ、変更されません。

Lab 色(Lab color)
: 入力・出力画像のLab色チャンネル（aとb両方）を混合します。明るさは入力画像からそのまま取られ、変更されません。「色(color)」とは違い、このブレンドモードは色空間の変換を伴なわず、値を切りつめたりすることもありません。こちらを使うほうが、「色」を使うよりも歪みが起きにくい場合があります。

## RGBチャンネル

以下はすべて、RGB色空間でブレンディングする場合のみ使えます。

RGB 赤チャンネル
: 入力・出力画像の「赤」チャンネルを混合します。その他のチャンネルは入力画像からそのまま取られ、変更されません。「RGB（シーン参照）」色空間でブレンディングする場合、出力の「赤」チャンネルは、「ブレンド支点(blend fulcrum)」に比例した値で乗算されます。

RGB 緑チャンネル
: 入力・出力画像の「緑」チャンネルを混合します。その他のチャンネルは入力画像からそのまま取られ、変更されません。「RGB（シーン参照）」色空間でブレンディングする場合、出力の「緑」チャンネルは、「ブレンド支点(blend fulcrum)」に比例した値で乗算されます。

RGB 青チャンネル
: 入力・出力画像の「青」チャンネルを混合します。その他のチャンネルは入力画像からそのまま取られ、変更されません。「RGB（シーン参照）」色空間でブレンディングする場合、出力の「青」チャンネルは、「ブレンド支点(blend fulcrum)」に比例した値で乗算されます。

# HSVチャンネル

以下はすべて、「RGB（ディスプレイ参照）」色空間でブレンディングする場合のみ使えます。

HSV 明るさ(HSV lightness)
: 入力・出力画像の明るさを混合します。色は入力画像からそのまま取られ、変更されません。「明るさ(lightness)」とは違い、このブレンドモードは値を切りつめません。

HSV 色(HSV color)
: 入力・出力画像の色を混合します。明るさは入力画像からそのまま取られ、変更されません。「色(color)」とは違い、このブレンドモードは値を切りつめません。

# その他

明るさ(lightness)
: 入力・出力画像の明るさを混合します。色（彩度と色相）は入力画像からそのまま取られ、変更されません。

色光度(chrominance)
: 入力・出力画像の色光度を混合します。明るさと色相は入力画像からそのまま取られ、変更されません。このブレンドモードは、RGBの比をユークリッドノルムで割って使います。

明るく
: _「RGB（シーン参照）」色空間では使えません_
: 入力・出力のピクセル値を比較し、明るいほうの値を出力します。

暗く
: _「RGB（シーン参照）」色空間では使えません_
: 入力・出力のピクセル値を比較し、暗いほうの値を出力します。


色相(hue)
: _「RGB（シーン参照）」色空間では使えません_
: 入力・出力画像の色相（色合い）を混合します。明るさと彩度は入力画像からそのまま取られ、変更されません。

色(color)
: _「RGB（シーン参照）」色空間では使えません_
: 入力・出力画像の色（彩度と色相）を混合します。明るさは入力画像からそのまま取られ、変更されません。

: _注意： モジュールによって極端に色相が変更される場合（補色を生成する場合など）、このブレンドモードを使うと強い色ノイズが出る場合があります。_

色調整
: _「RGB（シーン参照）」色空間では使えません_
: モジュールの中には、主に画像の色調に関する値に対して処理を行ない、さらに彩度の調整を加えるようなものがあります（ [_レベル(levels)_](../../module-reference/processing-modules/levels.md) や [_トーンカーブ(tone curve)_](../../module-reference/processing-modules/tone-curve.md) のようなモジュール）。このブレンドモードは、モジュールの出力から明るさをとり、それから入力・出力の色を混合し、モジュールの色操作を調整できるようにします。
