---
title: parametric masks
id: parametric
weight: 30
draft: false
---

パラメトリックマスク機能を使うと、マスクが個々のピクセルに対しどのようにかかるかを詳細に設定することができます。具体的には、設定されたパラメータから中間のブレンドマスクを自動的に生成することで実現しています。パラメータとしては、描画マスクのようにピクセルの物理的座標を使うのではなく、色空間内の座標を使います。

モジュール色空間の各データチャンネル（例えばLabやRGB）と、いくつかの仮想データチャンネル（色相や彩度など）に対し、チャンネルごとの不透明度関数を作ります。すると、各ピクセルに対し、対象データチャンネルの値を使って、この関数によって0〜1（100%）の範囲のブレンディング係数が対応づけられるようになります。

結果、画像の各ピクセルはそれぞれのデータチャンネルの値に応じて異なったブレンディング係数を持つことになります。最後に、すべてのブレンディング係数と、全体の不透明度スライダーの値とが（ピクセルごとに）すべて掛けあわされ、画像に対する最終的なパラメトリックブレンドマスクが構成されます。

あるピクセルに対するブレンドマスクの値が0であれば、そのピクセルはモジュールの入力から変更されません。ブレンドマスクの値が1（100%）であれば、そのピクセルに対する操作は完全に効果を発揮します。

# チャンネルタブ

チャンネルタブのいずれかをクリックすると、マスクを構成するためのデータチャンネルを選択できます。

（_ディスプレイ参照型(display-referred)_） _Lab_ 色空間で動作するモジュールの場合、L、a、b、C（LChの彩度）、h（LChの色相）のチャンネルがあります。

_ディスプレイ参照型 RGB(display-referred RGB)_ 色空間で動作するモジュールの場合、g（グレー）、R、G、B、H（HSLの色相）、S（HSLの彩度）、L（HSLの明度）のチャンネルがあります。

_シーン参照型 RGB(scene-referred RGB)_ 色空間で動作するモジュールの場合、g（グレー）、R、G、B、Jz（JzCzhzの輝度）、Cz（JzCzhzの彩度）、hz（JzCzhzの色相）のチャンネルがあります。g（グレー）の値はR・G・Bチャンネルの加重平均として計算されます（重みは、使っている色空間によります）。JzCzhz色空間はJzazbz色空間の極座標表示であり、これはLChがLab空間の極座標表示であるのと同様です。Lab色空間におけるLと同様に、Jzはピクセルの輝度を表現していて、我々が輝度を知覚するやりかたに合わせてあります。しかし、Jzazbz色空間のほうがLab色空間に比べて高ダイナミックレンジ画像の場合でもずっとよく対応可能で、また色相のずれも起きにくくなっています。

_このような各種色空間については、 [Wikipedia](https://en.wikipedia.org/wiki/Color_space) を参照してください（訳注：日本語ページにもあります）。_

それぞれのデータチャンネルに対して、スライダーが1つか2つ表示されます。一方はモジュールが受けとる _入力データ(input data)_ についてのもので、もう一方はモジュールが生成する _出力データ(output data)_ （ブレンディングする前の）についてのものです。デフォルトでは出力のスライダーは非表示になっており、ブレンディングメニューの _出力チャンネル操作を表示(show output channels)_ を使うことで表示できます。

_ブースト係数(boost factor)_ スライダーを使うと、パラメトリックマスクのスライダーで扱う値の範囲を広げられます。シーン参照型編集では輝度の値が100%を越える場合があるため、ハイライトを対象とする場合にこのスライダーが使えます。このスライダーは、使う意味があるチャンネルの場合だけ操作できるようになります。

![input and output sliders](./parametric/input-output-sliders.png#w33)

## データチャンネルとマスクの確認

チャンネルの入力・出力スライダーにマウスカーソルを重ねた状態でCキーを押すと、画像の対応するチャンネルの入力・出力値を確認することができます。画像の表示が変化し、各ピクセルが当該チャンネルの値に対応するグレースケールか、 [設定(preferences) > ダークルーム(darkroom) > 各色チャンネルの表示(display of individual color channels)](../../../preferences-settings/darkroom.md) で設定した仮の色で表示されます。

同様にMキーを押すと、現在のスライダーの設定で構成されるマスクが表示されます。

マウスカーソルをスライダーから離すと、少し後に画像表示は元に戻ります。

## 線形・対数モード

マウスカーソルをスライダーに重ねてAキーを押すと、表示が「対数」(log)モードに変わります。こうすると暗部をより細かく調整することができます。もう一度Aキーを押せば、「線形」(linear)モードに戻ります。

# チャンネル入力・出力スライダー

それぞれの色チャンネルのスライダーを使って、台形状の不透明度関数を構成します。この目的のため、スライダーひとつに4つのマーカーが用意されています。スライダーの上にある、中を塗った三角形のマーカー2個で、不透明度が1になる範囲を決めます。そしてスライダー下の中抜き三角形のマーカー2個で、不透明度がゼロになる範囲を決めます。1の範囲とゼロの範囲の中間では、直線的に不透明度が変化します。

つまり、（内側の）中塗り三角マーカーが台形関数の上底（通常、狭いほう）を示します。一方、（外側の）中抜き三角マーカーが台形関数の下底（通常、広いほう）を示します。マーカーの順序は常に同じで、変わりません。複数を同じ場所に設定することは可能ですが、順番を入れかえることはできなくなっています。

右側の極性(polarity)ボタン（+/-）では、関数の形を「範囲選択」モードと「範囲非選択」モードとで切り替えられます。この際、上と下の三角マーカーも入れかわり、現在の極性が示されます。この二種類の台形関数の違いは、以下の図で示されるとおりです。

**範囲選択モード**

![range select slider](./parametric/blendif_2a.png#w33)

![range select graph](./parametric/blendif_2b.png#w33)

**範囲非選択モード**

![range deselect slider](./parametric/blendif_3a.png#w33)

![range deselect graph](./parametric/blendif_3b.png#w33)

デフォルトでは、すべてのマーカーが両端に置かれています。

この状態では、範囲選択モードの関数は全範囲の値を選択することになり、「全部100%」のマスクを構成します。ここからスライダーを内側に操作していくと、除外する範囲を徐々に増やし、狭い範囲だけを残していくことができます。

逆に、（極性ボタンを押して）範囲非選択モードの関数を使うと、デフォルトでは全範囲の値を選択から除外することになり、「全部0%」のマスクを初期値として構成することになります。ここからスライダーを内側に操作していくと、今度は選択する範囲を徐々に増やし、残った狭い範囲だけを除外していくことになります。

# カラーピッカー

カラーピッカーボタンは2つあります。左側のボタンでは、画像から一点かあるいは範囲を選択できます（訳注：ボタンをCtrl+クリックすると範囲選択モード）。選択すると、現在のデータチャンネルにおける対応する値がスライダーに表示されます。

右側のカラーピッカーボタンでは、選択範囲に基づいてスライダーの値を自動的に設定することができます。ボタンをクリックしてから画像でドラッグ操作すると、入力スライダーのパラメーターが選択範囲から自動設定されます。Ctrl+クリックしてからドラッグすると、出力スライダーのパラメーターが設定されます。

# 反転

スライダーの上（訳注：カラーピッカーの右）にある反転(invert)ボタンを押すと、パラメトリックマスク全体の極性が反転します。これは各スライダーの横にある極性ボタンとは意味が違います。極性ボタンは、単に現在のチャンネルの個々のスライダーだけを反転します。

# リセット

スライダーの上（訳注：反転ボタンの上）にあるリセットボタンを押すと、マスクに関する全パラメータをデフォルトの状態に戻します。

