---
title: overview
id: overview
weight: 10
draft: false
---

編集モジュールはそれぞれ、ピクセルパイプライン内で前のモジュールから入力を受け取り、画像データに処理を行い、それから出力をピクセルパイプライン内で次のモジュールに渡します。

ここで、次のモジュールに渡す前に、モジュールの出力データを入力データと組み合わせる追加処理を加えることができます。この追加処理を _ブレンディング(blending)_ と呼びます。入力・出力データは、ブレンド演算子とか [ブレンドモード(blend modes)](./blend-modes.md) とか呼ばれるアルゴリズムを使って組み合わせられます。

さらに、ブレンドモードには _不透明度(opacity)_ パラメータがあり（0%〜100%の値をとります）、モジュールの入力・出力データがそれぞれ最終的な出力にどの程度寄与するかを決めます。通常、不透明度を0%とすると最終的な出力は入力データと同一になり（モジュールの処理は無視され）、100%とするとモジュールの処理が最大限効果を発揮します。

不透明度は、全ピクセルで同一の値とすることもできます（グローバル不透明度スライダーを使います）。この場合、ブレンディングは画像全体で均一に効果を発揮します。あるいは、不透明度の値をピクセルの位置や状態によって変化させることも可能です。このように画像の中で不透明度を変化させることを _マスク(mask)_ と呼びます。マスクを使うと、モジュールの効果が画像のどの部分でどの程度影響するかを、細かく制御することができます。[描画マスク(drawn mask)](./masks/drawn.md) 、 [パラメトリックマスク(parametric mask)](./masks/parametric.md) 、 [二種のマスクの組み合わせ(combination of the two)](./masks/drawn-and-parametric.md) のいずれかを選び、有効化してください。

ブレンディングとマスクの機能は、それぞれのモジュールの一番下にある一連のアイコンを使って操作します。

![mask & blend options](./overview/mask-blend-options.png#w33)

アイコンの左から順に、それぞれ以下の方法を選択します。

オフ(off)
: モジュールの出力は、特にブレンディングされることなくそのまま次のモジュールに渡されます。この状態のときは、それ以外の設定は表示されません。

一様(uniformly)
: 入力・出力データが、選択されたブレンドモードで、全ピクセルについて一様に組み合わされます。組み合わせる度合いは、単独の不透明度スライダーで設定します。この状態では、ブレンドモード選択と不透明度スライダーが追加で表示されます。デフォルト設定は、ブレンドモード「通常」(normal)で、不透明度100%です。

[描画マスク(drawn mask)](./masks/drawn.md)
: 形状を描画することで定義された位置のピクセルに、選択されたブレンドモードと不透明度によるブレンディングが適用されます。この状態では、マスクの形状を描画するためのインターフェースが表示されます。この状態でも、マスクのための形状が描かれていない場合は、すべてのピクセルの不透明度が等しくスライダーで定義された値に設定されます。

[パラメトリックマスク(parametric mask)](./masks/parametric.md)
: 選択されたブレンドモードと、個々のピクセルの状態に応じて決まる不透明度によるブレンディングが適用されます（訳注：「輝度が特定の値の範囲にあるピクセルだけ不透明度100%とする」など）。この状態では、ピクセルの値によって不透明度を設定するためのインターフェースが表示されます。

[描画&パラメトリックマスク(drawn & parametric mask)](./masks/drawn-and-parametric.md)
: 描画マスクとパラメトリックマスクの組み合わせによって、選択されたブレンドモードと不透明度によるブレンディングが適用されます。

[ラスターマスク(raster mask)](./masks/raster.md)
: ピクセルパイプラインで前の段階にあるモジュールで生成されたマスクによって、選択されたブレンドモードと不透明度によるブレンディングが適用されます。

ブレンディングオプション
: パラメトリックマスクを生成するときにどの色空間を使うかを選択し、またマスクを生成するときにモジュールの出力の値を使うことを許すかも選択します（通常、パラメトリックマスクはモジュールに対する入力の値を使って生成します）。以下の選択肢から選んでください（訳注：これは「ブレンドモード」とは別もので、一番右の三本線メニューから選びます）。
: - _デフォルトのブレンド色空間に戻す(reset to default blend colorspace)_: パラメトリックマスクを生成するために、モジュールのデフォルト色空間を使います。
: - _Lab_: パラメトリックマスクを生成するために、（可能なら）Lab色空間を使います。
: - _RGB（ディスプレイ）_: パラメトリックマスクを生成するために、ディスプレイ参照型RGB/HSL色空間を使います。
: - _RGB（シーン）_: パラメトリックマスクを生成するために、シーン参照型RGB/J<sub>z</sub>C<sub>z</sub>h<sub>z</sub>色空間を使います。
: - _出力チャンネル操作を表示(show output channels)_: [パラメトリックマスク](./masks/parametric.md) 出力チャンネルに関するインターフェースを表示し、パラメトリックマスクをモジュールの出力値で定義できるようにします。

---

**注意：** 上述のブレンディングオプションは、モジュールによっては使えないものがあります。

---

