---
title: the pixelpipe & module order
id: the-pixelpipe-and-module-order
weight: 20
draft: false
---

[編集モジュール(processing modules)](../../module-reference/processing-modules/_index.md) は一定の順序で入力ファイルに適用され、出力画像が生成されます。この一連のモジュール適用のことを「ピクセルパイプライン(pixelpipe)」と呼びます。

ピクセルパイプラインの順序は、画面右パネルに表示されているモジュールの順序で示されています。モジュール一覧の一番下から始まり、RAW画像に順次編集モジュールがひとつずつ適用されて、処理が一段ずつ積み重ねられてゆき、一覧の一番上まで到達すると最終的な処理結果が得られます。

---

**注意：** 編集モジュールが実行される順序は、darktableの画面に表示されている順序と必ず同じになります。 **右パネルに表示されているモジュールの順序を変えると、画像に行なわれる処理の順序が変わります。**

---

# モジュールの順序とワークフロー

ピクセルパイプラインの中でモジュールが実行される順序は、出力品質を最高に近づけるために十分な検討の上決められています。以前のバージョンのdarktableでは、モジュール実行の順序を変更することは不可能でした。しかしながら、いくつか非常に特殊な使い方においては、ピクセルパイプライン中でいくつかモジュールの順序を動かすほうがよい場合がありえます。

モジュールの順序を変えるひとつの大きな理由は、darktableのバージョン3.0で _シーン参照(scene-referred)_ 作業法が導入されたときに生じました。バージョン3.2では、さらに _ディスプレイ参照(display-referred)_ および _シーン参照_ のワークフローとして整理され、 [設定(preferences) > プロセッシング(processing) > ピクセルワークフローのデフォルト操作を自動適用する(auto-apply pixel workflow defaults)](../../../preferences-settings/processing.md) の項目で設定できるようになりました。バージョン3.6以降は、 _シーン参照_ ワークフローがdarktableを使う上での公式に推奨される（そしてデフォルト設定の）方法となりました。

_シーン参照_ ワークフローでは、可能な限り多くの処理を線形RGB色空間で行い、ピクセルパイプラインの最後で出力媒体におさまるよう階調を圧縮します（非線形なトーンマッピングを使います）。これには旧来の _ディスプレイ参照_ ワークフローと比べて、より物理的に正当な色空間で処理を行うというメリットがあります。 _ディスプレイ参照_ ワークフローでは、非線形な _知覚的_ 色空間で処理を行っています。（知覚に即した処理ではなく）物理的な現実に即した処理を行うことで、処理アルゴリズムが予測可能な結果をもたらすように、また異常な結果が最小限になるようにすることが、ずっと楽になります。

この2つのワークフローの違いを理解するため、以下のような図が助けとなるかと思います。

![scene-referred and display-referred modules](./the-pixelpipe-and-module-order/scene-display-workflows.png)

1. _シーン参照_ のモジュールは、撮影時にカメラが集めた光の量に比例する、線形のデータを処理します。ピクセルパイプラインにおけるシーン参照部分では、画像のダイナミックレンジはだいたい表示媒体（モニターや印刷用紙など）のものより大きくなります。

2. ピクセルパイプラインのどこかの時点で、各ピクセルの値は非線形トーンマッピング操作で圧縮され、モニターや印刷に適した狭いダイナミックレンジにおさまるように変換されます。

3. 残りのモジュールは、ピクセルパイプラインにおける非線形の _ディスプレイ参照_ 部分で働き、最終的な出力となる画像を生成します。

## ディスプレイ参照ワークフロー

バージョン3.0以前では、darktableのワークフローは _ディスプレイ参照_ （「ピクセルワークフローのデフォルト操作を自動適用する」が「ディスプレイ参照」）であり、現在のバージョンでもこの選択肢は旧版モードとして存在します。このワークフローでは、 [_ベースカーブ(base curve)_](../../../module-reference/processing-modules/base-curve.md) か [_フィルミックRGB(filmic rgb)_](../../../module-reference/processing-modules/filmic-rgb.md) モジュールが、ピクセルパイプラインの早い段階でトーンマッピングを行い、その他の大部分のモジュールは圧縮された _ディスプレイ参照_ 空間で動作します。

ディスプレイ参照ワークフローを選択すると、古い（darktable 3.0以前の）モジュール順序が有効になり、また新しく編集を始めた画像に対して [_ベースカーブ(base curve)_](../../../module-reference/processing-modules/base-curve.md) モジュールが自動的にオンになります。

_ディスプレイ参照_ 空間でのピクセル値は非線形であり、元の撮影シーンを物理的な現実に即して表現したものにはなっていません。このことにより、使うモジュールによってはいろいろな歪みなどが生じるため、 _シーン参照_ ワークフロー（現在はこちらがデフォルト）が作られました。

## シーン参照ワークフロー

darktable 3.0で、 _シーン参照_ ワークフロー（「ピクセルワークフローのデフォルト操作を自動適用する」が「シーン参照」）が導入されました。モジュールの処理順序は完全に書き直され、 [_フィルミックRGB(filmic rgb)_](../../../module-reference/processing-modules/filmic-rgb.md) と [_ベースカーブ(base curve)_](../../../module-reference/processing-modules/base-curve.md) といったトーンマッピングのモジュールは、ピクセルパイプラインのずっと後のほうに置かれるようになりました。このことはつまり、ピクセルに対する操作のほとんどは _線形RGB_ 空間で実行されるようになり、ごく一部のモジュールだけが非線形の _ディスプレイ参照_ 空間で実行されるようになった、ということを意味します。現在、このワークフローでは、画像処理の大部分を [_フィルミックRGB_](../../../module-reference/processing-modules/filmic-rgb.md) より前に位置するモジュール（フィルミックRGBも含む）で行うことが推奨されています。ピクセルパイプラインのこの部分では、操作は完全に線形であり、ずっと物理的な現実に即しており、歪みを生じることもずっと少なくなります。

このワークフローでは、 _バージョン3.0_ のモジュール順序が使われ、新しく編集を始めると自動的に [_露光(exposure)_](../../../module-reference/processing-modules/exposure.md) と [_フィルミックRGB_](../../../module-reference/processing-modules/filmic-rgb.md) のモジュールがオンになり、シーン参照ワークフローで編集を始めるのにちょうどよいように設計されたデフォルトの設定がなされます。

# モジュール順序の変更

以下の理由により、ピクセルパイプライン中のモジュールの順序は変更しないでおくことが強くおすすめされます。

- モジュールの順序は、十分な考慮の上、最良の出力が得られるように配置されています。順序を変えると、たいていの場合、出力結果はむしろ悪くなります。
- 編集モジュールは、ピクセルパイプライン中で順序を動かすと意味をなさない場合がいくつか存在します。例えば、 [_ハイライト再構成(highlight reconstruction)_](../../../module-reference/processing-modules/highlight-reconstruction.md) は、 [_デモザイク(demosaic)_](../../../module-reference/processing-modules/demosaic.md) がなされる前のRAWデータに処理を行う必要があります。またデモザイクは [_入力カラープロファイル(input color profile)_](../../../module-reference/processing-modules/input-color-profile.md) が適用される前でなければなりません。この理由により、ピクセルパイプラインのはじめのほうにあるモジュールには、今でも順序が変えられないようになっているものがあります。
- ほとんどの編集モジュールは、ある特定の色空間で動作するよう設計されています（詳しくは [カラーマネジメント(color management)](../../../special-topics/color-management/_index.md) の節を参照）。モジュールの順序を完全に自由に動かせるようにするためには、ピクセルパイプライン中の現在の色空間が何であっても対応できるように、色空間ごとのモジュールの動作アルゴリズムをそれぞれ別個に実装しておく必要があります。こうなるとソフトウェアとしてあまりにも複雑になりすぎます。

一般的にはピクセルパイプラインのモジュール順序はそのままにしておくほうがよいですが、それでも、Ctrl+Shiftを押しながらモジュールを別の場所に動かすと、順序を変えることが可能になっています。この操作は、画像処理結果にどのような影響をおよぼすか十分理解している場合にだけ行なってください。

モジュールの順序を、 _バージョン3.0_ のものか _旧版(legacy)_ のものかを手動で変更するには、 [モジュール順序(module order)](../../../module-reference/utility-modules/darkroom/module-order.md) モジュールを使ってください。これを使うと、独自のモジュール順序をプリセットとして定義することも可能です。