---
title: wavelets
id: wavelets
weight: 55
draft: false
---

ウェーブレット(wavelet)とは画像処理において使われる手法のひとつで、画像を複数の _レイヤー(layer)_ に分け（ _分解(decompose)_ と呼びます）、それぞれのレイヤーが異なったスケール（大きさ）のディテールを持つようにします。このように画像を分解すると、モジュールがこのうちのいくつかのレイヤーにだけ処理を行い、元どおりにレイヤーを合成して最終的な出力画像を得る、ということが可能になります。そうすると、モジュールで処理するにあたって、画像の中のどの部分に影響を与えるかを正確に制御できるようになります。

darktableでこのように処理ができる例としては、以下のようなものがあります。

- ノイズ除去（ [_ノイズ低減（プロファイル）(denoise (profiled))_](../../module-reference/processing-modules/denoise-profiled.md) 、 [_RAWノイズ低減(raw denoise)_](../../module-reference/processing-modules/raw-denoise.md) 、 [_コントラストイコライザー(contrast equalizer)_](../../module-reference/processing-modules/contrast-equalizer.md) などのモジュール）
- コントラスト調整（ [_コントラストイコライザー_](../../module-reference/processing-modules/contrast-equalizer.md) モジュール）
- 不要なディテールのぼかし、除去（ [_レタッチ(retouch)_](../../module-reference/processing-modules/retouch.md) モジュール）

# 理論

ウェーブレットとは、数学的に言うと、ゼロから始まって上下に振動した後またゼロに戻るような形をした関数のことです。以下の図（上半分）では、いろいろなサイズの単純なウェーブレットの例を示しています。

![wavelets-overview](./wavelets/wavelets-overview.png#w50) 

このようなウェーブレットを使い、 _畳み込み(convolution)_ と呼ばれる数学的な操作によって、画像を走査します。畳み込みによって、ウェーブレットの大きさに近いスケールのディテールが、画像から抽出されます。そして、各ウェーブレットのスケールに対応したディテールのレイヤーが生成されます。

以下では、上にあげた画像からディテールレイヤーを抽出する例を示します。この例では、画像を [_レタッチ(retouch)_](../../module-reference/processing-modules/retouch.md) モジュールで処理しており、画像を8段階のレイヤーに分解して、さらにモジュールの操作によって各ウェーブレットで抽出したディテールを表示しています。

![wavelets-retouch-gui](./wavelets/clean-retouch.png#w33)

_ウェーブレット分解(wavelet decompose)_ 画面にある四角の並びが、各ウェーブレットによって抽出されたレイヤーを示しています。左端の一番黒い四角が画像全体（分解前の画像）を表し、グレーの四角がそれぞれの分解されたレイヤーです。その下にある階段アイコンでレイヤー表示オンオフを切り替えることができ、現在選択されているレイヤーを確認することができます。

上の画像から生成されたレイヤーをいくつか見てみましょう。

スケール2には、非常に細かいディテールだけが存在します。眉や睫毛の形、肌の細かい凹凸などです。それ以外のより粗いスケールのディテールは、別のレイヤーに抽出されており、このスケールでは確認できません。

![wavelets-layer-scale-2](./wavelets/wavelets-layer-scale-2.png#w50)

スケール5と6には、より大きい形状が抽出されていることがわかります。

![wavelets-layer-scale-5](./wavelets/wavelets-layer-scale-5.png#w50) 

![wavelets-layer-scale-6](./wavelets/wavelets-layer-scale-6.png#w50)

スケール8では、鼻や目や頬のおおまかな外形といった、非常に大きいレベルの形状のみが確認できます。

![wavelets-layer-scale-8](./wavelets/wavelets-layer-scale-8.png#w50)

# なぜウェーブレットを使うのか？

例えば、上の例において、肌の質感自体は損なわずに肌のしみの部分だけを少し隠したいとします。ウェーブレット分解を使えば、これは簡単な操作になります。つまり、レタッチ(retouch)モジュールのガウシアンぼかし機能を、その「しみ」が含まれるスケールのレイヤー（複数かもしれませんが）にだけ適用して、その他のレイヤーはそのままにすればよいのです。その調整処理のあと、レタッチモジュールが処理されたレイヤーと残りの変更していないレイヤーをそのまま再合成し、最終的な出力画像が生成されます。

以下に上の例で実際に実行した様子を示します。1つめが元画像、2つめがぼかし対象のレイヤー（スケール5）、そして3つめがスケール5レイヤーにぼかしをかけてからレイヤーを再合成した最終的な画像です。

![wavelets-original](./wavelets/wavelets-original.png#w50) 

![wavelets-layer-scale-5](./wavelets/wavelets-layer-scale-5.png#w50) 

![wavelets-blur-layered](./wavelets/wavelets-blur-layered.png#w50)

見ての通り、大きめのスケールにあるしみは消えていますが、より細かいスケールのディテールはそのまま残っています。

# ウェーブレットのスケールごとの操作

モジュール内でウェーブレットを使うとき、各スケールにどのように操作するか調整する操作インターフェースは、2種類あります。

## ウェーブレット分解(wavelet decomposition)

上述の通り、 _レタッチ_ モジュールでは、画像のディテールを何段階のレベルに分けるか選ぶことができます。画像をその段階のレイヤーに分解し、操作を個々のレイヤーかあるいは画像全体に適用することができます。

![wavelets-retouch-gui](./wavelets/clean-retouch.png#w33)

詳しくは、 [_レタッチ_](../../../module-reference/processing-modules/retouch.md) モジュールの説明を参照してください。

## スプライン曲線による操作

ノイズ除去（ [_ノイズ低減（プロファイル）(denoise (profiled))_](../../module-reference/processing-modules/denoise-profiled.md) 、 [_RAWノイズ低減(raw denoise)_](../../module-reference/processing-modules/raw-denoise.md) 、 [_コントラストイコライザー(contrast equalizer)_](../../module-reference/processing-modules/contrast-equalizer.md) の3つのモジュールでは、操作をそれぞれのスケールに対して適用するにあたって、 _スプライン曲線_ を使った方法で設定します。

![spline](./wavelets/clean-spline.png#w33)

この画面では、表示されているそれぞれのノードが、画像のディテールのレベルを表しています。左に行くほど粗い、右に行くほど詳細なディテールになります。それぞれのノードをマウスで上下に動かすことで、モジュールの操作が対応するウェーブレットのスケールに適用される量を増減できます。

この曲線を変更するには、動かしたいノード付近の線のあたりをクリックし、そのまま上下にドラッグしてください。ノードを動かしたときに曲線が動く幅は、マウスホイールで変更できます。マウスポインターの周囲に表示されている円のサイズが変わると思います。この円が小さいほど、上下にドラッグしたときの影響はノード周辺だけに限定されます。大きくなると、影響する範囲がもっと広くなり、隣接するノードも動くようになります。マウスカーソルをこのグラフの上で動かしたときに表示される影の部分は、ドラッグしたときに影響を受ける曲線の範囲を示しています。