---
title: color calibration
id: color-calibration
applicable-version: 3.6
tags:
working-color-space: RGB
view: darkroom
masking: true
include_toc: true
---

色空間補正、ホワイトバランス調整にチャンネルミックスもできる高機能モジュールです。

この単純な、しかし強力なモジュールは、以下のような目的で使うことができます。

- [_ホワイトバランス(white balance)_](./white-balance.md)モジュールと協調して、ホワイトバランスの調整（ [色順応処理(chromatic adaptation)](#white-balance-in-the-chromatic-adaptation-transformation-cat-tab) ）を行います。この場合、 _ホワイトバランス_ モジュールは、初期段階でのホワイトバランスの設定を行います（これは [_デモザイク(demosaic)_](./demosaic.md) モジュールを効果的に機能させるために必要になります）。それから _カラー較正(color calibration)_ モジュールが、入力カラープロファイル(input color profile)が適用された後に、もっと人間の知覚にあわせたホワイトバランスを計算します。

- 単純なRGB [チャンネルミキサー(channel mixer)](#channel-mixing) として、RGBチャンネルそれぞれの入力に対するRGBチャンネルの出力を調整し、クロストークカラーグレーディングを行います。

- 各ピクセルのRGBチャンネルの相対的な強さに応じて、ピクセルの [彩度と輝度](#brightness-and-colorfulness-tabs) を調整します。

- 光のスペクトルに対する白黒フィルムの反応と同様の動作で、RGBチャンネルの相対的な強さに応じた [グレースケール出力](#gray-tab) を生成します。

- [カラーチャート](#extracting-settings-using-a-color-checker) を使い、入力カラープロファイルにおける色の正確性を向上させます。

# 色順応変換(Chromatic Adaptation Transformation, CAT)タブのホワイトバランス調整

「色順応処理」とは、「撮影シーン内のいろいろな表面が別の光源に照らされていたとしたら、どのように見えるか」を予測するための処理です。ただ、撮影シーン中の色を光源の違いに合わせるために我々が実際に予測したいことは、「目の前のモニターと同一の光源で照らされた場合、各表面がどのように見えるはずか」になります。一方、ホワイトバランスは、白やグレーの部分が実際に無彩色に（R、G、B成分が等しく）なることを保証するだけで、その他の色がどうなるかは関知しません。つまりホワイトバランスでは、色順応処理を部分的に行うだけです。

色順応処理は、 _カラー較正(color calibration)_ モジュールの色順応変換（CAT）タブで調整できます。これを使う場合でも _ホワイトバランス(white balance)_ モジュールはやはり必要で、（入力カラープロファイルの値にあわせて）基本的なホワイトバランス処理を行います。この技術的なホワイトバランス処理（「カメラ参照」モード）は、標準D65光源に照らされたグレーを無彩色にするような基本的な設定で、デモザイク処理がより正確になりますが、シーンに応じた知覚的な補正は一切行いません。それから、 _ホワイトバランス_ と _カラープロファイル入力_ モジュールで行われるこうした補正のあとに、 _カラー較正_ モジュールによって実際の色順応処理が行われます。そのため、 _カラープロファイル入力_ モジュールでカスタム行列を使うのはおすすめできません。さらに、このモジュールが思わぬ動作をしないように、 _ホワイトバランス_ モジュールのRGB係数も正確である必要があります（？）。

設定で色順応ワークフローの選択肢（[設定(preferences) > プロセッシング(processing) > 色順応処理のデフォルト設定を自動適用(auto-apply chromatic adaptation defaults)](../../preferences-settings/processing.md)）を「モダン(modern)」にすることで、新しく編集を始めるときに _カラー較正_ と _ホワイトバランス_ モジュールが自動的に適用されて色順応処理が行なわれるようになります。ホワイトバランスの処理をすべて _ホワイトバランス_ モジュールで設定したい場合は、選択肢「レガシー(legacy)」も用意されています。どちらを使った場合でも、ピクセルパイプラインのさらに後で [_カラーバランスRGB(color balance RGB)_](./color-balance-rgb.md) などのモジュールを使い、クリエイティブなカラーグレーディングを行うことには問題ありません。

デフォルトでは、 _カラー較正_ での色順応処理は次のように行なわれます。

- まず、RAWファイルのEXIFデータから、カメラで設定された撮影シーンのホワイトバランスを読み取り、
- _ホワイトバランス_ モジュールで得られるカメラ参照ホワイトバランスを使ってこの値を調整し、
- 現在の入力カラープロファイル（標準行列のみ）を使ってさらに調整します。

一貫性を保つため、 _カラー較正_ のデフォルト設定では常に、 _カラープロファイル入力_ モジュールで標準の行列が使われていると想定され、非標準の設定は無視されます。しかし、 _カラー較正_ のデフォルト設定で _ホワイトバランス_ モジュールで自動適用されるプリセットを読みこむことは可能です。

また、 _ホワイトバランス_ モジュールとは違い、 _カラー較正_ では [マスク(masks)](../../darkroom/masking-and-blending/masks/_index.md) を使うことができる、という点もポイントです。つまり、画像の別々の部分に別々の光源を想定して調整することができるのです。

こうするためには、まず全体の調整のための _カラー較正_ モジュールのインスタンスを作り、別個に扱いたい部分を抜いたマスクを使ってください。それからふたつめのインスタンスを作り、[ラスターマスク(raster mask)](../../darkroom/masking-and-blending/masks/raster.md)を使って、最初のインスタンスで使ったマスクを反転して再利用します。

## CATタブのワークフロー

色順応処理における光源と色空間の初期値は、デフォルトではRAWファイルのEXIFメタデータから作られます。CATタブには、この初期パラメータを手動で設定するための4つの選択肢が用意されています。

- カラーピッカー（色見本の右側）を使って画像の中から無色の部分を選択するか、できない場合は画像全体を選択すると、アルゴリズムによって選択範囲の平均色を算出し、それを光源の色として使います。この方法は、自然な撮影シーンでは平均の色が無色になる、という「グレーワールド」仮定に基づいています。ですので、色を塗った表面などの、人工的な撮影シーンではこの方法はうまく動きません。

- _（AI） 境界から検出(detect from edges)_ を選択すると、機械学習の手法により、画像全体から光源を検出します。このアルゴリズムでは、画像から検出された境界部分の、色の変化度合いの平均を算出し、それを光源の色として使います。この方法は「グレー境界」仮定に基づいていますので、大きな色収差がある場合は失敗する場合があります。他の境界検出手法と同様、この方法はノイズに敏感で、高ISOな画像には適していません。しかし、無色の部分がないような人工的な撮影シーンには最適です。

- _（AI） 表面から検出(detect from surfaces)_ を選択すると、上のふたつの手法を組み合わせ、画像全体に適用します。このアルゴリズムでは、くっきりした境界のある領域や色に強い相関のある領域を重視して、画像の平均色を算出します。こうすることにより、 _境界_ 版よりもノイズに強くなり、本当に無色でない表面があっても単純な平均をとる場合よりうまくいきやすくなります。しかし、鮮やかな色がついたテクスチャ（緑の草など）がある場合は失敗しやすくなります。

- _カメラ設定(as shot in camera)_ を選択すると、カメラのデフォルト値に戻し、RAWファイルのEXIFを再読みこみします。

色見本は、現在算出されている光源の色の、sRGB空間における値を示しています。色順応アルゴリズムの目標は、この色を純粋な白にすることですが、これは必ずしも「画像をその *知覚的な* 反対色にシフトさせる」という意味ではありません。光源の色が適切に設定されていれば、モジュールをオフにしたとき、画像全体が色見本に表示される色と同じ色調になるはずです。

色見本の左側には _CCT_ （相関色温度 correlated color temperature）の近似値が表示されます。CCTとは、現在使われている光源に最も近い色温度（ケルビン単位）です。たいていの画像処理ソフトでは、ホワイトバランスは色温度と色合いのペアで設定するようになっています。しかし、光源が昼光とかけはなれている場合、CCTは不正確で意味の薄いものになりますし、CIE（国際照明委員会）でもそのような条件での使用は勧めていません。CCTの表示は、以下の中で最も近いCCTを示します。

- CCTのあとに _（昼光(daylight)）_ がついている場合、現在の光源は理想的な太陽光スペクトルに近く（±0.5%）、CCTの数字に意味があることを示しています。この場合は、 _D （昼光）_ 光源を使うのがおすすめです。
- CCTのあとに _（黒体(black body)）_ がついている場合、現在の光源は理想的な（プランク）黒体のスペクトルに近く（±0.5%）、CCTの数字に意味があることを示しています。この場合は、 _プランク輻射（黒体）(Planckian)_ 光源を使うのがおすすめです。
- CCTのあとに _（無効(invalid)）_ がついている場合、現在の光源のスペクトルは昼光とも黒体ともかけはなれており、したがってCCTの数字には意味がなく、間違っていることを示しています。この場合は、 _カスタム(custom)_ 光源を使うのがおすすめです。このときも色順応処理はやはり期待どおり機能します（下の注記を参照）ので、 _（無効）_ の表示は単に、現在の光源の色は表示されているCCTに結びついているわけではない、ということを示しているにすぎません。この表示があったからといって心配する必要はありません。昼光光源や黒体光源を使うと期待どおりのふるまいをしないので使わないほうがいい、と示すために表示されるだけです。

上記の光源検出法のどれかを使った場合、このモジュールが、算出された光源がふたつの理想的なスペクトル（昼光と黒体）を基準にしてどのあたりになるのかを調べます。そして最も確からしいスペクトルモデルを使って _光源(illuminant)_ を決定します。それに応じて、操作画面は以下のように変化します。

- 検出された光源が _D （昼光）_ か _プランク輻射（黒体）_ に近い場合、CCTに意味がありますので、色温度のスライダーが表示されます。
- _カスタム_ 光源の場合は、CIE 1976 Luv 色空間での色相・彩度スライダーが表示され、なにかの仮定なしの知覚的枠組みで光源の色を直接設定できるようになります。

---

**注意：** 内部的には、光源の値はCIE xyY色空間の絶対色度座標で表現されています。このモジュールの光源設定は、単にこの値を現実世界との関係から設定するためのもので、これをすばやく処理できるように設計されています。CCTが「無効」と表示されていたとしても、実際の処理アルゴリズムで問題が起きるわけではないです。単にCCTと対応するxyY座標の関係が物理的に正確なものではない、というだけです。どのような表示であれ、処理アルゴリズムはいつでも、光源の色として設定された値（色見本に表示されている色）を使います。

---

光源の種類の設定を変更すると、このモジュールは元の設定をできるだけ正確に新しい光源での設定に変換しようとします。何かの光源を _カスタム_ 光源に変換する場合は、 _カスタム_ 光源というのは一般的な表現形式なので、元の設定を完全に変換することができます。しかしそれ以外の光源の間で変更する場合や、 _カスタム_ 光源からそれ以外への変換をする場合は、丸め誤差が発生するため元の光源での設定を完全に再現することができません。

これ以外にも、組み込みの _光源_ が用意されています（下記参照）。これらの値は標準的なCIE光源からとられたものであり、絶対値です（？）。もし、どのような種類の電球で撮影シーンが照明されているかが正確にわかっていて、また使用しているカメラの入力プロファイルと参照（D65）係数が正確であることが確かであれば、これらの組み込みの値を使うことができます。そうでなければ、下記の [_警告(caveats)_](#caveats) を参照してください。

## CATタブの操作

順応(adaptation)
: 色順応変換とチャンネルミックスが行われる色空間です。以下の選択肢から選べます。

: - _線形ブラッドフォード（1985）(Linear Bradford)_ 昼光に近くICC v4標準と互換性がある光源の場合は正確ですが、もっと面倒な光源の場合は色域外の色が生じやすくなります。
: - _CAT16（2016）_ この設定がデフォルトです。色域が広い場合や彩度が高いシアン・紫がある場合に、偽色が生じにくくなります。また、一般的にブラッドフォード式CATより正確です。
: - _非線形ブラッドフォード（1985）(Non-linear Bradford)_ 線形のものよりよい結果を出すこともありますが、確実性に欠けます。
: - _XYZ_ これは最も不正確になる方法で、一般的にテストやデバッグの場合以外はおすすめしません。
: - _なし（無効）(none (disable))_ 変換をいっさい行わず、パイプラインの元のRGB空間を使います。

光源(illuminant)
: 撮影シーンを照らしていると想定する、光源の種類です。以下の選択肢から選べます。

: - _パイプラインと同じ（D50）(same as pipeline)_ このインスタンスで色順応変換を行わず、 _順応_ で選んだ色空間を使ってチャンネルミックスだけ行います。
: - _CIE標準光源(CIE standard illuminant)_ CIEの標準光源（昼光、白熱灯、蛍光灯、等エネルギー光源、黒体）のいずれか、あるいは非標準の「LEDライト」光源から選択します。これらの値はすべてあらかじめ計算されたもので、カメラセンサーのプロファイルが適切である限り、そのまま使うことができます。プランク黒体軌跡と近い動作の光源については、さらに「温度」スライダーが使えます（下記参照）。
: - _カスタム(custom)_ 画像の中に中間グレーの部分がある場合は、光源の色をカラーピッカーで設定するか、あるいは色相と彩度のスライダーを使って手動で設定することができます（LCh 知覚色空間を使います）。カラーピッカーの隣にある色見本は、色順応変換処理で使われる、算出された光源色を示しています。このカラーピッカーは、AI検出で使う範囲を制限するためにも使います（下記）。
: - _（AI） 表面から検出(detect from image surfaces)_ このアルゴリズムは、YUV色空間の色差チャンネルについてチャンネル間・チャンネル内で高い共分散を持つような領域を、画像の中から検出して色の平均値を求めます。別の言い方では、画像の中でグレーのはずの部分を、実際にはグレーでないような単一色の表面はちゃんとよけて探します。また、色ノイズや色収差の部分もはずしています。
: - _（AI） 境界から検出(detect from image edges)_ _ホワイトバランス(white balance)_ モジュールの、「グレーワールド」仮定に基づく自動ホワイトバランス設定とは違い、この手法は「グレー境界」仮定に基づいて適切な光源を自動検出します。ラプラシアンのミンコフスキーpノルム（p = 8）を計算し、最小値を見つけることで検出しています。つまり、どの境界も全チャンネルにおいてグラデーションのきつさは同様のはずである、という「グレー境界」仮定をおいています。ひとつ前の、表面から検出する手法に比べると、こちらのほうがノイズに敏感です。
: - _カメラと同じ(as shot in camera)_ 光源を、カメラのホワイトバランス設定から計算します。

色温度(temperature)
: 光源の色温度を設定します。光源がもっと青いと想定される場合は、スライダーを右に動かします。すると、ホワイトバランス調整後の画像はより赤く、暖色に見えるようになります。光源がもっと赤い場合は、スライダーを左に動かします。補正された画像はより青く、寒色になります。

: この設定は、プランク黒体軌跡に近いふるまいをする光源の場合だけ使うことができ、黒体軌跡にそって微調整を行います。それ以外の光源の場合、「色温度」という概念自体に意味がないため、色温度スライダーは使えません。

色相(hue)
: カスタムホワイトバランスの場合、光源の色の _色相_ をLCh色空間で設定してください（CIE Luv色空間をもとにしています）。

彩度(chroma)
: カスタムホワイトバランスの場合、光源の色の _彩度_ をLCh色空間で設定してください（CIE Luv色空間をもとにしています）。

色域圧縮(gamut compression)
: ほとんどのカメラのセンサーは、目には見えない紫外線にも多少は反応し、青チャンネルに記録されて「偽色」を生じます。入力プロファイルが適用されたあとは、このような偽色は色域の外になり（つまり、一部の色が、現在の色空間の中で正の値を持つ有効な[R,G,B]の組で表現できなくなる場合がある）、階調に異常や歪みを生じます。色順応処理でもまた、一部の元々は有効な色が色域外になったり、元から色域外の色がさらに離れてしまったりします。
: _色域圧縮_ では、知覚に基づいた非破壊的な方法を使い、彩度を圧縮しつつ輝度をそのままに、また色相を可能な限り保つことで、画像全体をパイプラインで使っている色空間の色域にできるだけおさめます。この機能が役に立つひとつの例としては、青色LEDの光があるような撮影シーンがあげられます。青色LEDはよく大きな問題となり、最終的な画像で色域のひどいクリッピングが発生する場合があります。

負RGB値のクリップ(clip negative RGB from gamut)
: 負のRGB値をすべて取り除きます（ゼロとします）。変な黒レベルや、青色LED光があるときの青チャンネルのクリッピング問題などを扱うときに役立ちます。この設定は色に破壊的な変更を行います（色相が変わる場合があります）が、どんな場合でも必ず、出力は有効なRGB値になります。この設定は、自分で何をやっているかよく理解していて、色域マッピングを手動で調整したい場合をのぞいて、オフにするべきではありません。そのような場合は、 _露光(exposure)_ モジュールの _黒レベル調整(black level correction)_ を使って負のRGB値をなくして（RGB値というのは光を表現しているので、光はエネルギーですから、必ず正の値であるはずです）、それから画像に真っ黒な領域がなくなるところまで _色域圧縮_ の値を増やしてください。適切なノイズ除去も、おかしなRGB値をなくす助けになります。なお、このように手動で調整しても、青の極端な値を復元するには十分ではないような場合がありえます。

---

**注意 1**: ピクセル操作において、負の値にたいして定義されていない対数や羃関数が多く使われているため（ _フィルミック(filmic)_ 、 _カラーバランス(color balance)_ 、CIE LabとCIE XYZの間の色空間の変換操作すべて）、OpenCLのドライバによっては、ピクセルパイプライン中で負のRGB値があるときにうまく動作しないという現象が報告されています。こうした操作に対する入力は事前に整理されてはいるのですが、OpenCLのドライバによっては十分ではなく、そういう場合は `NaN` （非数(Not a Number)）が出力されることになります。そのあとにローカルフィルタ（ _シャープ化(sharpness)_ 、 _ローカルコントラスト(local contrast)_ 、 _コントラストイコライザー(contrast equalizer)_ 、 _ローパス(low pass)_ 、 _ハイパス(high pass)_ 、 _表面ぼかし(surface blur)_ 、 _フィルミック(filmic)_ のハイライト再構築といった、ぼかしやシャープ化の操作）によってこの `NaN` が周辺に広がり、黒・グレー・白の大きな四角形が現れるかもしれません。

上記のような現象が起きている場合、 _カラー較正_ モジュールの「負RGB値のクリップ」を **必ず** オンにする必要があります。

**注意 2**: 色関係のアルゴリズム（特に色域圧縮）が _カラー較正_ でうまく動作しないよくあるケースは、輝度（CIE 1931 XYZ 色空間のYチャンネル）の値がゼロなのに色の値（CIE 1931 XYZ 色空間のXとZチャンネル）がゼロでないような場合です。このような状態は、対応するような物理的な現実が存在しない異常な数値であり（輝度のないピクセルは色もないはずです）、xyYやYuvの色空間でゼロによる除算が発生し、結果として RGB値として `NaN` が出てくることになります。この問題を _カラー較正_ の中で補正することは **ありません**。なぜなら、これは入力プロファイルか黒レベルか（その両方か）がおかしいことによる現象なので、チャンネルミキサーで入力カラープロファイルを調整するか _露光(exposure)_ モジュールで _黒レベル補正(black level correction)_ を調整するかして手動で対応する必要があるからです。

---

## CAT警告

このモジュールでの色順応処理は、パイプラインの前の段階での処理についていくつかの仮定をおいており、そしてこの仮定は、意図せずに、そして気づかないうちにあっさりくずれてしまう場合があります。このような失敗を避けるために、 _カラー較正_ モジュールでは以下のような場合に警告が表示されます。

- _カラー較正_ モジュールで色順応処理をするようになっているのに、 _ホワイトバランス(white balance)_ モジュールで「カメラ参照(camera reference)」に設定されていない場合、両方のモジュールで警告が表示されます。このエラーは、 _ホワイトバランス_ モジュールを「カメラ参照」に設定するか、 _カラー較正_ モジュールで色順応処理を無効にすれば解決します。なお、センサーによっては _ホワイトバランス_ モジュールでも微修正を必要とする場合があり、そのような場合はこの警告は無視してかまいません。

- _カラー較正_ のインスタンスをふたつ以上作っていて、それぞれで色順応処理をしている場合、後ろのインスタンスで警告が表示されます。ただし、これは正しい場合（例えば、マスクを作って、画像内の重なっていない部分にそれぞれ別々のホワイトバランス処理をする場合など）もありえるので、そのような場合は無視できます。そうでなければ、色順応処理はどれかひとつのインスタンス以外は無効にして、二重（以上）の処理を避ける必要があります。

  デフォルトでは、すでに色順応処理をしている _カラー較正_ モジュールがある場合、新しく作ったインスタンスでは自動的に色順応処理が「なし（バイパス）(none (bypass))」に設定され、多重処理のエラーが起きないようにします。

CATタブで _順応(adaptation)_ の設定を「なし（バイパス）」にするか、 _光源(illuminant)_ の設定を「パイプラインと同じ（D50）(same as pipeline)」にするかで、_カラー較正_ における色順応処理を無効にできます。

以上の警告は、典型的なRAW編集ワークフローでデフォルト設定をそのまま使う場合の、ありがちな間違いを防ぐためのものです。カスタムプリセットや特殊なワークフローを使う場合（フィルムスキャンとかJPEGを編集する場合など）は、警告は無視できますし、そうすべきです。

詳しく理解している場合、 [設定(preferences) > プロセッシング(processing) > 警告を表示する(show warning messages)](../../preferences-settings/processing.md) で警告を表示しないように設定することもできます。

# チャンネルミックス

このモジュールの残りの部分は普通のチャンネルミキサーで、RGBそれぞれのチャンネルの入力の相対的な強さに対して、R・G・Bの出力、彩度、輝度、グレーなどを調整することができます。

チャンネルミックスは、 [CATタブ](#cat-tab-controls) の _順応(adaptation)_ で設定された色空間で行なわれます。いろいろな実用上の理由で、CAT色空間は人間の知覚に基づいた、撮影シーンにおける光の量に比例するようなRGB色空間となりますが、それ以外のRGB空間と全く同様にふるまいます。CAT空間は人間の知覚と関連しているので、これを使うことでチャンネルミキサーの調整が楽になりますが、 _順応_ の設定を「なし（バイパス）(none (bypass))」にすることでパイプラインの作業RGB空間でチャンネルミックスを行うことも可能です。色順応処理を行なわずに _順応_ で設定した色空間でチャンネルミックスをしたい場合、 _光源(illuminant)_ を「パイプラインと同じ（D50）(same as pipeline)」に設定してください。

---

**注意** チャンネルミックスで使われる、CATあるいはRGBの原色の実際の色（のsRGB色空間への射影）は、RGBスライダーの背景の色として表示されています。これは、設定を変更したときに実際どのように色が変化するか知る助けになります。

---

チャンネルミックスとは、各チャンネルの増幅・減衰度合を、すべてのチャンネルの元の値の比として定義する操作です。各チャンネルの出力値を入力値と単純に結びつける単一の補正ではなく（例えば、`Rの出力 = Rの入力×補正割合` とするなど）、各ピクセルの他の _すべての_ チャンネルにも依存した補正を行います（例えば、`Rの出力 = Rの入力×Rの補正 + Gの入力×Gの補正 + Bの入力×Bの補正`）。すなわち、ピクセルの各チャンネルが相互に影響を与えるようになります。これは「クロストーク」と呼ばれ、3次元色空間の中で原色を回転させることと等価です。また、物理的なカラーフィルターをデジタルで再現することにもなっています。

3次元色空間で原色を回転させることは、最終的には一般的な色相の回転操作と等価なのですが、RGBの補正と最終的に知覚できる色相の回転にどのような関連があるかが直接わかるわけではなく、この操作は直感的なものではありません。ここでの「R」、「G」、「B」というのは単に操作するために用意された3種類の光の組み合わせとして理解すべきであり、色とか色相の組ではないのです。さらに、RGBの三刺激値は輝度と色光度を分離しておらず加法混色なので、「G」チャンネルは「R」や「B」より強く人間の輝度の知覚に結びついています。そしてすべてのピクセルのGチャンネルはゼロでない値を持ち、ということはGチャンネルの補正はすべてのピクセルに影響する、ということになります。

すなわちチャンネルミックスは（加法混色の）RGB三刺激値の物理的な解釈に結びつけられていて、原色のカラーグレーディングや光源の補正に適していますし、色の変化をなめらかに混ぜあわせることができます。しかし、知覚的な観点（輝度、色相、彩度）から挙動を理解したり、予測したりしようとするとうまくいかないでしょうし、おすすめできません。

---

**注意：** このモジュールで、色空間におけるチャンネルに「R」「G」「B」という名前が使われているのは、単なる慣習的なものです。それぞれのチャンネルは、必ずしも「赤」とか「緑」とか「青」に見えるとは限りません。ですから、名前からチャンネルの意味を考えようとするのはおすすめできません。これは、 _どんな_ RGB空間でも、それがどんなアプリケーションで使われていても通じる、一般的な原則です。

---

# R、G、Bタブ

一番単純に考えると、 _カラー較正_ モジュールのR、G、Bタブは、3x3行列と入力値の[R G B]ベクトルの積とみなすことができます。これは行列形式のICCカラープロファイルがやっていることと実際ほぼ同じで、行列の値をICCプロファイルのファイルから読むのではなくdarktableのGUIを使って入力できる、というだけです。

```
┌ R_out ┐     ┌ Rr Rg Rb ┐     ┌ R_in ┐
│ G_out │  =  │ Gr Gg Gb │  X  │ G_in │
└ B_out ┘     └ Br Bg Bb ┘     └ B_in ┘
```

例えば、ある色空間から別の色空間に変換する行列があるとすると、その値を _チャンネルミキサー_ に次のように入力することができます。

- _R_ タブを選択し、入力 R・G・BのスライダーでRr、Rg、Rbの値を設定する
- _G_ タブを選択し、入力 R・G・BのスライダーでGr、Gg、Gbの値を設定する
- _B_ タブを選択し、入力 R・G・BのスライダーでBr、Bg、Bbの値を設定する

デフォルトでは、 _カラー較正_ のミックス関数は単に入力のR、G、Bチャンネルをそのまま対応する出力チャンネルにコピーします。これは以下のような単位行列を掛ける操作と等価です。

```
┌ R_out ┐     ┌ 1  0  0 ┐      ┌ R_in ┐
│ G_out │  =  │ 0  1  0 │   X  │ G_in │
└ B_out ┘     └ 0  0  1 ┘      └ B_in ┘
```

R・G・Bタブのスライダーがどういうふうに働くか直感的に理解するには、次のように考えてみてください。

- _R_ の出力チャンネルに対しては、スライダーを右に動かすほど、画像のR/G/Bの領域がより「赤く」なり、左に動かすほどより「シアンに近く」なります。
- _G_ の出力チャンネルに対しては、スライダーを右に動かすほど、画像のR/G/Bの領域がより「緑に」なり、左に動かすほどより「マゼンタに近く」なります。
- _B_ の出力チャンネルに対しては、スライダーを右に動かすほど、画像のR/G/Bの領域がより「青く」なり、左に動かすほどより「黄色に近く」なります。

## R、G、Bタブの操作

R・G・Bタブそれぞれで以下の設定ができます。

入力 R/G/B(input R/G/B)
: タブの該当出力チャンネル（Rタブなら出力のRチャンネル）に対し、入力のR、G、Bチャンネルがそれぞれどの程度影響するか設定します。

チャンネル正規化(normalize channels)
: 行列の値を正規化し、入力画像に対して出力画像の該当チャンネルの輝度を同程度に保ちたい場合、このチェックボックスにチェックを入れてください。

# 輝度(brightness)タブと彩度(colorfulness)タブ

画像内のピクセルの輝度と彩度は、R、G、B入力チャンネルごとに調整することもできます。この処理は、基本的に [_フィルミック RGB(filmic rgb)_](filmic-rgb.md) モジュールの（RGBの比率を保存する）トーンマッピングや（RGBの比率をいじる）中間トーン彩度と同様のアルゴリズムを使っています。

彩度アルゴリズム(saturation algorithm)
: ここで選択することで、darktable 3.6 より前のバージョンで編集された画像でも、彩度のアルゴリズムを2021年の新版にすることができます。すでに新版を使っている場合は表示されません。

## 彩度タブの操作

入力 R/G/B(input R/G/B)
: ピクセルの彩度を、ピクセルのRGBチャンネルごとに調整します。例えば、 _入力 R_ スライダーを動かすと、「R」成分を多く含んでいるピクセルほど彩度が大きく変わり、「R」を少ししか含んでいない色はそんなに影響を受けません。

チャンネル正規化(normalize channels)
: 入力・出力画像の全体の彩度がなるべく変わらないようにするには、このチェックボックスにチェックを入れてください。

## 輝度タブの操作

入力 R/G/B(input R/G/B)
: 画像の中にある色に対して、RGBチャンネルごとに輝度を調整します。例えば、 _入力 R_ スライダーを動かすと、R成分を多く含む色ほど輝度が大きく変わり、R成分を少ししか含んでいない色はあまり変化しません。それぞれのピクセルを暗く/明るく変化させる際には、ピクセルのRGBチャンネルの比率を保つようにすることで、色相が変わらないようにしています。

チャンネル正規化(normalize channels)
: 入力・出力画像の全体の輝度がなるべく変わらないようにするためには、このチェックボックスにチェックを入れてください。

# グレー(gray)タブ

_カラー較正_ のもうひとつの便利な使いみちは、チャンネルの情報を統合してグレースケールの出力、すなわちモノクロ画像を作ることです。 _グレー_ タブを選び、R・G・Bのスライダーを操作して、それぞれのチャンネルがどの程度出力の輝度に影響するか設定してください。これは次のようなベクトルの積と等価です。

```
GRAY_out  =   [ r  g  b ]  X  ┌ R_in ┐
                              │ G_in │
                              └ B_in ┘
```

肌のトーンを扱う場合、三つのチャンネルの相対的な強さが、画像の細部のレベルに影響します。Rを強めにすると（例えば [0.9, 0.3, -0.3] など）より滑らかな描写になり、Gを強めにすると（例えば [0.4, 0.75, -0.15] など）より細部が描写されるようになります。どちらの場合でも、不必要に肌の質感を強調しないように、Bのチャンネルを弱めています。

## グレータブの操作

入力 R/G/B(input R/G/B)
R、G、Bそれぞれのチャンネルが、どの程度出力のグレーレベルに影響するか設定します。三つのスライダーの値の合計がゼロでないときだけ、画像はモノクロに変換されます。Bを強くすると細部がより描写されるようになる傾向にあり、Rを強くすると肌のトーンが滑らかになる傾向があります。

チャンネル正規化(normalize channels)
: スライダーを動かしても全体の輝度をなるべく一定に保ちたい場合、このチェックボックスにチェックを入れてください。

# カラーチャートから設定を作る

チャンネルミキサーは結局のところRGB行列なので（RAW画像に使う [_入力カラープロファイル(input color profile)_](./input-color-profile.md) と同様）、その場で必要な設定値を計算することで、チャンネルミキサーを使って入力カラープロファイルの色正確性を向上させることができます。

この計算する設定値というのは、ある特定の光源において撮影シーンとカメラに記録された値の色の違いを最小にすることを目標としています。これは一般的なICCカラープロファイルを作ることと等価ではありますが、ここでは、「プロファイル」に相当するのがモジュールに（R・G・Bタブで）設定される値である点が違います。この値は、プリセットやスタイルとして保存して、別の画像でも再利用することができます。このようなものは一般の入力プロファイルを補完・改善するためのもので、入力プロファイルの代わりとなるようなものではありません。

この機能は以下のような作業を手助けします。

* [演色性(Color Rendering Index, CRI)](https://en.wikipedia.org/wiki/Color_rendering_index) が低い電球のような、扱いにくくホワイトバランス設定だけでは不十分となる光源の対応
* 美術品のデジタル化や商品撮影など、元の色の正確な再現が必要な作業
* 複数のカメラを使った撮影において、基本的な見た目の統一・色設定の共有（最終的な見た目は統一的になるようにして）などの目的で、異なるカメラでの差を補正すること
* ホワイトバランスを固定し、反射光による色かぶりを抑えながら、まともな色パイプラインを、最小の労力と時間で得ること

## サポートされているカラーチャート

現在のところ、独自のカラーチャートを使うことはできません。以下の動作確認済みの（評判のよいメーカーの）カラーチャートがサポートされています。

- X-Rite / Gretag MacBeth Color Checker 24 (2014年以前のもの、以降のもの両方),
- Datacolor SpyderCheckr 24,
- Datacolor SpyderCheckr 48.

ノーブランドの安価なカラーチャートを買うのはやめたほうがよいです。そのようなものだと、それぞれの色の正確性が保証できないかもしれません。不正確なカラーチャートはそもそもカラー較正の目的に反しており、やらないより悪くなる場合もあります。

IT7・IT8のカラーチャートは、持ち運びが難しく、各現場で使うというのは現実的ではないため、サポートされていません。このようなチャートはむしろ、例えば [Argyll CMS](https://encrypted.pcode.nl/blog/index.html%3Fp=594.html) などを使って、標準の光源で一般的なカラープロファイルを作るのに向いています。

---

**注意**: X-Rite社は2014年に顔料の製法を変更しており、それぞれの色が若干変わっています。darktableではどちらもサポートされていますが、使っているものに対して正しい設定をするように注意してください。よくわからなければ、両方を試してみて、処理のあとで平均デルタEの値が最も低くなるほうを使ってください。

---

## 前提条件

この機能を使うためには、サポートされているカラーチャートを、撮影現場で、適切な照明のもとでテスト撮影する必要があります。

* カラーチャートをフレームの中央部分50%以内に入れ、周辺減光の影響がないようにする
* 主な光源がチャートから十分遠く、チャート表面に均一に光が当たっているようにする
* 光源・チャート・レンズ間の角度を調整し、チャートの色に反射や光沢が入らないようにする
* 最良の結果を得るためには、適切な輝度で撮影する必要があります。このためには、まずカラーチャートをブラケット撮影（-1〜+1EV）し、darktableで読みこんで、 _カラー較正_ と _出力カラープロファイル(output color profile)_ の間のモジュールはすべて無効にします。カラーチャートの白の部分が、 CIE Lab 色空間で 94〜96%の輝度Lとなるか、CIE XYZ 色空間で83〜88%の輝度Yとなっているような画像を使ってください（カラーピッカーを使って判定）。この手順は、厳密には絶対必要というわけではありません。単一の画像を撮影し、プロファイル品質表示(profile report)で表示される推奨露光補正を行なう、という方法もあります。

照明が標準D50からD65光源（直射の自然光で、色のついた反射光がない状態）に近ければ、カラーチャートを撮影した画像を使って、昼光光源で（多少ホワイトバランスの調整をするだけで）一般的に使うことができる「プロファイル」を作ることができます。

照明が特殊で標準光源とかけ離れている場合、カラーチャートを撮影した画像は、同様の照明条件で撮影した画像で使うための「プロファイル」を作るためにのみ使うことができます。

## 使い方

カラー較正で使われる設定は、選択されたCAT色空間と、パイプラインの前の段階で _ホワイトバランス(white balance)_ や _入力カラープロファイル(input color profile)_ での色関係の設定に依存します。従って、「プロファイル」の計算結果（つまりRGBチャンネルミックスの係数）は、特定の _CAT 色空間_ と _ホワイトバランス_ ・ _入力カラープロファイル_ の設定の組み合わせのときだけ使えるものとなります。もし計算した「プロファイル」で一般的なスタイルを作ろうというのであれば、これらのモジュールの設定もまたスタイルに入れておく必要があることに注意してください。

プリセットやスタイルを作るには、以下の手順に従ってください。

1. [_レンズ補正(lens correction)_](./lens-correction.md) を有効にして、較正処理に影響を与える周辺減光を補正します。
2. _カラー較正_ モジュールの最下部で、 _カラーチャートで較正する(calibrate with a color checker)_ と書いてあるあたりの三角印をクリックして、操作する部分を表示します。
3. _チャート(chart)_ ドロップダウンリストから、カラーチャートのメーカーと商品を選択します。
4. 画像のプレビューに、カラーチャートの部分に重ねてガイドが表示されます。チャートの角部分をドラッグして遠近法歪みを補正し、ガイド表示がカラーチャートにぴったり合うようにします。
5. _再計算(refresh)_ ボタンをクリックして、値を計算します。
6. _プロファイル品質表示(Profile quality report)_ の内容を確認します。もし "good" であれば、 _確定(validation)_ ボタンを押してください。そうでなければ、最適化方針を変えて、もう一度再計算してください。
7. 計算された「プロファイル」をプリセットかスタイルとして保存するか、あるいは、モジュールの設定値を同様の照明条件で撮影された画像すべてに、ライトテーブルやフィルムストリップで単純にコピーペーストします。

---

**注意：** この計算を行うときは _入力カラープロファイル_ モジュールで標準行列を使う _必要は_ ありません。ですが、カメラ設定(as shot in camera)のデフォルトホワイトバランスは別の「プロファイル」に対してはうまく機能しませんので、計算された値を再利用するなら必ず同じ入力カラープロファイルを使う必要があります。ご注意ください。

---

## 計算結果の品質表示を確認する

プロファイル品質表示(profile report)は、計算結果の品質を確認する助けとなります。カラー較正の計算結果は「最良の」最適化にすぎず、色スペクトル全域に対して100%正確になるようなことは決してありません。そのため、計算された「プロファイル」が信頼できるかどうか判断するために、「どの程度」不正確であるかを調べる必要があります。

悪い「プロファイル」ができてしまうことは実際ありえますし、そのようなものを使うとむしろ有害です。

### デルタEと品質表示

カラーチャートのそれぞれの色の基準値と計算で得られた値の間にどの程度差があるか、その知覚的な指標として、 [CIE delta E 2000](https://en.wikipedia.org/wiki/Color_difference#CIEDE2000) (ΔE) という値を使います。

- ΔE = 0 は、差がないということを意味します。較正で得られた色は基準の色と正確に同一です。残念ながら、実際にはこのようなことは起きません。
- ΔE = 2.3 の場合を、最小可知差異（Just Noticeable Difference、JNDと略す）と呼びます。人間がかろうじて気づける程度の差があるという意味です。
- ΔE < 2.3 は、普通の人が見ると基準の色と得られた色の差に気付かない、ということを意味します。これは十分な結果と言えるでしょう。
- ΔE > 2.3 は、普通の人が見ても基準の色と得られた色の差に気付く、ということを意味します。これは十分とは言えませんが、避けられない場合もあります。

品質表示では ΔE の平均値と最大値を、カラー較正モジュールの入力時点（モジュールの処理が行われる前）、色順応処理が行なわれた後（ホワイトバランスだけ適用された状態）、モジュールの出力時点（ホワイトバランスとチャンネルミックスが適用された状態）についてそれぞれ表示します。問題なく処理が行なわれていれば、それぞれの段階の ΔE は前の段階のものより低くなるはずです。

### 計算された「プロファイル」

「プロファイル」作成処理によって生成される値には、RGBの3x3行列と、検出された光源があります。この2つは、 _CAT_ タブで設定されるCAT _順応(adaptation)_ 色空間で表現されており、また、これらの値を別のソフトで使いたくなったときのために「プロファイルデータ(profile data)」のところで表示されています。検出された光源が _昼光(daylight)_ か _黒体(black body)_ のいずれかであれば、この行列はそれなりに汎用性があり、別の _昼光_ あるいは _黒体_ 光源の場合にも多少のホワイトバランス調整だけで再利用できます。

### 正規化値(Normalization values)

これらは、プロファイルの問題を可能な限り少なくするために、 [_露光(exposure)_](./exposure.md) モジュールでそのまま設定すべき _露光(exposure)_ や _黒レベル補正(black level correction)_ の値です。この設定は必ずしも必要ではなく、ぎりぎりまで精度を上げたい場合にのみ役立つものです。ただし、ここの設定により負のRGB値が発生し、パイプライン中でクリッピングが起こる場合がありうることには注意が必要です。

### ガイド表示

![color checker](./color-calibration/color-checker.png#w75)

カラーチャートに重ねて、それぞれの部分の中心に小さい円が表示されます。これはそこの色の基準の値になるはずの色（をディスプレイRGB色空間に射影したもの）です。これを確認することで、標準の色と実際の色の差を、 ΔE 値をいちいち見ずとも見た目である程度判断する役に立ちます。なおこの表示は、プロファイル品質表示の _正規化値_ のところで表示された値を _露光_ モジュールで実際に設定したときにのみ、信用できます。

「プロファイル」が計算されると、カラーチャートのそれぞれの部分に斜線が1本か2本表示される場合があります。これは以下のような意味です。

* 斜線がついていないところは ΔE < 2.3 （JND）の状態で、通常は見ても差に気付かない程度に正確であることを表しています。
* 斜線が1本あるところは 2.3 < ΔE < 4.6 の状態で、やや不正確であることを表しています。
* 斜線が2本（X字に）あるところは ΔE > 4.6 （JNDの2倍）の状態で、かなり不正確であることを表しています。

これらの表示により、色の正確性を確認しながら最適化のトレードオフを設定することができます。

## 「プロファイル」の改善

どんな較正であっても、それは（加重最小二乗法を使った）「最良の」最適化にすぎず、カラーチャートのすべての色を ΔE < 2.3 の基準内に収めるということは不可能です。つまり、ある程度の妥協が必要になります。

_最適化目標(optimize for)_ では、プロファイルでどの色の正確性を上げてどの色を犠牲にするかという、最適化戦略を設定することができます。以下の選択肢から選んでください。

- _なし(none)_ 明示的な戦略は用意せず、カラーチャートのメーカーが暗黙的に採用している戦略を使います。例えば、カラーチャートがおおむね彩度の低い色を揃えているのであれば、計算される「プロファイル」は彩度が低い色についてより正確になります。
- _無彩色(neutral colors)_: グレーや彩度の低い色を重視します。この設定は、安価な蛍光灯やLED照明のような演色性が低い照明など、極端な場合に有用です。ですが、この設定で得られる値を使うと、彩度の高い色について、何もしない場合よりもさらに大きくずれる場合があります。
- _飽和色(saturated colors)_: 原色や彩度の高い色を重視します。この設定は、製品の写真や商業的な写真のような場合に有効です。ブランドカラーを正しく合わせることができます。
- _肌や土の色(skin and soil colors)_ 、 _葉の色(foliage colors)_ 、 _空や水の色(sky and water colors)_: ある特定の色相の範囲を重視します。この設定は、被写体となる対象がはっきり決まっており、また被写体に特定の色調があるような場合に有効です。
- _平均デルタE(average delta E)_: すべての色についてなるべく色のずれ度合いを均一にして、知覚的な色のずれの平均値を最小化しようとします。これは一般的に使える設定です。
- _最大デルタE(maximum delta E)_: 色のずれの平均値を少々犠牲にして、大きなずれや孤立値をなるべく減らそうとします。この設定は、彩度の高い青をなるべく再現しようとする場合に有効な場合があります。

どのように設定しても、平均 ΔE を小さくしようとする戦略では通常最大 ΔE は大きくなりますし、その逆も成り立ちます。また、青は最も補正が難しい色ですので、通常、ほかの色を少々犠牲にしても青の再現を保とうとするか、あるいは青を犠牲にして他のすべての色を再現しようとするか、結局はこのいずれかになります。

なるべく楽によい値を得るためには、撮影時の光源の品質（常に、昼光で演色性が高い光源が望ましいです）、最初の _入力カラープロファイル(input color profile)_ の品質、 _露光(exposure)_ モジュールで設定した _黒レベル補正(black point compensation)_ などが関係しますが、まず最初に最も重要になるのは、カメラのセンサーのフィルターアレイの数学的性質です。

## プロファイルの確認

_色空間チェック(color space check)_ ボタン（モジュール最下部のボタンの一番左）を使うと、 _カラー較正_ モジュールの出力とカラーチェッカーの基準値の ΔE がどの程度になるか、これだけを単独で計算することができます。これは以下のような目的で使うことができます。

1. 特定の条件で計算された「プロファイル」が、別の条件でカラーチャートを撮影した画像に対してどの程度正確なのかを確認する場合。
2. ピクセルパイプラインのより前の段階でなされている色の補正がどの程度よいかを評価する場合。まず _カラー較正_ が実質的に無効化される設定を行い（CAT  _順応(adaptation)_ を _なし(none)_ にして、それ以外の設定はすべてデフォルト値）、平均 ΔE がどの程度よくなっているかを調べます。

# 警告

光源の色を設定する際に、CCTを使う方法や標準のCIE光源を使えるというのは、 _カラープロファイル入力(input color profile)_ モジュールでの標準行列の正常なデフォルト値、 _ホワイトバランス(white balance)_ モジュールでの妥当なRGB係数に依存しています。

一部のカメラでは、特にオリンパスやソニーのものですが、ホワイトバランス係数が想定外のものになっていて、撮影シーンで本当に昼光光源を使っている場合でさえも、いつでも検出されたCCT値が「無効」になってしまいます。この問題は多くの場合、Adobe DNG Converterから取られた標準の入力行列の問題によるものです。

D65光源に対して較正されているモニタがあれば、次のような手順でこの問題の影響を軽減することもできます。

1. モニタを白一色の表示にします。例えばお好みの画像編集ソフトで何もないキャンバスを表示するなど。
2. お使いのカメラで、その画面をピンボケの状態で撮影します。よけいな光源がフレームに入っていないこと、クリッピングがないことを確認してください。絞り値はf/5.6からf/8の間を使ってください。
3. 撮影された画像をdarktableで開き、 _ホワイトバランス_ モジュールのスポイトツールを画像の中心部で（中心部以外では色収差の影響を受ける場合があります）使って、ホワイトバランスを設定してください。この操作で、3つのRGB係数が生成されます。
4. _ホワイトバランス_ モジュールでこの係数について [プリセットとして保存(Save a preset)](../../darkroom/processing-modules/presets.md#creating-and-editing-presets) し、同じカメラで撮影したカラーのRAW画像では必ずこのプリセットが自動適用されるように設定します。