---
title: demosaic
id: demoasic
applicable-version: 3.8
tags: 
working-color-space: Not Applicable (RAW) 
view: darkroom
masking: false
---

RAWファイルのデモザイク処理を設定します。

# ベイヤーフィルター

デジタルカメラのセンサーセルというものは、そもそも色に反応はしません。単に、光の強さのレベルを記録することができるだけです。そこでカラー画像を得るために、それぞれのセンサーセルに特定の色（赤、緑、青）の光だけを通すカラーフィルターをつけてあります。つまり、RAW画像のそれぞれのピクセルが持っている情報は、単一の色に関するものだけということになります。

カラーフィルターは通常、ベイヤーフィルター配置として知られるモザイク状のパターンで配列されています。デモザイクアルゴリズムによって、周辺のピクセルのデータから補間されて不足している色の情報が再構成されます。さらに詳しく知りたい場合、Wikipediaの [demosaicing](https://en.wikipedia.org/wiki/Demosaicing) や [Bayer filter](http://en.wikipedia.org/wiki/Bayer_filter) のページを参考にしてください。

darktableでは、複数のデモザイクアルゴリズムが用意されており、それぞれ個別の特徴があります。多くの場合違いはとても微妙で、ピクセルごとにチェックして初めてわかるような場合もあります。しかし、darktableの処理はピクセル単位で行われますし、デモザイクの結果はその他のモジュールで処理するための元データとなりますので、アルゴリズムの選択によっては、最終的な画像の細かいディテールなどではっきり目につくような違いが出てくる場合があります。たとえば、迷路のようなパターンが発生するとか、色の境界がきれいに出なかったりするとか、そういうようなことです。

デモザイク補間アルゴリズムはよく歪み（存在しないはずの構造）を生み出すことがあります。画像を拡大したときに [モアレ(Moiré patterns)](https://en.wikipedia.org/wiki/Moire_pattern) が目につく、などが典型的なものです。選択したアルゴリズムによっては、RAWデータに _もともと存在する_ モアレや迷路状パターンの対処がより良くなったり、あるいは悪くなったりするかもしれません。このような場合は、 _VNG4_ や _LMMSE_ がより安定して結果を出すことも多いです。

ベイヤーフィルターのセンサーに対しては、以下のアルゴリズムを使うことができます。

- _PPG_ は以前デモザイクアルゴリズムのデフォルトでした。これは高速ですが、他のアルゴリズムのほうがだいたい良い結果を得られます。

- _AMaZE_ と _RCD_ では高周波領域（細かいディテール、境界、星など）でより良い再構成結果が得られますが、色の再構成が行き過ぎたり、コントラストの低い領域でノイズが増えたりすることがあります。 _AMaZE_ は通常高周波のディテールをよく保ちますが、 _RCD_ よりも色再構成の行き過ぎが起きやすいです。 _RCD_ は現状で _PPG_ と同等の処理速度がありますが、より良い結果が得られますので、現在ではこれがデフォルトのアルゴリズムとなっています。

- _LMMSE_ は、高ISOでノイズの多い画像の場合に、歪みを生じやすい _AMaZE_ や _RCD_ より適しています。また、他のアルゴリズムではモアレが出てしまうような画像に対して、LMMSEでうまく処理できる場合があります。

- _VNG4_ は低周波領域（空のような、コントラストの低い領域）により適していますが、 _AMaZE_ や _RCD_ と比べると、高周波ディテールがいくぶん失なわれることが多く、色ずれが起きる場合もあります。実際のところ、もはやVNGの利用はおすすめしません。ほとんどの画像に対して、通常は他のアルゴリズムのほうがよい結果を生みます。

---

**注意：** デモザイクアルゴリズムの処理速度はものによって大きく異なり、特に _AMaZE_ は他のものよりもずっと遅いです。

---

# ベイヤーフィルターではないセンサーについて

ベイヤーフィルターを使っていないセンサーのカメラもいくらか存在します。「X-Trans」センサーのカメラには、固有のデモザイクアルゴリズムがあります。X-Transセンサーに対するデフォルトのアルゴリズムは _Markesteijn 1-pass_ であり、これはなかなか良い結果を出します。さらに多少良い品質を（処理速度を犠牲にして）求めるなら、 _Markesteijn 3-pass_ を選択してください。コンピューターによっては _VNG_ が _Markesteijn 1-pass_ より高速な場合がありますが、歪みは出やすくなります。

# 特殊なアルゴリズム

_passthrough (monochrome)_ は、カラーフィルターが物理的に除去された（引っ剥がすなどして）カメラを使う場合にのみ意味があります。デモザイクアルゴリズムは通常、不足している色の情報を周辺のピクセルのデータから補間することで再構成します。しかし、カラーフィルターが存在しないのならば、補間するようなものはありません。そこで、このアルゴリズムは単純に全ての色チャンネルを同一として、モノクロの画像を出力します。この方法は、通常のデモザイクアルゴリズムで生じる可能性がある、補間による歪みを避けることができます。

_photosite color_ は画像処理に使うためのものではありません。これは生のフォトサイト（訳注：個々のセンサーの受光部）のデータを受けとって、単純に赤・青・緑のピクセルとして出力するものです。これはデバッグ用の処理で、生のデータを確認して、（これ以外の）デモザイクアルゴリズムによって起こるエラーを分析する助けにするためのものです。

# 複合デモザイクアルゴリズム

画像によっては、高周波情報をよく保存するアルゴリズム（ _AMaZE_ や _RCD_ など）でデモザイクしたほうがよい領域と、低周波情報により適したアルゴリズム（ _VNG4_ など）のほうが合っている領域と、両方が含まれる場合があります。

複合デモザイクアルゴリズム（例えば _RCD + VNG4_ ）では、センサーデータのデモザイク処理が二回なされます。まず _RCD_ や _AMaZE_ や _Markesteijn 3-pass_ を実行し、それから _VNG4_ です。両方のパターンのデモザイク済みデータが保持され、それ以降の処理で使われます。

それから高周波アルゴリズムの結果のほうが「 _ローカルデータチェンジ_ 」（訳注：下を参照）のために解析され、 一定の閾値に応じて（実際にはここでもう少しいろいろな数学的処理もなされます）、ローカルデータチェンジによって二つのデモザイクアルゴリズムの結果に対する重みが決められ、最終的な画像がピクセルごとに各色チャンネルについて出力されます。

一般的には、ディテールがたくさんある領域のほうはそのような目的に適したアルゴリズム（ _RCD, AMaZe, Markesteijn 3-pass_ ）でデモザイクが行なわれ、一様な領域（青空など）は二番目のアルゴリズム（ _VNG4_ ）でデモザイクが行われます。

_「ローカルデータチェンジ」(local data change) は、技術的にはガウシアンぼかしをかけた単一チャンネルの選択マスクとして実装されており、閾値とピクセルごとの輝度を組み合わせて計算されています。_

## 閾値の設定

閾値の自動計算は実装が困難です。かわりに、「ブレンドマスクを表示」(display blending mask)ボタンがありますので、 _選択マスク_ を表示して、どちらのアルゴリズムが適用されるか手動で調整することができます。表示されたマスクが明るいピクセルほど、最終的な出力は高周波向けアルゴリズムから取られるようになります。

# モジュールの操作

手法(method)
: 利用するデモザイクアルゴリズムです（上述）。

境界閾値（ _PPG_ のみ）(edge threshold)
: 追加のメジアンフィルタの閾値です。デフォルト値の0では、このメジアンフィルタは無効になります。

lmmse精緻化（ _LMMSE_ のみ）(lmmse refine)
: LMMSEアルゴリズムを使う場合の、結果を改善するための微調整ステップです。「メディアン」ステップでは、出力を平均化します。精緻化ステップでは、赤と青のチャンネルに対して多少の再計算を行います。この設定は色ノイズがある場合も使えますが、色ノイズが激しい場合は出力画像が劣化する可能性があります。

色スムージング(color smoothing)
: 追加でいくつか色のスムージングを行います。デフォルトは「オフ」です。

緑色の均等化(match greens)
: 一部のカメラでは、緑フィルタの特性が若干異なっています。この設定は、追加の均等化を行い歪みを減らします。選択肢としては「無効」(disabled)、「局所平均」(local average)、「全体平均」(full average)、「全体・局所平均」(full and local average)があります。この設定は、X-Transセンサーの場合は表示されません。

複合切り替え閾値 _（複合アルゴリズムモードのみ）_ (switch dual threshold)
: 複合デモザイクモードでの、輝度の閾値を設定します。低く設定すると高周波デモザイクアルゴリズムが優先され、高くすると低周波アルゴリズムが優先されます。

ブレンドマスク表示 _(複合アルゴリズムモードのみ)_ (display blending mask)
: 高周波・低周波領域を区別するために使われるブレンドマスク（「複合切り替え閾値」で設定されます）を表示します。各ピクセルについて、明るく表示されているほど、最終的な出力が高周波向けアルゴリズムから取られるようになります。
