---
title: diffuse or sharpen
id: diffuse
applicable-version: 3.8
tags:
working-color-space: RGB
view: darkroom
masking: true
---

「拡散」（diffusion）とは、粒子が動くことで時間がたつにつれて発生源から徐々に広がっていくような物理的プロセスのことです（訳注：拡散としていますが、日本語では光の「散乱」と書く現象も英語ではdiffusionと呼びます）。画像処理の分野では、拡散は主に以下のふたつの場面で発生します。

- レンズのガラス（ぼけを生じる）や湿度の高い空気（かすみを生じる）による光子の拡散（散乱）
- 乾いていないインクや水彩の中での、顔料の拡散

どちらの場合でも、拡散によって粒子が周囲に「漏れ出て」局所的な変化を弱めることで、画像のシャープさが低下します。

_拡散/シャープ化（diffuse or sharpen）_ モジュールは、いろいろな拡散を表現できる一般化された物理モデルを使っており、また、拡散が進むことと元に戻ることの両方を仮想的に起こすために使うことができます（拡散によって起こる効果を追加することも、起きた結果を消すこともできます）。

これは非常に技術的なモジュールですので、各種目的に対してどのように使えるかを示すため、いくつかプリセットが用意されています。

以下のような目的で、拡散（による影響）をなくすことができます。

- recover the original image from sensors with an anti-aliasing filter or mitigate the blur created by most demosaicing algorithms (use the _sharpen sensor demosaicing_ preset and move the module before the _input color profile_ module in the pipeline),
- センサーとアンチエイリアスフィルターだけから得られる元々の画像に戻す、あるいは、ほとんどのデモザイク方法で発生するぼけを軽減する（この場合 _デモザイク効果のシャープ化（sharpen sensor demosaicing）_ というプリセットを使い、このモジュールが _入力カラープロファイル（input color profile）_ モジュールよりピクセルパイプライン中で前に来るように動かしてください）
- レンズ固有のぼけを補正する（ _レンズぼけ補正（lens deblur）_ プリセット）
- 空気の影響によるかすみを除去する（ _かすみ除去（dehaze）_ プリセット）
- 画像を見やすくするため、鮮明にする（ _ローカルコントラスト（local contrast）_ プリセット）

なお、いわゆる被写体ぶれ（動いていることが原因のぶれ）は「拡散を元に戻す」処理で補正することはできません。これはそもそも拡散現象ではないからです。

以下のような目的で、拡散（による影響）を追加することができます。

- ブルームやオートン効果（輝きとやわらかい雰囲気を加える）を作り出す（ _ブルーム（bloom）_ プリセット）
- 画像の中の、色が欠落していたり正常でなかったりする部分を回復する（ _ハイライト塗りなおし（inpaint highlights）_ プリセット）
- 境界を保ったままノイズを除去する（ _ノイズ除去（denoise）_ プリセットのいずれか）
- サーフェスブラー効果（表面をなめらかにする）を加える（ _サーフェスブラー（surface blur）_ プリセット）

このプロセスは物理的なものですので、結果がおかしくなる場合でさえも創造的な目的に使うことができる場合があります。例えば、

- 線画や水彩画のような効果を出す（ _線画（simulate line drawing）_ や _水彩画（simulate watercolor）_ プリセット）
- ノイズを増やすことで、ランダムなパターンや質感を作り出す（処理を繰り返すことで、ノイズが周囲のピクセルと影響しランダムな点が発生します）

---

**注意：** このモジュールは、実際には異方性多重スケール偏微分方程式を解くという、非常に重い処理を行っています。繰り返し回数が増えるとさらに実行時間が長くなりますので、OpenCLの利用を強くおすすめします。OpenCLが使えないシステム向けには、「高速」（fast）プリセットもいくつか用意されています。

---

# 基本概念

## 時間

拡散とは、時間とともに進行する過程です。時間が経過するほど、粒子が遠くまで進む可能性があります。このモジュールでは、処理の繰り返し回数（自分自身に対してアルゴリズムが適用される回数）が「時間」に相当します。適切に設定されていれば、繰り返し回数が増えるほど情報の再構成（ぼけの除去、ノイズ除去、かすみ除去）が正確になる可能性がありますが、逆に結果が悪くなる場合もあります。

## 方向

現実の拡散現象は、通常、ポテンシャルの高い（エネルギーや粒子の密度が高い）位置から低い（エネルギーや粒子の密度が低い）位置に向かって発生します。画像においては、これは「拡散は常に最も明るいピクセルから最も暗いピクセルに向かって発生する」ということを意味します。

このモジュールの実装では、等方性の拡散（熱の拡散のように、どの方向へも同様に拡散する）を使うことで、現実の拡散と同様の現象を仮想的に再現することもできます。ですが、強制的に勾配（輝度の変化する方向）と平行な方向へ拡散しやすくする（対象の境界に向かって拡散し、「ゴースト」境界を作り出す）こともできますし、勾配と直角な方向（等輝度線と呼ばれます。輝度が変わらない方向です）へ拡散しやすくすることもできます（水彩画の一滴の中のように、境界の内部にとどまる方向に拡散しやすくする）。各方向（勾配方向、等輝度方向）への相対的な重みはユーザーが設定可能で、このモジュールの [_拡散の指向性（diffusion directionality）_](#diffusion-directionality) という部分にあります。

## 速さ

環境にどの程度流動性があるかによって、粒子がどの程度自由に動けるかが決まり、そしてどの程度速く動けるかが決まります。拡散の速さは、このモジュールの [_拡散の速さ（diffusion speed）_](#diffusion-speed) という部分で設定できます。

情報の再構築（ノイズ除去、ぼけ除去、かすみ除去）を行う場合、精度を上げるには、速さの設定を小さい値にすることをおすすめします。そうすることで行きすぎ（そして結果の劣化）を防ぎますが、必要な繰り返し回数は増えるかもしれません。繰り返し回数を少なくすませるためには、速さを大きくすることもできます。また、強いぼけを適切に処理するためには繰り返しを多くする必要があるので、そのような場合は結果が劣化しないように速さも調整する必要があることに注意してください。

速さの設定はすべて加算されます（1次から4次のオーダーについて）。さらに、「`1次 + 2次`」と「`3次 + 4次`」の和は±100%を越えないようにする必要があります。 [グリッチアート](https://ja.wikipedia.org/wiki/%E3%82%B0%E3%83%AA%E3%83%83%E3%83%81%E3%82%A2%E3%83%BC%E3%83%88) 的なことをするのでなければ。

## scale
## スケール

自然な拡散現象の場合、最も近い座標との間でのみ起こると想定されています。すなわち、各段階において、各ピクセルはその最近傍の9つのピクセルとだけ作用します。

ここで、ちょっと早回しして時間を節約するため、 [_コントラストイコライザー（contrast equalizer）_](./contrast-equalizer.md) モジュールの多重スケールウェーブレットの仕組みを再利用して、拡散を様々なスケール（距離）において発生させることができます。拡散の起きる最大スケールは、 _拡散半径の範囲（radius span）_ パラメータで設定できます。

どのような拡散の場合でも、 _シャープネス（sharpness）_ パラメータで各スケールのディテールを増大させたり減少させたりできます。 _コントラストイコライザー（contrast equalizer）_ のスプライン曲線のような感じです。 _境界の感度（edge sensitivity）_ 設定とあわせることで、このパラメータは _コントラストイコライザー_ （の _輝度（luma）_ や _境界（edges）_ タブ）と同様の機能を実現しますが、こちらはシーン参照RGB空間で動作する点が違います。

# モジュールの操作

## 拡散の特性

繰り返し回数
: 処理アルゴリズムが繰り返し適用される回数を指定します。大きな値にするほどモジュールの処理は遅くなりますが、拡散の速さが十分低ければ情報の再構成がより正確になります。

拡散半径（中心値）（central radius）
: 拡散の主なスケール（距離）の大きさを指定します。ゼロであれば、拡散が主に細かいディテールについて発生するようになります（ぼけ補正やノイズ除去で使います。訳注：「主にすぐ隣のピクセルとだけ作用する」状態になる、という意味だと思います）。ゼロ以外の値であれば、拡散が主に発生するディテールの大きさが設定されることになります（ローカルコントラスト強化で使います）。

拡散半径の範囲（radius span）
: この値を設定すると、「拡散半径（中心値）」の周囲の値、ある程度の範囲のスケールのディテールに対しても拡散が起こるよう指定できます。この「範囲」は、ディテールのスケールの範囲を定義し（`「中心値」 - 「範囲」` から `「中心値」 + 「範囲」` まで）、その範囲内のスケールでは拡散が起こるようになります。大きな値にするほど広範囲のスケールで拡散が起こるようになりますが、そのかわり処理時間は長くなります。小さい値では、「中心値」に近いスケールでだけ拡散が発生するようになります。ぼけの補正をする場合、この範囲はだいたいお使いのレンズのレンズぼけの幅程度に、「中心値」はゼロに設定する必要があります。シャープネスやノイズには影響を与えずにローカルコントラストを強化するつもりの場合は、この範囲は最大でも「中心値」の3/4までにする必要があります。

ここで言う「拡散半径」（拡散の起こる距離）は、画像を等倍で表示したときのピクセル数で表現されますので、解像度が異なる画像の間で設定をコピーペーストすると、結果がすこし異なる場合があります（ピクセル単位でのシャープネスは除く）。

電気関係の技術者向けに言うと、ここで設定されるのはウェーブレット空間でのバンドパスフィルターで、 `「中心値」` を中心として `「範囲」` のあたり（標準偏差）で減衰するガウシアン型窓関数を使う、ということです。ウェーブレットスケールというのは各高調波（倍音）のようなもので、それぞれのウェーブレットスケールによって処理が行なわれるディテールの半径が決まります。

## 拡散の速さ

（訳注：「低周波数」「高周波数」と言っているのは、おおむね「粗い形状」「細かい形状」と同じような意味です。）

1次の速さ（勾配）（1st order speed (gradient)）
: 低周波数のウェーブレットレイヤーにおける、 _1次の異方性（1st order anisotropy）_ で設定された方向への、拡散の速さを決めます。正の値は拡散を進行させ、負の値は拡散を元に戻し、ゼロでは何も起きなくなります。

2次の速さ（ラプラシアン）（2nd order speed (laplacian)）
: 低周波数のウェーブレットレイヤーにおける、 _2次の異方性（2nd order anisotropy）_ で設定された方向への、拡散の速さを決めます。正の値は拡散を進行させ、負の値は拡散を元に戻し、ゼロでは何も起きなくなります。

3次の速さ（ラプラシアンの勾配）（3rd order speed (gradient of laplacian)）
: 高周波数のウェーブレットレイヤーにおける、 _3次の異方性（3rd order anisotropy）_ で設定された方向への、拡散の速さを決めます。正の値は拡散を進行させ、負の値は拡散を元に戻し、ゼロでは何も起きなくなります。

4次の速さ（ラプラシアンのラプラシアン）（4th order speed (laplacian of laplacian)）
: 高周波数のウェーブレットレイヤーにおける、 _4次の異方性（4th order anisotropy）_ で設定された方向への、拡散の速さを決めます。正の値は拡散を進行させ、負の値は拡散を元に戻し、ゼロでは何も起きなくなります。

## 拡散の指向性

1次の異方性（1st order anisotropy）
: 低周波数のウェーブレットレイヤーにおける、低周波数の勾配に対する拡散の方向を決めます。ゼロでは等方的（全方向で同じ）に、負の値ではより勾配に沿う方向に、正の値ではより等輝度線に沿う方向に拡散が起きます。

2次の異方性（2nd order anisotropy）
: 低周波数のウェーブレットレイヤーにおける、高周波数の勾配に対する拡散の方向を決めます。ゼロでは等方的（全方向で同じ）に、負の値ではより勾配に沿う方向に、正の値ではより等輝度線に沿う方向に拡散が起きます。

3次の異方性（3rd order anisotropy）
: 高周波数のウェーブレットレイヤーにおける、低周波数の勾配に対する拡散の方向を決めます。ゼロでは等方的（全方向で同じ）に、負の値ではより勾配に沿う方向に、正の値ではより等輝度線に沿う方向に拡散が起きます。

4次の異方性（4rd order anisotropy）
: 高周波数のウェーブレットレイヤーにおける、高周波数の勾配に対する拡散の方向を決めます。ゼロでは等方的（全方向で同じ）に、負の値ではより勾配に沿う方向に、正の値ではより等輝度線に沿う方向に拡散が起きます。

## 境界の取り扱い

シャープネス（sharpness）
: 拡散の性質にかかわらず、ウェーブレットのディテールを増幅します。正の値では境界がシャープに、負の値では境界をぼかし、ゼロでは何も起きません。これは、ブルームやぼかしを加える操作をしているとき、ある程度のシャープさを残しつつ境界のまわりに輝きを追加したい場合の調整に一番役立ちます。この設定ではハローや偽色帯を防ぐことはできませんので、単にシャープ化するためだけに使うのはおすすめしません。

境界の感度（edge sensitivity）
: 境界が検出された場合に、拡散の速さに制限を設けます。なお境界の検出には、各ピクセルの周囲の局所分散を用います。ゼロはこの制限をなくし、大きい値にするほど制限が強く、拡散が境界に強く影響されるようになります。境界の周囲に偽色帯やハローなどの異常が見られる場合、この値を大きくしてください。

境界の閾値（edge threshold）
: 境界を検出する、分散の閾値を設定します。この設定は主に分散の低い領域（暗い領域、ぼやけた領域、凹凸のない表面など）に影響します。正の値は、低分散領域での制限を強くします。黒つぶれが起きないようにシャープ化する、あるいはローカルコントラストを強化する場合に向いています。負の値は、低分散領域での制限を下げます。こちらは黒い／ぼやけた領域で最大の効果を発揮するようにノイズを除去する、あるいはぼかしを加える場合に向いています。

## 拡散の空間分布

輝度マスク閾値（luminance masking threshold）
: この設定は、ハイライト部分の色を回復する処理の場合に便利です。0%より大きい値を設定すると、設定値より高い輝度の領域でのみ拡散が発生するようになります。なお、仮想的な「粒子」を配置して（拡散による）色つけを開始するために、対象領域にはまずガウシアンノイズが加えられます。

# 作業の流れ

このモジュールを使う上での主な問題は、入力パラメータの設定によって出力結果が大きく変化するにもかかわらず、それぞれのパラメータの意味は日常生活と直感的に結びつかない（日常生活にあるものにあてはめて理解することができない）、ということです。ユーザーとしては、もともとフーリエ偏微分方程式に馴染みがあるのでもなければ、圧倒されてしまうことと思います。この節では、「背後の理論を理解する」という重荷を背負わずともすむ形でこのモジュールを使う方法を、いくつか説明します。

## 一般的な指針

このモジュールで画像のぼけやブレを除去したいという場合は、まず最初に画像の色収差やノイズを補正してください。ぼけの除去処理はそのような異常を大きくする場合があるからです。また、画像で黒がクリップされていない（もともと負の値になっているようなピクセルが存在しない）ようにすることも重要です。この点については、 [_露光（exposure）_](./exposure.md) モジュールの _黒レベル補正（black level correction）_ で補正できます。

このモジュールはRGBチャンネルそれぞれに対して動作しますので、 [_カラー較正（color calibration）_](./color-calibration.md) より後で実行し、中立的ででホワイトバランスが補正された画像が入力となるようにしたほうがよいです。なお、ローカルコントラストやシャープネスを上げると、色のコントラストや彩度も多少上がりますが、通常これはよい結果を生みます。また、このモジュールでは境界を検出するために分散による正則化を使いますので、このモジュールは非線形の操作よりも（ピクセルパイプライン中で）前に置くことが望ましいです。

## プリセットから始める

最初から用意されているプリセットは、開発チームによって調整され、典型的な目的に対して種々の画像を用いてテストされています。このモジュールの一番簡単な使いかたは、このようなプリセットから始めて、必要に応じて調整することです。

- 効果が強すぎるようであれば、繰り返し回数（iterations）を減らします。
- 境界に異常が見られるならば、境界の感度（edge sensitivity）を上げます。
- ぼけの除去が「必要なぼけ」の部分にまで及んでいるようであれば、拡散半径（radius）を小さくします。
- ぼけの除去が明るい部分ではうまくいくのに暗い部分で効きすぎているようであれば、境界の _閾値（threshold）_ を上げます。
- ぼけの除去によって黒いピクセルがクリップされる場合は、 _露光（exposure）_ モジュールで _黒レベル補正（black level correction）_ を下げます。
- _シャープネス（sharpness）_ の設定をお好みにあわせて微調整します。

## いちから始める

（訳注：もう一度書いておきますが、「低周波数」「高周波数」と言っているのは、おおむね「粗い形状」「細かい形状」と同じような意味です。）

このモジュールのデフォルト設定は完全に中立で、画像に対して何の処理も行いません。このモジュールのポイントは、それぞれの次数における処理が、画像の質感に対してそれぞれ独特の方法で影響する、ということです。

まず、基本の処理を行うために1次のパラメータ（速さと異方性（speed、anisotropy））を調整してください。それから、半径（radius）を設定します。この設定は粗めの質感に影響を与えます（ぼかすにしろシャープにするにしろ）。1次の処理は、ウェーブレットの低周波数のスケールに働き、低周波数の勾配に対して平行あるいは直角の方向に作用する、ということを覚えておいてください。

次に、2次のパラメータ（速さと異方性）の調整をはじめます。2次の処理も低周波数のウェーブレットスケールに対して働きますが、こちらは _高_ 周波数の勾配に対して平行あるいは直角の方向に作用します。それぞれ、最大のシャープネスあるいはノイズに向かう方向となります。この処理は、1次の処理をシャープ化に（負の値で）使った場合、ノイズ削減のために（2次の処理を拡散を進める方向に、正の値で）使うことができます。

ここまでの2つの段階は、ズームアウトした画像で（全体が見える状態で）設定することができます。処理アルゴリズムは最大限の注意を払って作成されており、結果がズーム段階にあまり依存せず見えるようにしてはありますが、プレビューが本当に正確であるのは1:1のズーム（等倍表示）のときだけです。どのような場合でも、ピクセルレベルで（半径2px未満で）起きるようなことは、50%より低いズームレベルでは確認できなくなります。

ここまで来たら、境界の異常を調整するために境界の感度を調整する必要があるかもしれません。理論的には、そもそも等輝度方向への拡散であれば、境界の内側でだけ拡散が進むよう制限されるはずなのですが、画像の中に角や鋭く突き出た形状がある場合、その制限だけでは十分ではありません。

境界の感度を調整して十分な結果が得られる状態にした時点では、通常、画像はわりとソフトな（くっきりしていない）感じになると思います。ほとんどの場合、ここで繰り返し回数の値を増やして、補正することが必要になります。この操作は重い処理ですので、お使いの機材における処理時間と品質のトレードオフを検討しつつ慎重に進めてください。もし必要なだけ繰り返し回数を増やせないのならば、拡散の速さを大きくする必要があります。

最後は、3次と4次の微調整を行い、各ウェーブレットスケールにおける高周波数成分の調整をします。ここの設定は、油断するとあっという間にノイズが拡大してしまいますので、1次や2次の設定よりさらにずっと慎重に調整する必要があります。

3次の設定は、低周波数レイヤーでの勾配あるいは等輝度線に沿って働きます。そこでこの設定は、高周波数での拡散が「実際の境界を考慮したとき、より正当な」方向に進むよう調整するために使うことができます（またノイズの影響を受けにくいです）。

4次の設定は、高周波数レイヤーでの勾配あるいは等輝度線に沿って働き、よりノイズの影響を受けやすいです。4次の拡散は、シャープネスにあまり影響を与えずにノイズを削減する最もよい方法で、単独のノイズ削減処理としても、ぼけ除去処理の調整としても有効です。

# 画像情報の再構築に複数のインスタンスを使う

ノイズの後処理では、拡散プロセスを **追加する** ことが役に立つ場合があります。これは [_ノイズ削減（プロファイル）（denoise (profiled)）_](./denoise-profiled.md) モジュールより後の、追加の処理として加えることもできます。

逆に、以下のような光学的な問題に対応するには、拡散プロセスを **元に戻す** ことで役に立つ場合があります。

1. センサーのローパスフィルター（LPF）や [_デモザイク（demosaic）_](./demosaic.md) モジュールによるアンチエイリアスなどによって生じるぼけ
2. レンズ固有のぼけ
3. かすみや霧
4. 光の散乱（大きすぎるディフューザーを使った場合など）、それによって生じる均質な照明と被写体ローカルコントラストの喪失

こうした問題が、ひとつの画像で複数同時に発生することもありますので、モジュールのインスタンスを複数用意して個別に対応するほうがよい場合があります。その場合、粗いスケールから細かいスケールの順で補正が実行され、またノイズ除去が必ず最初に行われるようにしてください。すなわち、インスタンスの [ピクセルパイプライン中の順序（pipe order）](../../darkroom/pixelpipe/the-pixelpipe-and-module-order.md) が以下のようになっていなければなりません。

1. ノイズ除去
2. ローカルコントラスト強化
3. かすみ除去
4. レンズ固有のぼけの補正
5. センサーとデモザイク処理の補正

粗いスケールの情報再構成から始めることで、細かいスケールでの再構成のときにノイズが入ったり強くなったりする可能性を下げることができます。画像を（RAWデータから）生成するときにはこのような順にはなりませんので、少々直観に反しています。ご注意ください。同様の理由で、ノイズ除去は必ず、いかなるシャープ化やアキュータンス（先鋭度）増加操作よりも前に来るようにしてください。

# 使用上の注意

このモジュールの効果はスケールに関係ないように作られてはいますが、確実な出力が得られるのは100%かそれ以上のズームレベルのとき、あるいはサイズそのままでエクスポートしたときだけです。より低いズームレベルで見たときやより低い解像度でエクスポートしたときには、出力結果は予想通りになるかもしれませんし、そうでないかもしれません。

ぼけを除去するように設定するときには、「歴史上最もすばらしい写真というものは、だいたいは現在のものと比べてはるかにシャープでないレンズを使って撮影されている」という事実を常に意識するようにしてください。現在の傾向としては、ますますシャープなレンズを製造・販売してその上ソフトウェア的にも信じがたい量のシャープ化をかけるということになっていますが、このような流儀はよりよい写真を得ることにはつながり _ません_ し、レタッチ処理はめんどうになるばかりです。また、やわらかなフォーカスや多少ぼんやりした様子には、いくらか詩的なよさというものがありますし、それは完璧で劣化のないHD画像では伝わらないものかもしれません。

また、全体のコントラスト（単純なトーンカーブや黒/白レベル設定で得られるもの）もまた、「シャープさ」を感じる度合いに影響を与えますが、これは光学的なシャープさ（光学的な解像力）とは全く違ったものである、という点にも注意する必要があります。人間の視覚は単にローカルコントラストに反応するだけなのですが、それは光学的シャープさ（例えば光の散乱がなく、境界が細いとか）が原因の場合も、また色調の変化が強調されたことが原因の場合もあります。コントラストを上げるために何かのグローバルトーンマップを使えば、画像はより「シャープに」見えます。コントラストを下げるためにトーンマップを使えば、画像は「ぼんやりして」見えます。このどちらの場合においても、被写体の境界は実際にはいかなる意味でも何も変わっておらず、違って見えるというのは単なる気のせいなのです。

人は加齢によっていろいろな影響を受けますが、その中には視覚の減衰もあります。50歳以上の人がちょうどよいと感じるシャープ化の量は、20代のときと同じとは限りません。シャープ化によって _好ましい_ 結果を得るのではなく（いいと思えるのは設定者と同等の視覚の人だけかもしれません）、 _もっともらしい_ 結果を得る（ふだん物を見ている感じに合わせる）ということを頭におくとよいかもしれません。

最後にもうひとつ。シャープさを等倍（100%）かそれ以上にズームしてチェックする、というのは馬鹿げたことです。美術館でも、展示会でも、画面の上でさえも、観客はふつう写真を全体として見るのであって、虫眼鏡を使って見るわけではありません。さらに言えば、実際に使われる場面ではほとんど、写真の解像度が3000x2000ピクセル（だいたい300DPIでA4にプリントする程度）を越えることはありません。つまり、24メガピクセルセンサーの機種であれば、4の倍数でダウンスケールすることになります。24メガピクセルのファイルを等倍で確認するというのは、実際には存在する機会がないような画像を見ていることになるのです。この意味で、ピクセルレベルでシャープ化をするというのは、時間とCPU処理の無駄にすぎません。
