---
title: filmic rgb
id: filmic-rgb
applicable-version: 3.6
tags:
working-color-space: RGB
view: darkroom
masking: true
include_toc: true
---
銀塩フィルムの階調と色特性を再現する形で、画像の色調の範囲を変換します。

このモジュールでは、撮影シーンのダイナミックレンジをディスプレイのダイナミックレンジに対応させるにあたり、ダイナミックレンジを広げることも、圧縮することも可能です。このモジュールは中間トーンの色やコントラストを保ち、陰影を復元し、ハイライト部分や暗い部分を圧縮します。ハイライトについては、ディテールを保ちたい場合（雲など）には十分な注意が必要です。

このモジュールは、T. J. Sobotkaによる [Blender 3D](https://www.blender.org/) の同名のモジュールに由来しています。元々は生のセンサー値の高いダイナミックレンジを復元する目的で作られましたが、 [_ベースカーブ(base curve)_](./base-curve.md) モジュールの置き換えとしてどんな画像に対しても使えます。以下の動画は、このモジュールの作者による詳しい説明です（訳注：英語です）。 [フィルミックRGB：darktable 3.0におけるダイナミックレンジのマッピング](https://www.youtube.com/watch?v=zbPj_TqTF880)

_フィルミックRGB(filmic rgb)_ はdarktable 2.6にあった _フィルミック(filmic)_ モジュールの後継です。基本的な原理はそれほど変わっていませんが、デフォルト値や想定している条件には違いがあります。ですので、旧バージョンを使っていた人は、これまでのワークフローと1対1の対応がつくわけではないことにご注意ください。

---

**注意**： このモジュールは非常に専門的に見えるかもしれませんが、これを操作するときの最善の方法は、目で見て結果を確認しながら進めることです。効果を調整するときに画面に表示されている数値自体には、あまりとらわれすぎないようにしてください。

---

# 前提条件

フィルミックRGBを最大限に活用するため、画像に対して多少の準備が必要です。

撮影（ETTR）
: カメラ内の設定では、「露出を右へ」（ETTR、Expose To The Right）と呼ばれる方法をおすすめします。これは、露出を設定するにあたって、ハイライト部分がヒストグラムの右端に、白飛びしないぎりぎりのところにくるようにする、ということです。これが "Expose To The Right" と呼ばれるのは、カメラのヒストグラム表示が右端についていて、かつ右側でピークになっていない（この場合クリッピングの可能性がある）ことを条件とするからです。この方法で、カメラのセンサーのダイナミックレンジを最大限生かすことができます。

: カメラのデフォルトの自動露出設定モードでは通常、画像全体の平均輝度が中間グレーになるように設定されます。ときどき、明るいトーンが優勢な撮影シーン（雪景色など）では、カメラの自動設定で明るい部分をより中間グレーに寄せるため、露出アンダーになることがあります。逆に暗いトーンが優勢な撮影シーンでは、画像が露出オーバーになり、ハイライト部分がクリッピングされることがあります。そのような場合、カメラの手動露出設定機能で、露出を上げ下げすることができます。darktableの露光モジュールでは、露出設定を自動的に考慮に入れることができます。

: 場合によっては（例えば、ぴかぴかした物が鏡のように光を反射している場合など）多少のクリッピングはしかたがない場合もあります。しかし、クリップされたデータは失われ、復旧は不可能であることは注意しておいてください。データがクリップされた場合、 _フィルミックRGB_ では「ハイライト復元(highlight reconstruction)」機能を使って、クリッピングの影響を和らげ、その他の部分となめらかにつなげることができます。この機能は [_再構成(reconstruct)_](#reconstruct) タブで設定できます。また、カメラによっては「ハイライト優先」の測光モードが使える場合があり、ハイライトがクリップされない範囲で露出を最大にするのに役立ちます。さらに、たいていのカメラは「ゼブラ」とか「点滅」のような、クリッピングが起きているときに警告を表示する機能がついています。

中間トーンに合わせて調整
: [_露光(exposure)_](./exposure.md) モジュールで、中間トーンが十分明瞭になるように露光を調整してください。この段階では、ハイライト部分が白飛びしてしまっても心配はいりません。フィルミックRGBの処理の過程で復元されます。しかし、黒い部分で負の値のピクセルがないようにする、ということは重要です。負の値があると、フィルミックRGBの計算処理によって予測できない結果が出る場合があります。一部のカメラでは（主にキヤノン）、rawspeed（darktableにおけるrawデコードライブラリ）によって黒レベルが過大に設定されることがあり、そうすると黒い部分が押しつぶされて負の値が発生してしまいます。その場合、 [_露光_](./exposure.md) モジュールで、黒レベル補正に負の値を設定して黒い部分を明るくしてください。

ホワイトバランス、ノイズ低減、デモザイク
: _フィルミックRGB_ の自動調整機能を使うつもりであれば、先に [_ホワイトバランス(white balance)_](./white-balance.md) モジュールを使って色かぶりを修正し、無彩色が得られるようにしておいてください。RGB色空間では、輝度と色光度は関連しており、そして _フィルミックRGB_ の輝度検出処理は両方が正確に測定できることを前提としています。もしノイズの多い画像の場合は、最初にノイズ低減(denoise)を入れて黒部分の露光の検出がおかしくならないようにしてください。また、高品質な [_デモザイク(demosaic)_](./demosaic.md) アルゴリズムを使ってください。ただし、自動調整機能を使わず、手動でフィルミックの設定をするつもりであれば、ノイズについて気にする必要はありません。

トーンマッピングモジュールの無効化
: _フィルミックRGB_ の色保存モードを使う場合、 [_ベースカーブ(base curve)_](base-curve.md) などのトーンマッピングモジュールを使わないでください。これらを使うと予測できない色ずれが起き、色保存(chrominance preservation)モードの意味がなくなってしまいます。そもそも、 _フィルミックRGB_ を使うのであれば、普通はこの種のモジュールは必要ないはずです。

# 使い方

_フィルミックRGB_ モジュールは、撮影シーン（RAW画像）のダイナミックレンジを、画面のダイナミックレンジに対応させるように作られています。

この対応づけは3つの段階で構成されており、それぞれの段階はモジュール設定の別々のタブで操作できます。

 - [_シーン(scene)_](#scene) タブは、撮影シーンの「入力」に関する設定が入っています。シーンのどの部分が白や黒にあたるかを決めます。

 - [_再構成(reconstruct)_](#reconsnruct) タブには、白飛びした部分を扱うための機能があります。

 - [_ルック(look)_](#look) タブは、 _シーン_ タブで設定された入力値をどのように対応させるかについて、審美的な意図を設定します。モジュールのこの部分では、S字型曲線を適用して変換ことで、中間トーンのコントラストを強め、かつグレー値を画面表示における中間グレーに対応させます。これは [_ベースカーブ(base curve)_](./base-curve.md) や [_トーンカーブ(tone curve)_](./tone-curve.md) モジュールと同様の動作です。一般的な方針としては、カーブの端でクリッピングが起きない範囲で、ラティチュードを最大限大きくする、ということになります。

 - [_ディスプレイ(display)_](#display) タブは、変換された画像を画面表示に対応させるための出力設定を行います。一般的な使い方では、このタブで設定の調整が必要になることはあまりないでしょう。

 - [_オプション(options)_](#options) タブでは、高度な設定やパラメータが調整できます。

_フィルミックRGB_ はローカルコントラストを圧縮することが多いです。そこで、 _フィルミックRGB_ を設定したあと、 [_ローカルコントラスト(local contrast)_](local-contrast.md) モジュールを使うとよいかもしれません。また、彩度を [_カラーバランスRGB(color balance rgb)_](color-balance-rgb.md) モジュールで上げたり、[_トーン イコライザー(tone equalizer)_](tone-equalizer.md) を使ってさらに調整するなども考えられます。

_フィルミックRGB_ のスライダーは一般的で安全な値の範囲に制限されていますが、スライダー上で右クリックしてキーボードから直接入力することで、範囲外の値を設定することも可能です。

---

**注意**： _フィルミックRGB_ では、「何もしないことになる設定」というものはありません。モジュールが有効化されれば、画像は必ず（少なくとも多少は）影響を受けます。ですが、次のような設定をすることで、何もしないことに近い状態にすることは可能です。

- [_ルック(look)_](#look) タブで、コントラストを1.0、ラティチュードを99%、中間トーンの彩度(middle tones saturation)を0%にして、
- [_オプション(options)_](#options) タブで、シャドウとハイライトのコントラストを _ソフト(soft)_ にします。

この設定では、フィルミックは [_シーン(scene)_](#scene) タブで設定された限界に対する対数トーンマッピングだけを行います。

---

# 表示形式について

_フィルミックRGB_ 最上部にあるグラフ表示部分は、機能をより理解する助けとなるよう、複数の表示形式から選ぶことができます。違う形式に切り替えるには、グラフの右側にある ![view-icon](./filmic-rgb/view-icon.png#icon) アイコンを押してください。また、  ![legend-icon](./filmic-rgb/legend-icon.png#icon) アイコンを使うと、縦・横軸の数値などをオンオフすることもできます。

表示形式には以下のようなものがあります。

ルックのみ(look only)
: デフォルトの表示です。メインの明るい曲線は、撮影シーンの（EV単位の）ダイナミックレンジを、どのようにディスプレイ出力のダイナミックレンジに圧縮するかを表しています。オレンジの点は中間グレーの点、白い点はラティチュード範囲の両端、下部にある曲線のオレンジ部分はスプライン曲線のオーバーシュート（ [_ルック(look)_](#look) タブの操作で、それなりに対処することができます）を表しています。暗い曲線は、ハイライトと暗部でどの程度彩度が低減されているかを示します。

ルックとマッピング（線形）(look + mapping (linear))
: この表示では、ダイナミックレンジの対応と出力の変換に加えて、線形空間における [0,1] の範囲の入力値から出力値への対応が示されます。なお、シーン参照ワークフローでは入力値が1を越えることがありえますが、グラフ上では [0,1] の範囲の入出力値だけが表示されることに注意してください。これは、 _ベースカーブ(base curve)_ や _トーンカーブ(tone curve)_ といった他のトーンカーブマッピングモジュールとグラフの形を比べられるようにするためです。撮影シーン上の白の点が実際にはどういう値になっているかは、 _X軸_ のカッコの中に表示されます（入力値1に対するパーセンテージで表示されます）。

: ![filmic-rgb-look-mapping-lin](./filmic-rgb/filmic-look-mapping-lin.png#w50)

ルックとマッピング（対数）(look + mapping (log))
: ひとつ前のものと同様ですが、対数グラフで表示されます。

: ![filmic-rgb-look-mapping-lin](./filmic-rgb/filmic-look-mapping-log.png#w50)

ダイナミックレンジマッピング(dynamic range mapping)
: この表示形式はアンセル・アダムスのゾーンシステムから考案されたもので、入力における各ゾーン（EV）がどのように出力のゾーンに対応しているかが示されます。撮影シーンの中間グレーは必ず出力の（線形）空間における18%に対応づけられます。そして、どのように撮影シーンの露出範囲の両端のほうで階調範囲がより少ないゾーン数のディスプレイ出力空間に圧縮され、中間トーンにスペースを残して残ったゾーンにわり当てるか、という程度が表示されます。ラティチュードの範囲は、中間部にある暗いグレーのエリアで表されています。

: ![filmic-rgb-look-mapping-lin](./filmic-rgb/filmic-dynamic-range-map.png#w50)

---

**Note:** When some parameters are too extreme, resulting in an unfeasible curve, _filmic rgb_ will sanitize them internally. Sanitizing is illustrated in two ways on the look views:
**注意：** 無理な設定のパラメータがあり、指定通りの曲線が実現できないときには、 _フィルミックRGB_ は内部的に自動で調整します。調整が行なわれている場合、「ルック」の表示（曲線グラフ）で、以下の2通りの方法で示されます。

- A dot becoming red indicates that the linear part of the curve is pushed too far towards the top or the bottom. In the [_look_](#look) tab, reduce the _latitude_ or recenter the linear part using the _shadows ↔ highlights balance_ parameter.
- 直線部分の端のドットが赤くなっている場合、直線部分が上か下に行きすぎていることを示しています。 [_ルック(look)_](#look) タブにおいて、 _ラティチュード(latitude)_ を下げるか、 _シャドウ↔ハイライト バランス(shadows ↔ highlights balance)_ を調整して直線部分をずらすかしてください。
- A dot becoming a half circle indicates that contrast is too low given the dynamic range of the image. Increase _contrast_ in the [_look_](#look) tab, or the _dynamic range_ in the [_scene_](#scene) tab.
- 端のドットが半円形になっている場合、設定されたダイナミックレンジに対してコントラストが低すぎることを示しています。 [_ルック(look)_](#look) タブで _コントラスト(contrast)_ を上げるか、 [_シーン(scene)_](#scene) タブで _ダイナミックレンジ(dynamic range)_ を拡大するかしてください。

---

# モジュールの操作

## シーン(scene)

_シーン_ タブの操作は、原理的には [_レベル(levels)_](./levels.md) モジュールと同様です（黒、グレー、白ポイントの操作）。違いは、 _レベル_ はディスプレイ参照の値（0%〜100%）を想定しているのに対し、 _フィルミック_ ではシーン参照の値（マイナス無限大EV〜プラス無限大EV）を使うことができることで、そのために違ったインターフェースが必要になります。

中間グレーの輝度（デフォルトでは隠れています）(middle-grey luminance)
: この値は、撮影シーンにおけるどの輝度が、基準となる中間グレーとして扱われるか（またその結果ディスプレイの18%に対応させられることになるか）を決めます。選択領域の平均輝度を知りたい場合、カラーピッカーを使ってください。もし、撮影シーンと同じ光源で撮影したグレイカードかカラーチャート（IT8チャートかカラーチェッカー）の写真があるなら、このカラーピッカーを使ってグレイ部分の輝度を簡単に調べることができます。なければ、カラーピッカーは被写体の平均輝度を調べるのに使えます。

: これは画像の明度補正と似た効果をおよぼします。100%に近い値であればハイライトが圧縮されることはないですが、暗部を再現することはできません。0%に近い値であれば暗部をよく再現させますが、ハイライトは激しく圧縮され、ローカルコントラストも減少します。

: 中間グレーの輝度を変更すると、ダイナミックレンジのクリッピングを防ぎ、適切な設定を手助けするため、白と黒の相対露光量もあわせて自動的に変更されます。グレーの設定による自動調整では満足な結果にならなかった場合は、白と黒の相対露光量をあとから再調整することもできます。

---

**注意：** これを使って中間グレーを設定する、というのは非推奨です。そのため、デフォルトでは表示されなくなりました。中間グレーのレベルを設定する場合、 _露光(exposure)_ モジュールを使うほうがよいです（上記 [_使い方_](#usage) を参照）。それでもこのスライダーを表示させたい場合は、 [_オプション(options)_](#options) タブで _カスタムの中間グレー値を使用(use custom mid-grey values)_ にチェックを入れると有効になります。

---

白 相対露光量(white relative exposure)
: 撮影シーンにおける中間グレーの輝度から、ディスプレイ上で純粋な白に対応させるシーン上の輝度までの段数（EVで）です。これはシーンのダイナミックレンジの、ディスプレイで表現される部分の右端となり、シーン上でこの値より大きい輝度はディスプレイではクリップされます（純粋な白になります）。ここでのカラーピッカーは、選択領域のRGB色空間における最大輝度の値を読み、それを純粋な白として、100%の輝度になるように白の相対露光量を設定します。

黒 相対露光量(black relative exposure)
: 撮影シーンにおける中間グレーの輝度から、ディスプレイ上で純粋な黒に対応させるシーン上の輝度までの段数（EVで）です。これはシーンのダイナミックレンジの、ディスプレイで表現される部分の左端となり、シーン上でこの値より小さい輝度はディスプレイではクリップされます（純粋な黒になります）。ここでのカラーピッカーは選択領域のRGB色空間における最小輝度の値を読み、それを純粋な黒として、0%の輝度になるように黒の相対露光量を設定します。黒のカラーピッカーはノイズの影響を大変受けやすく、最小輝度の値が（実際のデータとして）純粋な黒なのか、単なるノイズなのか区別することができません。そのため、低ISOの場合や高品質のデモザイク(demosaic)を使っている場合のほうが有効に働きます。カラーピッカーを使った結果黒の相対露光量が--16EVに設定された場合、それはこの測定が失敗したということであり、手動で設定する必要があります。

: 「黒 相対露光量」の設定で、どの程度低照度の部分を復元するか決めることができます。

ダイナミックレンジ拡大縮小と自動調整(dynamic range scaling and auto-tune)
: 自動調整のカラーピッカーは上記のカラーピッカーをまとめたもので、白と黒の相対露光量を一度に設定することができます。選択領域の輝度の最大値を使って白を、最小値を使って黒を設定します。風景写真ではおおむねよい結果が得られますが、ポートレートや室内の写真では通常失敗します。

: もし本当の白や黒がそもそも撮影シーンにない場合、画像から得られる最大・最小のRGB値は有効な仮定としては使えません。「ダイナミックレンジ拡大縮小」を使うと、検出されたダイナミックレンジとパラメータを対称的に拡大・縮小できます。これは両方のカラーピッカーに対して機能し、白と黒の相対露光量が調整されます。

---

**注意**： カメラのセンサーのダイナミックレンジ（DxoMark.comとかPhotonsToPhotos.orgで見れるようなやつ）とフィルミックに出てくるダイナミックレンジ（撮影シーンの白のEV〜シーンの黒のEV）には、直接の関係はありません。パイプラインの _フィルミック_ より前の段階ではいろいろな操作がなされます（黒RAWオフセットで黒を0に対応させている場合など）。そうなると理論的には _フィルミック_ が入力として受けとるのは無限大のダイナミックレンジになります。これはあくまでソフトウェア的なピクセルエンコーディング操作と関係があるだけで、実際のセンサーの能力とは無関係です。

_シーン参照(scene-referred)_ ワークフローでは、 _露光(exposure)_ モジュールで必ず黒レベル補正(black level correction)が --0.0002に設定されるので、 _フィルミック_ が入力として実際に受けとるダイナミックレンジは、ほとんどの場合 12.3EV 程度になります。もし _フィルミック_ で黒の相対露光量を --16EV に設定しても黒がクリップされているようなら、この値をもう少し下げてください。

---

## 再構成(reconstruct)

このタブの操作では、画像内のクリップされた部分とそうでない部分が自然に接続するように調整したり、隣接したピクセルから色を再構成したりすることができます。撮影するときにどうやってもクリッピングが起こる照明部分（裸電球や太陽がフレームに入っている場合など）を取り扱うために設計されており、銀塩フィルムと同様にそうした部分の境界でうまく拡散を起こすよう働きます。広い範囲でクリッピングが起きている場合や、色がにじんで失われた部分を復元させるようなものではありません。

ここの再構成アルゴリズムに対してなるべくデータを与えるため、 [_ハイライト再構成(highlight reconstruction)_](./highlight-reconstruction.md) モジュールを無効にしておくとよい場合があります（ _ハイライト再構成_ モジュールは、デフォルトの動作ではハイライトをクリップします）。なお、こうするとハイライトがマゼンタ寄りになるかもしれませんが、 _細部 グレー/カラー(gray/colorful details)_ スライダーで調整してください。

最初に、ハイライト再構成処理の対象となる画像の範囲を指定するため、マスクを用意する必要があります。それから、再構成アルゴリズム内で発生する多少のトレードオフを微調整するための操作ができるようになります。

### _ハイライトクリッピング(highlights clipping)_

ここでの操作は、画像の中のどの領域がハイライト再構成アルゴリズムの対象となるか選択します。

閾値(threshold)
: ここで設定した閾値より明るいピクセルが、再構成アルゴリズムの対象となります。単位は EV で、 _シーン(scene)_ タブで設定された白の点に対する相対値です。デフォルトでは +3 EV に設定されており、これは、ハイライト再構成の効果が発生するには、ピクセルが [シーン](#scene) タブで設定された白の点より少なくとも +3 EV 明るくなければならない、という意味です。実際には、これはハイライト再構成がデフォルトでは事実上無効になっているということです（処理速度的な問題で、必要なときだけ有効にすべきなのです）。そこで、 _ハイライト再構成_ 機能を使うには、まず _ハイライト再構成マスクを表示(display highlight reconstruction mask)_ アイコンをクリックしてマスクを表示させ、それから再構成したいハイライト部分がマスクで白く選択された状態になるまで、閾値を下げていきます。最初に [RAW露出オーバー警告(raw overexposed warning)](../utility-modules/darkroom/raw-overexposed.md) を使って画像をチェックし、 RAW ファイルのどのピクセルがクリップされているか、またそのピクセルが RGB のどれかのチャンネルだけでクリップされているのか全部なのかを見ておくとよいかもしれません。

遷移(transition)
: クリップされたピクセルとそうでないピクセルの間の遷移をなめらかにするために使います。ここを右に動かすと、マスクのぼかし具合が大きくなり、クリップされた領域とそうでない領域との遷移がなめらかになります。こうするとふたつの領域がよりなめらかに混合されるようになります。左に動かすと、マスクのぼかし具合は小さくなり、境界がよりはっきりして、クリップされた領域とそうでない領域の混合具合も減少します。

ハイライト再構成マスクを表示(display highlight reconstruction mask)
: この表示の右にあるアイコンをクリックすると、ハイライト再構成マスクの表示・非表示を切り替えられます。上のふたつの設定を変更する場合、表示しておくことをおすすめします。

### _バランス(balance)_

ここでは、各種再構成アルゴリズムでトレードオフになる要素を調整することができます。

構造↔質感(structure↔texture)
: このスライダーでは、再構成アルゴリズムに対して、滑らかな階調で塗ることを優先するか（構造(structure)）、クリップされていないピクセルの情報から得られるディテールを使って質感を再構成することを優先するか（質感(texture)）を調整できます。デフォルトでは中間の0%になっており、両方を同程度に重視します。もし、3つのチャンネルすべてでクリッピングが起きている領域が多く存在する場合、そのような領域には再構成アルゴリズムのために得られる質感情報も存在しないので、色の再構成を優先するためにスライダーを左に動かすほうがよいです。一方、もし1つか2つのチャンネルだけでクリッピングが起きている領域が多くある場合、クリップされていないチャンネルにディテールが残っている場合があり、スライダーを右に動かせば、そのようなクリップされていないディテールを使った質感の再構成を優先できます。

ブルーミング↔再構成(bloom↔reconstruct)
: このスライダーでは、アルゴリズムに対して、クリッピングが起きた領域ではっきりしたディテールを再構成することを優先するか（再構成(reconstruct)）、あるいはその領域をぼかして銀塩フィルムにおけるブルーミング効果のようなことを起こすか（ブルーミング(bloom)）を調整できます。デフォルトでは100%に設定されており、これはクリッピング領域でディテールを最大限明瞭にすることになります。クリッピング領域をもう少しぼかしたければ、スライダーを左に動かしてください。ぼかしを強めると、副作用としてハイライト部分が暗くなりがちで、その結果再構成された部分の色がより強くなる場合があります。

細部 グレー↔カラー(gray↔colorful details)
: このスライダーでは、アルゴリズムに対して、ハイライトを白黒っぽく再構成するか、色をつけて再構成するかを調整できます。ハイライト部分にもっと色が必要であれば、スライダーを右に動かしてください。彩度をもっと下げたければ、スライダーを左に動かしてください。マゼンタや色域外の色が出てくるようであれば、彩度を下げるようにしたほうがよいかもしれません。

## ルック(look)

_ルック_ タブを操作するときは、 _ルックのみ(look only)_ の表示にしてスプラインS字曲線を見ることをおすすめします。この曲線は、グラフ左下の撮影シーン/ディスプレイの黒レベルからスタートし、なめらかに上昇して右上のシーン/ディスプレイの白レベルに到るはずです。ただし、S字曲線に対する条件が厳しすぎる場合、曲線の暗部かハイライト部（あるいはその両方）でディスプレイの限界を越える「オーバーシュート」を起こしていることがあります。そのような場合、オーバーシュート部分は警告のためオレンジで表示されます。

もしオレンジの警告がS字曲線のどちらかの端で表示されているなら、曲線が滑らかに単調増加するものに直すために修正操作が必要になります。たとえば以下のようなものが考えられます。

- ラティチュードかコントラスト、あるいはその両方を減らす

- シャドウ/ハイライト(shadows/highlights)のスライダーを調整し、ラティチュードの位置をずらしてスプライン曲線に余裕をもたせる

- _シーン(scene)_ タブの黒・白の相対露光量のスライダーが、撮影シーンに合わせて適切に設定されているか確認する

- [_オプション(options)_](#options) タブのコントラスト設定（どちらか、または両方）を _安全(safe)_ か _ハード(hard)_ にする

もし [_ディスプレイ(display)_](#display) タブの _ターゲット 黒 輝度(target black luminence)_ がゼロ以外の値に設定されている場合、このこともまた _フィルミックRGB_ で滑らかな単調増加スプライン曲線を得るのが難しくなる要因になります。この値を減らすことでも、制約を弱めることができます。より詳しいことは [_ディスプレイ_](#display) の節を参照してください。

コントラスト(contrast)
: _フィルミック_ のS字曲線は、設定されたパラメータから仮想的ノードを作成して、間を補完することで作られます。トーンカーブ(tone curve)モジュールと同様ですが、ここではノードを手動で動かすことはできません。このS字曲線は、3つの部分に分けられます。中間の線形部分、それと中間部から露光範囲の両端までをなめらかに接続する両端の部分です。

: コントラストスライダーは中間部の傾きを調整します。これはグラフ表示で確認できます。ダイナミックレンジが大きくなるほど、自然な見た目の画像にするためにはコントラストの値を大きく設定しなければなりません。このパラメータは主に中間トーンに影響します。なお、全体のコントラストはアキュータンス（シャープネスとして感じられます）に影響します。つまり、低コントラストの画像は、たとえ光学的にはシャープネスが高い（ [光学伝達関数(Optical Transfer Function)](https://en.wikipedia.org/wiki/Optical_transfer_function) 的な意味で）としても、シャープネスが低いように見えることに注意してください。

: コントラストを1に設定するとほぼS字曲線ではなくなりますが、ハイライト部と暗部には非常に小さくスプライン関数の影響が残ります。

硬さ(hardness) （これまでの _ターゲット冪乗転送関数(target power factor function)_ ）
: 以前のバージョンの _フィルミックRGB_ では _ターゲット冪乗転送関数_ と呼ばれていたもので、デフォルトでは非表示になっており、 [_シーン(scene)_](#scene) タブの設定を元に自動設定されます。このスライダーを表示するには、 [_オプション(options)_](#options) タブで _硬さの自動設定(auto adjust hardness)_ のチェックをはずす必要があります。

: これは出力転送関数に適用される冪関数で、よく不適切にも _ガンマ_ と呼ばれています（この用語は画像処理ソフト界隈では様々な意味で使われていますので、私たちはこの用語を使わないことにします）。これは中間トーンを圧縮したり持ち上げたりしてディスプレイの非線形性を補償したり、8ビットのファイルフォーマットにエンコードする際の量子化歪みを避けたりするために使うものです。これはICCカラープロファイルを適用する場合の一般的な処理です（線形RGB空間、すなわちREC 709やREC 2020のような1.0の線形「ガンマ」を持つもの、をのぞく）。しかし、 _フィルミックRGB_ の出力においては、信号は対数エンコードされ、ICCカラープロファイルでどうこうできるものではなくなります。その結果、もし1/2.2のガンマを適用した場合、最終的には二倍になり、ディスプレイ参照空間において中間グレーは45%であるべきところが76%に対応づけられてしまいます。

ラティチュード(latitude)
: ラティチュードは、中間の線形部分両端の2つのノードの間隔で、 [_シーン(scene)_](#scene) タブで設定されたダイナミックレンジ（白の相対露光量から黒の相対露光量を引いた値）に対するパーセンテージで表されます。これは、優先的に対応させられる輝度の範囲で、コントラストの値で設定される輝度の範囲に対応づけられます。通常、クリッピングが起きないかぎり、ラティチュードはできるだけ大きく保つことをおすすめします。もしクリッピングが見られるようなら、ラティチュードを小さくするか、あるいは _シャドウ↔ハイライト バランス(shadow↔highlights balance)_ の値を設定することでラティチュードの範囲をずらすか、あるいはコントラストを小さくするかで調整できます。

: また、輝度の両端部における脱色が起きないのがどの範囲になるかも、ラティチュードの値によって決まります（ _中間トーン彩度(middle tones saturation)_ を参照してください）。

シャドウ↔ハイライト バランス(shadow↔highlights balance)
: デフォルトでは、ラティチュードはダイナミックレンジの中央部に設定されます。もしこれだとどちらかの端でクリッピングが起きるのであれば、「シャドウ/ハイライト バランス」の値を設定することで、ラティチュードを（その傾きにそって）明るいほうか暗いほうへずらすことができます。こうすることで、必要な場合はダイナミックレンジの一方の端にもう一方よりも余裕をもたせることができます。

中間トーン彩度(mid-tones saturation)（これまでの _極端な輝度の色飽和(extreme luminance saturation)_）
: 輝度の極端な部分（ハイライトと暗部）では、ピクセルは白か黒に近付きます。白と黒には色がないわけですから、通常、その部分は彩度が0%になっていなければなりません。その彩度0%の部分まで自然に遷移するように、中間トーンの範囲の外にあるピクセルでは、輝度の両端に近付くにつれて次第に脱色されます。 _フィルミックRGB_ グラフ部分の暗いほうの曲線は、このラティチュード範囲からはずれたピクセルの脱色量を示しています。スライダーを右に動かすことで、脱色が始まる点を端に向かって動かし、脱色を示す曲線をより急勾配にすることができます。やりすぎると、ハイライト周辺に偽色帯が生じます。スライダーを左に動かすと、脱色が始まる点を中心に向かって動かし、脱色を示す曲線をなだらかにできます。ハイライト部分にもっと彩度がほしいと感じた場合、 [_シーン(scene)_](#scene) タブでの白 相対露光量の設定のせいでハイライトのクリッピングが起きているのではないことが確かならば、ここのスライダーを右に動かして彩度を上げてみてください。

: この脱色の動作は、以前のバージョンの _フィルミックRGB_ で（ _極端な輝度の色飽和_ というスライダーで）設定するときとは変わっていることにご注意ください。 [_オプション(options)_](#options) タブの _色科学(color science)_ という設定を "v3 (2019)" にすることで、以前の動作に戻すこともできます。

: デフォルトではこの値は0に設定されており、現在では彩度の調整はパイプラインのより前の段階で行うことが推奨されています。この目的のため、 [_カラーバランスRGB(color balance rgb)_](./color-balance-rgb.md) モジュールに「基本的な色彩調整(add basic colorfulness)」というプリセットが追加されました。

## ディスプレイ(display)

このタブの設定を変える必要はあまりないはずです。

ターゲット 黒 輝度(target black luminance)
: この設定値は、トーンマッピングを行う際の、出力輝度を決めます。99%の状況ではデフォルトの値でうまく動くでしょう。残りの1%は、対数エンコードのデータを扱うメディアに線形RGB空間（REC709、REC2020）で出力する場合です。このため、ここの設定は注意して扱ってください。darktableは、画面のプレビューとファイル出力に別々のピクセルパイプラインを使うということはできませんので。

: 「ターゲット 黒 輝度」の値は、出力メディアにおける最小値としての黒を設定します。デフォルトでは、出力色空間中で使えるビット数でエンコードできる、ゼロでない最小の値が設定されます。これをゼロに減らすということは、ゼロでない輝度が出力ではゼロになる場合があるということを意味しており、そうすると暗部の最も暗い部分でディテールが失なわれる可能性があります。このスライダーの値を増やすと、黒を持ち上げて色褪せた感じになり、ある種の「レトロな」外観になります。

ターゲット 中間グレー(target middle-grey)
: これは出力メディアにおける中間グレイの値で、S字曲線における中心ノードの対応先として使われます。ガンマ補正されたメディアでは、実際のグレイはガンマ補正して求められます（中間グレイ^(1/ガンマ)）ので、ガンマ値2.2で中間グレイ値を18%に設定すると、実際のターゲット中間グレイは45.87%となります。

ターゲット 白 輝度(target white luminance)
: この値は、出力メディアにおける最大値としての白を設定します。もし、白を弱めてレトロ風の外観にしたい場合、100%より小さい値を設定してください。

: 二倍化して画像の色が薄くなってしまうことを避けるため、 _フィルミックRGB_ では「ガンマ」圧縮を行ってICCのガンマ補正による出力を元に戻し、中間グレーが最終的には正しく対応させられるようにします。この圧縮を避けるには、冪乗の設定値を1.0にして、ターゲットの中間グレイを45%にしてください。

## オプション(options)

色科学(color science)
: この設定は、 _フィルミックRGB_ モジュールで使われるアルゴリズム（輝度両端での脱色の方針など）を決めるもので、新しく編集する場合のデフォルトは _v5 (2021)_ になっています。 _フィルミックRGB_ の以前のバージョンの動作に戻すには、ここを _v3 (2019)_ か _v4 (2020)_ に設定してください。もし以前のバージョンの _フィルミックRGB_ で編集した画像があれば、それについては編集内容の互換性のため、自動的にそのバージョンの値に設定されます。

色度保持(preserve chrominance)
: _フィルミックRGB_ において色光度がどのように扱われるかを決めます。何もしないか、3種類のノルムのうちどれかを使うかです。

: S字曲線をそれぞれの色成分に対して独立に適用すると、色成分の比率が変更され、その結果色のスペクトルの性質が影響を受け、最終的には画像の色調に影響します。 _色度保持(preserve chrominance)_ で _なし(no)_ を選んだときは、つまり以上のようなことが起こります。この設定にすると、ほかの設定のときより「良い」結果が得られるように思える場合もあるでしょうが、しかしピクセルパイプライン上のより後の段階に悪い影響を与え、たとえば全体の彩度に影響することがあります。

: これ以外の設定は、すべて同様の動作をします。S字曲線をR、G、Bのそれぞれのチャンネルに別々に適用するかわりに、あるノルムNを使って、3つの成分をそれぞれNで割り、S字曲線をNに適用します。こうすることで、チャンネル間の関係が保たれます。

: 色度保持におけるそれぞれの設定は、どのノルムを使うか（Nとして使われる値）を示しています。

: - _なし(no)_ は、R・G・Bチャンネル間の比率が保たれないことを意味します。暗部の彩度が高く、ハイライトの彩度が低くなりやすいです。色域外の青や赤がある場合は有用かもしれません。

: - _RGB最大(max RGB)_ は、R、G、Bチャンネルの中の最大値です。これは以前のバージョンの _フィルミックRGB_ モジュールと同じ動作です。これを使うと青い色が、特に空の色が暗くなりやすいです。クリップされたチャンネルがある場合には特に、ハローや偽色帯が出やすくなります。また、ローカルコントラストがいくぶん平板になるかもしれません。

: - _輝度 Y(luminance Y)_ は、R、G、Bチャンネルの値の線形結合です。これを使うと赤が暗くなりやすく、また赤のローカルコントラストが大きくなりやすいです。彩度が高い色域外の青がある場合、うまく動かないことが多い傾向にあります。

: - _RGBパワーノルム(RGB power norm)_ は、R、G、Bチャンネルの値の3乗の合計を、2乗の合計で割ったものです。つまり、(R³ + G³ + B³)/(R² + G² + B²)です。これは通常、RGB最大と輝度Yの値のちょうどよい折衷案的なものになります。

: - _RGBユークリッドノルム(RGB euclidean norm)_ は、RGB空間を感知しないスタイルで、どのようなカラープロファイルを使っているかにかかわらず同じ結果を出します。ハイライトを「パワーノルム」より重視し、よりハイライトの彩度を下げます。たぶん、カラーフィルムに一番近い見た目になるのではないでしょうか。

: ノルムの「正しい」選択というものはなく、処理している画像によります。いろいろ試してみて、歪みなどが出ずに一番きれいに見えるものを探してください。

ハイライトのコントラスト(contrast in highlights)
: _フィルミックRGB_ のS字曲線の、ハイライト端での曲がり具合を決めます。デフォルト設定（ _安全(safe)_ ）では、上や下に飛び出してしまわないことが保証されますが、白の近くでコントラストがかなり弱まります。 _ハード(hard)_ に設定すると、スプライン曲線の傾きについてきつい条件をかけ、S字曲線の曲がりかたを激しくするので、ハイライト側でより階調が圧縮されるようになります。 _ソフト(soft)_ に設定すると、この条件を緩め、曲がりかたを弱くするのでハイライト側での階調圧縮が少なくなります。

シャドウのコントラスト(contrast in shadows)
: _フィルミックRGB_ のS字曲線の、暗部端での曲がり具合を決めます。デフォルト設定（ _安全(safe)_ ）では、上や下に飛び出してしまわないことが保証されますが、黒の近くでコントラストがかなり弱まります。 _ハード(hard)_ に設定すると、スプライン曲線の傾きについてきつい条件をかけ、S字曲線の曲がりかたを激しくするので、暗部側でより階調が圧縮されるようになります。 _ソフト(soft)_ に設定すると、この条件を緩め、曲がりかたを弱くするので暗部側での階調圧縮が少なくなります。

カスタムの中間グレー値を使う(use custom middle-grey values)
: この設定をオンにすると、 [_シーン(scene)_](#scene) タブの _中間グレーの輝度(middle-grey luminance)_ スライダーが表示されるようになります。現在のバージョンの _フィルミックRGB_ では、中間グレーのレベルを設定するのは _露光(exposure)_ モジュールで行うことが推奨されているため、ここはデフォルトではオフになっています（ _中間グレーの輝度_ スライダーも非表示になっています）。

硬さの自動調整(auto-adjust hardness)
: デフォルトではこの設定はオンになっており、 _フィルミックRGB_ 出力転送関数に適用される冪関数（いわゆる「ガンマ」）を自動的に計算します。この設定をオフにすると、 [_ルック(look)_](#look) タブに _硬さ(hardness)_ スライダーが表示され、手動でこの値を設定できるようになります。

高品質な再構成の繰り返し回数(iterations of high-quality reconstruction)
: ハイライト再構成のアルゴリズムについて、処理の繰り返し回数が設定できます。回数が多いほど、クリップされた領域に周囲のピクセルから色を多く持ってくることが可能ですが、そのぶん処理が重くなります。クリップされたチャンネルによってハイライト部にマゼンタが現れるような、なかなかうまくいかない場合に有効かもしれません。

: デフォルトの再構成処理はRGBのチャンネル毎に別々に行われ、またそれぞれ一回だけ処理されますが、 _高品質_ 再構成の場合は、RGBの比率に対して別のアルゴリズム（彩度を輝度と分離します）を使い、複数回の処理を繰り返すことでクリップされた領域に周囲のピクセルから徐々に色を取りこみます。しかし、繰り返し回数が多すぎても再構成の質は下がり、例えば白い雲に青空の色がはみ出したり、木を通して見た太陽に葉の緑が入ってしまったりするように、クリップされた部分におかしな色が入ってしまう可能性があります。

ハイライトにノイズを入れる(add noise in highlights)
: 再構成されたハイライト部に人工的にノイズを入れ、周囲の（最初からノイズを含む）領域と比べて塗り潰しになりすぎることを防ぎます。再構成された領域と、周囲のクリップされていない領域とをなじませるのに役立つ場合があります。

ノイズの種類(type of noise)
: 入れるノイズの統計的な分布を設定します。人工的に生成されたノイズの見た目と、周囲の領域に含まれるカメラのセンサーから自然に発生したノイズの見た目を合わせるのに役立つ場合があります。普通のセンサーのノイズに最も近いのは _ポアソン分布(poissonian)_ ノイズですが、銀塩フィルムの粒状感に近い _ガウス分布(gaussian)_ と比べると見た目があまりきれいではありません。また、ノイズ除去のモジュールは大抵、センサーのノイズをポアソン分布から多少ガウス分布に変えることにも注意してください。実際の画像のノイズを確認して、合うほうを選択する必要があります。
