---
title: lens correction
id: lens-correction
applicable-version: 3.8
tags: 
working-color-space: RGB
view: darkroom
masking: false
---

レンズ原因の歪み、横色収差(TCA)、口径食（周辺減光）を自動的に修正（あるいは再現）します。

このモジュールは、カメラとレンズの組み合わせを画像のEXIFデータから決定し、外部ライブラリの [lensfun library](https://lensfun.github.io/) を使って補正パラメータを取得します。

お使いのPCのlensfunライブラリに、自動認識されたカメラとレンズの組み合わせについての補正プロファイルが存在しなかった場合、3つの測光パラメータ（後述）の設定の部分は警告メッセージに置きかわります。メニューから手動で正しいプロファイルを探せる場合もあります。

お使いのレンズがlensfunのリストにあるはずなのに正しく認識されなかった場合は、exiv2プログラムで多少設定が必要かもしれません（詳しくは [この書きこみ](https://dev.exiv2.org/boards/3/topics/2854) を参照してください）。なお、レンズ名はインポートの過程で取得されますので、設定のあとに画像をインポートしなおす必要がある場合もあります。

お使いのレンズが出てこなかった場合、まずlensfunの [サポートするレンズ一覧(currently supported lenses)](https://lensfun.github.io/lenslist/) を確認し、それから [`lensfun-update-data`](https://lensfun.github.io/manual/v0.3.2/lensfun-update-data.html) ツールを実行してみてください。それでもお使いのレンズに対するプロファイルがないようでしたら、darktableユーザーのTorsten Brongerが [レンズ較正(lens calibration service)](https://www.darktable.org/2013/07/have-your-lens-calibrated/) を提供しています。あるいは、 [lensfun のホームページ](https://lensfun.github.io/lenslist/) を読んで、補正パラメータを自作する方法を調べてみてください。もしパラメータを作成したなら、lensfunチームとも共有することをお忘れなく。

# モジュールの操作

カメラ(camera)
: 画像のEXIFデータから取得したカメラのメーカー名と機種名です。階層メニューからカメラを選択して、手動で設定することもできます。レンズについては、ここで選択されたカメラに対する補正プロファイルが存在するレンズだけが表示されます。

レンズ(lens)
: 画像のEXIFデータから取得したレンズのメーカー名と機種名です。階層メニューからレンズを選択して、手動で設定することもできます。これは主に純粋な（EXIFデータが取得できない）メカニカルレンズのために必要となりますが、ノーブランドやサードパーティー製のレンズでも使う必要があるかもしれません。

測光パラメータ（焦点距離、絞り、対象までの距離）(photometric parameters (focal length, aperture, focal distance))
: レンズ補正には、いくつかの測光パラメータが必要となります。これは画像のEXIFデータから読みとることができ、焦点距離（歪み、TCA、周辺減光の補正に必要）、絞り（TCA、周辺減光の補正）、対象までの距離（周辺減光の補正）です。EXIFデータに「対象までの距離」を記録しないカメラは多いですが、そういう場合は手動で設定する必要があります。

: 自動で設定されたパラメータは手動で設定しなおすことができます。メニューから定義済みの値のどれかを選択するか、ドロップダウンメニューが表示されているときにキーボードから値を入力してください。

補正(corrections)
: darktableがどの補正を行うかを（歪み、TCA、周辺減光）選択します。カメラの内部ですでに何かの（周辺減光とか）補正が行われている場合や、何かの補正を別のプログラムで行うつもりの場合などは、デフォルトの「全て」(all)から変えてください。

形状(geometry)
: レンズの問題を補正することに加えて、このモジュールでは画像の投影方法を変更することができます。このコンボボックスで、「心射方位」(rectilinear)、「魚眼」(fish-eye)、「パノラマ」(panoramic)、「正距円筒」(equirectangular)、「正射」(orthographic)、「平射」(stereographic)、「等立体角」(equisolid angle)、「Thoby魚眼」(Thoby fish-eye)の中から選択してください。アナモルフィックレンズの縦横比を補正したい場合は、 [_回転と遠近法補正(rotate and perspective)_](./rotate-perspective.md) モジュールを使ってください。

スケール(scale)
: 周囲に黒い部分が出ないように、画像を拡大縮小する比率を設定します。スライダー右にある自動スケールボタン（丸い矢印のボタン）を押せば、darktableが自動的に最適な値を設定します。

モード(mode)
: このモジュールのデフォルトの動作は、レンズの問題を _「補正」(correct)_ するというものです。これを「歪曲」(distort)に変えると、補正するかわりに、特定のレンズの問題や歪みを _再現_ します（効果が逆になります）。

TCA overwrite
: Check this box to override the automatic correction parameters for TCA. This will expose the TCA red and TCA blue parameters below. Un-check the box to revert back to automatic corrections.
: 自動で設定されたTCAの補正パラメータを上書きしたい場合、ここのチェックを入れてください。このチェックを入れると、次の「TCA 赤」と「TCA 青」の設定が表示されるようになります。チェックをはずせば、自動補正に戻ります。

TCA 赤、TCA 青
: TCAの補正パラメータを上書きして設定します。また、レンズプロファイルにTCA補正の値が含まれていない場合に、手動でパラメータを設定するためにも使えます。高コントラストの境界を持つ領域で、フチに（存在しない）色のついている部分を探して、そういう部分が最小になるようにTCAパラメータを調整してください。

補正済み(corrections done)
: 場合によっては、あるカメラとレンズの組み合わせに対して、lensfunのプロファイルが一部の補正しかサポートしていないことがあります。ここに表示されるメッセージは、どの補正が画像に対して実際に行われたかを示しています。

---

**注意：** TCA補正は、モノクロと判定された画像には適用されません（詳しくは [モノクロ画像の現像(developing monochrome images)](../../guides-tutorials/monochrome.md) を参照してください）。

**注意：** レンズ補正モジュールは、境界部分の不足したデータを、境界のピクセルを繰り返すことで埋めます。強い補正を行うと、この埋めた部分が見えるようになります（特に、ノイズの多い画像などで）。必要に応じて画像を切り抜きしてください。

---

ガイド線を表示(show guides)
: チェックを入れると、このモジュールが有効になっているときはガイド線が表示されるようになります。右側のアイコンをクリックすると、ガイド線の種類や色を変更できます。詳しくは [ガイドとオーバーレイ表示(guides & overlays)](../utility-modules/darkroom/guides-overlays.md) をご覧ください。