---
title: clipping warning
id: clipping
applicable-version: 3.4
tags: 
view: darkroom
---

画像の中で、輝度か色域のクリッピングが起きている可能性がある部分を強調表示します。

画像がディスプレイに送られるときには、各ピクセルは通常3つの数の組として表現されていて、それぞれが出力色空間での赤・緑・青の原色の強度を表しています。通常この出力色空間は、物理的な制約のあるハードウェアと強く関連しているので、 [R,G,B] の各チャンネルには最大値が設定され、それぞれがその色空間での最大の強度を表すようになっています。同様に、ゼロではない有限の値として扱う下限の値として、最小値も設定されています。広い色空間から最終的な出力色空間に変換しようとすると、この最大値を越える値は強制的に最大値とされ、最小値を下回る値は強制的にゼロとされます。この処理は「クリッピング」と呼ばれ、ディテールが失なわれたり、クリップされたチャンネルのある色が「不正確に」なったりする原因となります。

クリッピング警告をオンにするには、 ![clipping warning](./clipping/clipping-icon.png#icon) アイコンをクリックしてください。

出力色空間で表現されるにあたって、ピクセル値がクリップされる場合は2通りあります。

- _輝度(luminance)クリッピング：_ これは、ピクセルが明るすぎて出力色空間で表現できない場合に発生する場合があります。ピクセルの輝度は、 [R,G,B] チャンネルの値の重みつき平均として計算されます。もしこの値が許される最大値を越えているなら、それは露光過多であることを示しています。ピクセルの輝度は、出力色空間の [R,G,B] 値で表現するには暗すぎるという場合もあり、その場合は単に黒として表示されます。通常、輝度クリッピングに対処するには、注意深くトーンマッピングと露光補正を調整することになります。

- _色域(gamut)クリッピング：_ 出力色空間では原色が定義されており、それを特定の比率で混ぜることで最終的な出力として個々の色をつくります。しかし、3つの原色を組み合わせて作れる色というのは限られているのです。彩度の高い色などはこの方式で表すのが難しくなりうるもので、特に非常に明るい／暗いピクセルはやっかいです。もし、どのような [R,G,B] の組み合わせでも目的の色を目的の明るさで表現できないのであれば、その色は「色域の外にある」と言い、かわりにその色空間で許される [R,G,B] 値の組で表現 _できる_ ような別の色で手を打つ必要があるのです。色域クリッピングは、ハイライトや暗部で彩度が高くなりすぎないように注意したり、カラーグレーディングやカラーマッピングを少々使ったりして対処することができます。

このクリッピング警告(clipping warning)モジュールは、出力色空間で正確に表現できないピクセルを強調表示するためのもので、輝度・色域クリッピングの両方の場合に対応しています。バージョン3.4より前のdarktableでは、 [R,G,B] チャンネルのどれかが可能な最大値を越えているようなピクセルと、完全に黒として表示されてしまうようなピクセルをすべて強調表示していました。3.4以降では、クリッピング警告表示機能に、輝度と色域のクリッピングを見分けるためのモードが追加されたので、どのように対処するかよりよい方法を判断しやすくなりました。

クリッピング警告はピクセルパイプラインの最後に動作するので、ディスプレイの色空間でデータを受けとり、ヒストグラム色空間に変換します。お使いのディスプレイ色空間が「あまり良くない」場合（デバイスプロファイルではよくあることです）、ディスプレイプロファイルの色域外の色はクリップされたり、色ずれしたりします。

ここで説明しているクリッピング警告モジュールは、現像処理によって発生するクリッピングと、出力色空間の制約で発生するクリッピングについて警告します。以下のような似た機能と混同しないようにしてください。

- [RAW露光過多警告(raw overexposed warning)](./raw-overexposed.md) は、元々のRAWファイルのピクセルの中で、カメラのセンサーのダイナミックレンジの物理的限界によってクリップされている部分を表示します。このモジュールは撮影の時点で完全に失われた情報について強調表示するもので、ハイライト復元処理を使ってできるかぎり対処する必要があります。

- [色域チェック(gamut check)](./gamut.md) モジュールも、現像処理によって発生するクリッピングについての情報を表示します。これはlittleCMSという外部ライブラリに基づいており、クリッピング警告モジュールの _色域全体(full gamut)_ モードとおおむね等価です。色域チェックモジュールの欠点は、輝度クリッピングなのか色域クリッピングなのか区別できないということと、クリッピング警告モジュールよりだいぶ遅いということです。

# モジュールの操作

クリッピングアイコンを右クリックすると、以下の操作が可能です。

クリッピング表示モード(clipping preview mode)
: どのタイプのクリッピングについて強調表示するか選んでください。

: - _RGBチャンネル(any RGB channel)_: [R,G,B] チャンネルのいずれかがヒストグラム色空間で許される最大値を越えている場合にオーバークリッピング警告を表示し、 [R,G,B] チャンネルすべてが暗すぎて黒に表示される場合にアンダークリッピング警告を表示します。これはバージョン3.4より前のdarktableのデフォルトのモードです。
: - _輝度のみ(luminance only)_: 「上のしきい値(upper threshold)」と「下のしきい値(lower threshold)」のスライダーで輝度範囲を設定し、その範囲からはずれた輝度のピクセルを表示します。これが発生する場合、たいていはトーンマッピングか露光補正に問題があります。
: - _彩度のみ(saturation only)_: 色の彩度が高すぎて、[R,G,B] チャンネルのいずれか（あるいは複数）の値がヒストグラム色空間で許される範囲をはずれてしまっている部分を、強調表示します。これはつまり、そのピクセルの色はヒストグラム色空間で表現できないということを意味しており、色域マッピングや彩度の設定に問題がある場合にこうなる可能性があります。
: - _色域全体(full gamut)_: 上の3つのすべてを表示します。これはバージョン3.4以降のdarktableでのデフォルトで、問題となりうるピクセルを完全に表示します。

表示色(color scheme)
: デフォルトでは、上のしきい値を越えたピクセル（オーバークリッピング）は _赤_ で、下のしきい値を越えたピクセル（アンダークリッピング）を _青_ で、それぞれ表示します。この色の組み合わせは、オーバーとアンダーの表示を _黒と白(black & white)_ や _紫と緑(purple & green)_ に変えることができます。画像によっては変えたほうが見やすくなるでしょう。

下のしきい値(lower threshold)
: 白の点（通常 EV = 0）からの相対EVで表されます。 [R,G,B] のチャンネルがすべてこの値より低い場合、アンダークリッピング表示が現れ、該当するピクセルが最終的には黒になってしまうことを警告します。このしきい値を設定するには、出力する予定の媒体に応じて以下の値を参照してください。

: - _8-bit sRGB_ --12.69 EV で黒のクリッピングが起きます
: - _8-bit Adobe RGB_ --19.79 EV で黒のクリッピングが起きます
: - _16-bit sRGB_ --20.69 EV で黒のクリッピングが起きます
: - _芸術用マットプリント_ 通常 --5.30 EV で黒になります
: - _カラー光沢プリント_ 通常 --8.00 EV で黒になります
: - _白黒光沢プリント-_ 通常 --9.00 EV で黒になります

上のしきい値(upper threshold)
: クリッピング警告が表示されるのはピクセルが上限にどこまで近い場合か、という基準をパーセントで表します（デフォルトは98%です）。色域チェックの場合、これはピクセルの彩度がどの程度色空間の色域限界に近づいたらクリッピング警告が表示されるか、を決めることになります。