---
title: collections
id: collections
applicable-version: 3.8
tags: 
view: lighttable, tethering, map
---

ライトテーブルとフィルムストリップに表示される画像を、画像の属性によってフィルタリングします。フィルタリングされた後の画像の集合を _コレクション(collection)_ と呼びます。

darktableに画像をインポートすると、その画像の属性情報（ファイル名、パス名、EXIF、XMPサイドカーファイルからの情報、など）もdarktableのデータベースに記録されます。コレクションは、この属性情報によって画像をフィルタリングすることで定義されるので、つまりライトテーブルやフィルムストリップに表示される画像の絞りこみをすることで定義する、と言うこともできます。

デフォルトのコレクションは _フィルムロール(film roll)_ 属性によって定義され、最後にインポートあるいは選択されたフィルムロールの画像すべてが表示されます。

# フィルタリングに利用可能な属性

コレクション内の画像は、以下の属性によってフィルタリングできます。

## ファイル情報

フィルムロール(film roll)
: 画像が属するフィルムロールの名前（画像が存在するフォルダの名前と同じ）。Ctrl+Shiftを押しながらフィルムロールをクリック（訳注：特に設定してなければダブルクリック）すると、対応するフォルダに切り替えます。右クリックで、darktableのライブラリからそのフィルムロールに含まれる画像を削除する、あるいはdarktableに対してそのコレクションのフォルダの場所が変わったということを伝えます。

フォルダ(folders)
: 画像ファイルが存在するフォルダの名前。クリックすると（訳注：特に設定してなければダブルクリック）、そのフォルダとすべての子フォルダ以下の中身をコレクションに取りこみます。Shift+クリックでは、選択したフォルダの中の画像だけを取りこみます（子フォルダ以下は入れない）。Ctrl+クリックでは、その子フォルダ以下にある画像のみを表示します。Ctrl+Shift+クリックでは、対応するフィルムロールに切り替えます。フォルダ名を右クリックで、darktableのライブラリからそのフォルダに含まれる画像を削除する、あるいはdarktableに対してそのコレクションのフォルダの場所が変わったということを伝えます。

ファイル名(filename)
: 画像のファイル名。

## メタデータ

タグ(tag)
: 画像につけられているタグ。タグのついていない画像は、「タグなし」(not tagged)のところに分類されます。この属性が選択されている状態では、現在存在するタグが階層的に表示されます。

表題(title)
: 画像のメタデータの「表題」(title)フィールド。

説明(description)
: 画像のメタデータの「説明」(description)フィールド。

作成者(creator)
: 画像のメタデータの「作成者」(creator)フィールド。

公開者(publisher)
: 画像のメタデータの「公開者」(publisher)フィールド。

権利(rights)
: 画像のメタデータの「権利」(rights)フィールド。

注記(notes)
: 画像のメタデータの「注記」フィールド。

バージョン名(version name)
: 画像のメタデータの「バージョン名」フィールド。

評価(rating)
: 画像の評価（ついている星の数）。

色ラベル(color label)
: 画像につけられている色ラベル（赤、黄、緑、青、紫）。

ジオタグ(geotagging)
: 画像につけられている位置情報（ [位置情報(locations)](../map/locations.md) の節を参照）。

## 時刻

撮影日(date taken)
: 撮影された日付。 `YYYY:MM:DD` の形式。

撮影日時(date-time taken)
: 撮影された日時。 `YYYY:MM:DD hh:mm:ss` の形式。

インポート時刻(import timestamp)
: ファイルがインポートされた日時。 `YYYY:MM:DD hh:mm:ss` の形式。

変更時刻(change timestamp)
: ファイルが最後に変更された日時。 `YYYY:MM:DD hh:mm:ss` の形式。

エクスポート時刻(export timestamp)
: ファイルが最後にエクスポートされた日時。 `YYYY:MM:DD hh:mm:ss` の形式。

印刷時刻(print timestamp)
: ファイルが最後に印刷された日時。 `YYYY:MM:DD hh:mm:ss` の形式。

## 撮影情報

カメラ(camera)
: EXIFデータに記述されたカメラのメーカー名と機種名。

レンズ(lens)
: EXIFデータに記述されたレンズ情報。

絞り(aperture)
: EXIFデータに記述された絞り（F値）。

露出(exposure)
: EXIFデータに記述されたシャッタースピード。

焦点距離(focal length)
: EXIFデータに記述された焦点距離。

ISO
: EXIFデータに記述されたISO値。

アスペクト比(aspect ratio)
: 画像のアスペクト比（横÷縦）。darktableで切り抜きした結果も含みます。

## darktable関連情報

グループ化(grouping)
: 「グループリーダー」(group leaders)か「グループ配下」(group followers)のいずれか。

ローカルコピー(local copy)
: そのファイルのローカルコピーがあるかどうか。

履歴(history)
: 編集履歴が変更されているかどうか（「変更ずみ」(altered)、「自動適用ずみ」(auto applied)、「無変更」(basic)のいずれか）。

モジュール(module)
: 各編集モジュールが使われているかどうかに応じてフィルタリングします。

モジュール順序(module order)
: 画像のモジュール順序の設定。「v3.0」、「旧版」(legacy)、「カスタム」(custom)のいずれか。

# モジュールの操作

## フィルタリング条件の設定

このモジュールの一番上の部分で、コレクションに入る画像をフィルタリングする条件を設定します。

使用する属性
: 左側のコンボボックスで、どの [属性(attribule)](#filtering-attributes) を使ってフィルタリングするかを選択します。

検索パターン
: 属性コンボボックスの右にある入力欄に、検索するためのパターンを入力できます。ここで入力したパターンが、darktableのデータベースに存在するすべての画像に関して、選択した属性の値と比較されます。そしてフィルタリング機構によって入力パターンを含む属性値を持つ画像が抽出されます。なお、入力パターン中では `%` をワイルドカードとして使うことが可能です。入力すると、コレクション内容が、検索パターンとマッチした画像だけに限定されます。入力欄を空にすると、選択した属性を持つすべての画像が表示されます。マウスカーソルを属性や検索パターンに重ねると、追加情報がある場合はポップアップ表示されます。

: 数値や日付・時刻の値を持つような属性の場合、比較・範囲演算子と組み合わせて使うこともできます。 `<` , `<=` , `>` , `>=` , `<>` , `=` を使うと、それぞれ入力された値「未満」「以下」「より大きい」「以上」「等しくない」「等しい」という画像をそれぞれ抽出できます。また `[from;to]` という形式の表現を使うと、特定の範囲に入る値を持つような画像となります。

値の一覧から選択
: 検索パターンを使ってフィルタリング条件を設定する方法に加え、現在のフィルタリング結果の画像が持っている値を一覧表示したものから直接選ぶこともできます。このように選択した場合、検索パターンの欄は自動的に入力されます。

: _検索パターン_ の下には、現在選択されている属性の値として、フィルタリング結果の画像中でありうるものの一覧が表示されます。この一覧は、検索入力欄になにか入力するたびに更新されます。この一覧をスクロールして、どれかをダブルクリックすることで選択することもできます。

: シングルクリックモードを有効にしている場合（ [設定(preferences) > ライトテーブル(lighttable)](../../../preferences-settings/lighttable.md) を参照）、一覧をダブルクリックではなくシングルクリックで選択できます。このモードではまた、値の範囲をマウスで選択することもできます。この機能は数値か日付時刻の値を持つ属性のときだけ利用可能です。

## 複数のフィルタリング条件を組み合わせる

一連の「ルール」を使うことで複数のフィルタリングを組み合わせ、複雑なコレクションを構成することができます。ルールとは、フィルタリング条件に論理演算子をつなげて、それまでの条件（あれば）とどのように組み合わせられるのかも決めたものです。

検索パターン入力欄の右にある ![collect-expander-icon](./collections/collect-expander.png#icon) ボタンをクリックし、メニューを開いてください。メニューには以下の選択肢があります。

このルールを消す(clear this rule)
: 現在のルールを削除します。現在のルールしかなければ、デフォルトの状態に戻ります。

絞り込む(narrow down search)
: 新しいルールを追加し、それまでのルールと論理ANDで組み合わせます。（それまでの条件に加えて）新しい条件も満たすような画像だけがコレクションに残ります。

画像を追加
: 新しいルールを追加し、それまでのルールと論理ORで組み合わせます。（それまでの条件にかかわらず）新しい条件を満たす画像もコレクションに追加されます。

画像を除外
: 新しいルールを追加し、それまでのルールと論理EXCEPTで組み合わせます。新しい条件を満たす画像はコレクションから除外されます。

ルールの組み合わせ方を示す論理演算子は、追加されたルールの右に表示されるアイコンで示されます。ANDは ![collect-and-icon](./collections/collect-and.png#icon) アイコン、ORは ![collect-or-icon](./collections/collect-or.png#icon) アイコン、EXCEPTは ![collect-except-icon](./collections/collect-except.png#icon) アイコンです。このアイコンをクリックすると、そのルールに関する論理演算子を変更することができます。

## 移動した画像ファイルのフォルダ情報を更新

インポートされたファイルは、なるべくdarktableと別のところでは触らないほうがよいです。ですが、このモジュールは、インポートしたあとに画像の入ったフォルダを移動したりリネームしたりした場合に対応する助けにもなります。コレクションモジュールは、新しいフォルダ名でdarktableのデータベースを更新する機能があります。以下のように操作してください。

1. _使用する属性(image attribute)_ コンボボックスを「フォルダ」(folders)か「フィルムロール」(film roll)にします。
1. 元のフォルダか、フィルムロールの名前を探します。そのフォルダ名は ~~打ち消し線表示~~ になっていて、フォルダが存在していないことを示しているはずです。
1. フォルダ・フィルムロール名の上で右クリックし、「フィルムロールを検索」(search filmroll...)か「フォルダを検索」(search folder...)を選び、新しいフォルダの場所を選択します。

## 設定

オプションメニュー（モジュール名右の三本線アイコン）の「設定」(preferences...)で、コレクションモジュールの動作を以下のように調整できます。

タグを「未分類」に入れない(do not set the 'uncategorized' entry for tags)
: 子タグがないタグ（訳注：「何の子タグでもない」の間違いですかね？）を、自動的に「未分類」(uncategorized)としないようにします（デフォルト：オフ）。

タグの大文字小文字を区別する(tag case sensitivity)
: タグの大文字小文字を区別するかどうか設定します。 `sqlite` ICU拡張を使っていない場合、これはふつうのアルファベット26文字だけに適用されます（デフォルト：区別しない(insensitive)）。

一覧表示するフォルダ階層の深さ(number of folder levels to show in lists)
: フィルムロールの名前に表示されるフォルダ階層の深さを、右から数えた数で設定します（デフォルト：1）。

フィルムロール整列順(sort film rolls by)
: フィルムロールを「フォルダ名順」(folder)にするか「id順」（フィルムロールが最初にインポートされた日付順とおおむね同じです）にするかを設定します（デフォルト：id）。

降順に整列(sort collections descending)
: 「フィルムロール」（フォルダ名順のとき）、「フォルダ」、日時（撮影日時など）のコレクションを表示するとき、降順で表示します（デフォルト：オン）。