---
title: tagging
id: tagging
applicable-version: 3.8
tags:
view: lighttable, [darkroom], tethering, map
---

画像につけるタグを管理します。

タグを使うことで、画像にキーワードで情報を付加することができるようになります。タグは階層的なツリー構造として管理することもでき、これはタグが大量になってきた場合に便利です。

タグ情報は実際には [XMPサイドカーファイル](../../../overview/sidecar-files/_index.md) とdarktableのデータベースに保存されており、 [エクスポート](../export.md) する画像に埋めこむこともできます。

# 用語の定義

"`places|France|Nord|Lille`" という単一のタグを作る場面を考えます。

タグ(tag)
: 「タグ」とは、画像につけられる説明用の文字列のことです。タグは単一の語の場合も、パイプ記号で区切られた一連の語でパスを構成する場合もあります。例えば、 "`places|France|Nord|Lille`" は単一のタグであり、これのパスを構成するそれぞれの語は直前の語の一部分となっています。またひとつの画像には、いくつでもタグをつけることができます。

: タグには、属性（名前、非公開、分類、別名、順序など）をつけることができます。

ノード(node)
: タグの一部を構成するパスはすべて「ノード」となります。上の例では、 "`places`" 、 "`places|France`" 、 "`places|France|Nord`" 、 "`places|France|Nord|Lille`" はすべてノードです。階層的ツリー表示では、ノードはツリーの枝と葉を構成します。

フリーノード(free node)
: 明示的にタグとして定義されていないノードは、「フリーノード」と呼びます。上の例では、 "`places`" 、 "`places|France`" 、 "`places|France|Nord`" はすべてフリーノードです。フリーノードには、「名前」以外どんな属性もつけることができませんし、フリーノードを画像につけることもできません。詳しくは、以下の「複数のタグ」の節を参照してください。

分類(category)
: タグは、「分類」であるとユーザーが設定することができます。

# 複数のタグ

上の例は、単一のタグとその属性という単純なものでした。次のように、パイプの入ったタグを4つそれぞれdarktableで定義した場合を考えてください。

```
places|France|Nord|Lille
places|France|Nord
places|France
places|England|London
```

この場合、ノードとしては以下のものが存在することになります。

```
places
places|France
places|France|Nord
places|France|Nord|Lille
places|England
places|England|London
```

フリーノードは、 "`places`" と "`places|England`" です。この二つは、両方とも（暗黙的に）「分類」でもあります。

これらのタグは全て、好きな画像につけることができます。画像につけられたタグは、「分類」タグを除き、画像を [エクスポート](./export.md) するときにも入れることができます。

もし "`places|France|Nord|Lille`" タグを画像につけたとすると、 "`places|France|Nord`" タグと "`places|France`" タグも暗黙的にその画像についていることになります（明示的につける必要はありません）。ただし、これはこの二つもそれぞれタグとして定義されているからだ、という点に注意してください。 "`places`" ノードは、タグではなくフリーノードですので、暗黙的についたりはしません。

# モジュールの構造

![tagging-overview](./tagging/tagging-overview.png#w33)

タグ付けモジュールは2つの部分から構成されています。

1. 上部の _付加されているタグ(attached tags)_ 部分（下に _タグをつける/はずす(attach/detach)_ ボタンがあります）

2. 下部の _タグ一覧(tag dictionary)_ 部分（下に _新規/インポート/エクスポート(new/import.../export...)_ ボタンがあります）

## 付加されているタグ(attached tags)

_付加されているタグ(attached tags)_ 部分は、以下の画像に現在ついているタグが表示されます。

- マウスカーソル位置の画像（ライトテーブルで、マウスカーソルが画像の上にある場合）

- 現在選択中の画像（マウスカーソルが画像の上にない場合）

_付加されているタグ_ 部分の一番下には、左から順に以下のようなボタンがあります。

タグをつける(attach)
: _タグ一覧(tag dictionary)_ 部分でなにかタグが選択されていれば、そのタグを選択中の画像につけます。

タグをはずす(detach)
: _付加されているタグ_ の一覧でなにかタグが選択されていれば、選択中の画像からそのタグがはずされます。タグ名の上で右クリックし、ポップアップメニューから _タグをはずす(detach)_ を選んでもはずすことができます。

![check-icon](./tagging/check-icon.png#icon) 隠しタグ
: darktableが自動的につける隠しタグも含めて表示するかどうか、選択します。

![sort-icon](./tagging/sort-icon.png#icon) ソート
: _付加されているタグ_ 一覧を、アルファベット順に並べるかカッコの中の数が多い順に並べるか選択します（後者の数は、選択中の画像の中でそのタグをつけているものの数）。

![minus-icon](./tagging/minus-icon.png#icon) 親階層
: タグの分類名の部分（ "|" 記号より左側の部分）を表示するかどうか選択します。

Ctrlキーを押しながらマウスホイールを回すと、 _付加されているタグ_ 部分の高さを調整することができます。

## タグ一覧(tag dictionary)

_タグ一覧(tag dictionary)_ 部分には、現在darktableのデータベースに存在しているタグがすべて表示されます。一番上には、タグ名を入力する入力欄があり、その下がタグの一覧になっています。一覧のタグ名の左には、タグの状態を示すマークがついています。意味は以下のとおりです。

- チェックマーク [✓] は、そのタグが選択中の画像すべてにつけられていることを示します。

- マイナス記号 [--] は、そのタグが選択中の画像の少なくともひとつにつけられていることを示します。この記号が階層的 _ツリー_ 表示状態でノードの名前についていた場合、そのノード以下のタグのいずれかが、選択中の画像の少なくともひとつにつけられていることを示します。

- 何のマークもついていなければ、そのタグが選択中の画像のどれにもつけられていないこと、あるいはそのノード以下のタグはすべて選択中の画像のどれにもつけられていないこと、を示します。

階層的 _ツリー_ 表示では、斜体で表示されている名前は、それが分類かフリーノードであることを示しています。

_タグ一覧_ の一覧表示の下には、左から順に以下のようなボタンがあります。

新規(new)
: 一番上のテキスト入力欄に入力された名前で、新しいタグを追加します。

インポート(import...)
: Lightroomのキーワードファイルから、タグをインポートします。

エクスポート(export...)
: タグ情報をすべて、Lightroomのキーワードファイルにエクスポートします。

![plus-icon](./tagging/plus-icon.png#icon) サジェスト
: 選択中の画像に現在ついているキーワードをもとに、提案されるキーワードのリストを表示します。注意：この操作はデータベースの検索を行いますので、遅い場合があります。

![list-tree-icon](./tagging/list-tree-icon.png#icon) リスト／ツリー
: タグの表示を単純な _リスト_ 表示と階層的な _ツリー_ 表示とで切り替えられます。

Ctrlキーを押しながらマウスホイールを回すと、 _タグ一覧_ 部分の高さを調整することができます。

# 使い方

以下ではタグ関連の操作方法を説明します。

## テキスト入力

テキスト入力欄（ _タグをつける/はずす(attach/detach)_ ボタンの下）にはいくつかの使い道があります。

- _タグ一覧_ 表示が _リスト_ 表示モードの場合（ _ツリー_ 表示ではなく）、タグのはじめの何文字かを入力すると候補が表示されます。矢印キーで動かしてEnterキーを押すことで、候補のいずれかを選択できます。さらにもう一度Enterキーを押せば、選択中の画像にそのタグがつけられます。もちろん、二度目のEnterキーを押す前に選択されたタグ名を修正することも可能で、そうすると、もしその名前のタグが存在しなければ、二度目のEnterを押したときに新しく作られます。

- 自動補完的な候補表示以外にも、入力された文字列によって _タグ一覧_ に表示されるタグがフィルタリングされ、文字列と一致する部分がある（か別名が一致するかの）タグだけが表示されるようになります。Enterキーを押すと、選択中の画像に入力された名前のタグがつけられます。もしその名前のタグが存在しなければ、つける前に自動的に作成されます。

- ポップアップメニューの「入力欄にコピー」(copy to entry)を使うと、選択したタグを入力欄にコピーすることができます。そこから修正してEnterを押せば修正した名前のタグが作成されますので、似たような名前のタグを複数作るときなどに手間がはぶけます。

---

**注意：** もし入力を自動補完する動作がうっとおしければ、 [設定(preferences) > その他(miscellaneous) > タグ(tags) > 入力自動補完をしない(disable the entry completion)](../../../preferences-settings/miscellaneous.md#tags) で無効にすることもできます。

---

## タグの作成

新しくタグを作る方法はいくつかあります。

- _テキストファイルをインポート_： Lightroomのタグファイル形式のテキストファイルをインポートすることができます。また、タグをテキストファイルにエクスポートし、そのテキストファイルを修正して、もう一度インポートしなおすこともできます。インポート機能によって、必要に応じて自動的に既存のタグの修正や新しいタグの作成が行われます。テキストファイルでタグの名前を書きかえた場合、それは新しいタグとして扱われます。

- _タグのつけられた画像をインポート_： この方法では、インポートにあたって自動的にタグや分類の名前を変えたりするようなことはありません。

- _メニューの「新規タグ」(create tag)を使う_： （階層表示における）既存の分類の下や、一番上のレベルに手動でタグを作ります。

- _メニューの「タグとして設定」(set as a tag)を使う_： フリーノード（例えば ”`places|England`” など）をタグとして設定し、その子タグ（例えば ”`places|England|London`” など）のつけられた画像すべてに暗黙的につけることができます。

- _名前を入力して「新規」(new)ボタンを押す_： 階層的なタグはパイプ記号 "`|`" を使ってノードを区切ることで作成できます。なお、この方法で作成したタグは、自動的に選択中の画像につけられます。

特定の操作をしたとき、darktableによっていくつかタグが自動的に生成されます。例えば、 “`darktable|exported`” と “`darktable|styles|your_style`” は、それぞれ「エクスポートされた画像」と「スタイルが適用された画像」を示すのに使われます。

## タグの編集、名前の変更

_タグ一覧_ で右クリックすると表示されるポップアップメニューで、「編集」(edit ...)や「パス名を変更」(change path...)を選ぶと、タグの操作ができます。

「編集」操作では、タグの名前を変えることはできますが、そのタグがどのノードに属するかを変えることはできません（ここではタグの名前にパイプ記号 "|" は使えません）。すでに存在するタグ名に変更しようとすると、この操作は中止されます。また、 _プライベート(private)_ や _分類(category)_ のフラグをつけることや、タグに _別名(synonyms)_ をつけることもできます（下記参照）。こうした属性はそれぞれ、メタデータ項目の `XMP-dc Subject` と `XMP-lr Hierarchical Subject` に保存されます。エクスポートの際どのタグが埋めこまれるかを設定したければ、 [エクスポート(export)](./export.md) モジュールの設定を変えると可能です。

- 「プライベート(private)」に設定されたタグは、デフォルトではエクスポートされません。

- 「分類(category)」に設定された名前は、 `XMP-dc Subject` にはエクスポートされません。ただし、これはタグがどのように整理されているかを示している情報になるので、 `XMP-lr Hierarchical Subject` にはエクスポートされます。

- 「別名(synonyms)」はタグの情報量を増やすもので、主に検索を便利にするために使われます。例えば "juvenile" "kid" "youth" といったタグを "child" の別名とすることが考えられます。また、別名はタグ名を別の言語に翻訳するためにも使うことができます。

「パス名を変更」操作は、 _ツリー_ 表示のときだけ使うことができます。また、ノードの名前を変更したときに影響を受ける画像の数も表示されます。変更画面ではノードの全ての部分を、どのノードに属するかも含めて変更できます（分類はパイプ記号 "`|`" を使って表します）。この操作は強力ですが、画像のメタデータ構造に大きな影響を与えるので、注意して使ってください。もし実行しようとした操作が現在のタグ構造と矛盾する場合、操作は中止されます。

タグの構造を操作する簡単な方法は、ドラッグ&ドロップすることです。 _ツリー_ 表示モードでは、ノードをドラッグして好きなノードの上にドロップできます。動かしたノードとその子ツリー（あれば）は、重ねた先のノードの子の位置になります。ドラッグすると、重ねた先のノードの子ツリーが自動的に開いて表示されます。ノードを一番上の階層に動かしたければ、一番上まで動かしてドロップしてください。もし実行しようとした操作が現在のタグ構造と矛盾する場合、操作は中止されます。

## タグをつける

選択されている画像にタグを付ける方法には、以下のようなものがあります。

- _タグ一覧(tag dictionary)_ でタグをクリックして、それから _タグをつける(attach)_ ボタンを押します。
- _タグ一覧_ でタグを右クリックして、表示されたポップアップメニューで「タグをつける(attach tag)」を選びます。
- _タグ一覧_ でタグをダブルクリックします。
- _付加されているタグ_ に表示されているタグを右クリックするとポップアップメニューが表示されます。選択中の画像でそのタグがついていないものがあれば、「すべてにタグをつける(attach tag to all)」を選ぶと選択中画像すべてにそのタグがつけられます。
- 入力欄にタグ名を入力し、「新規(new)」ボタンかEnterキーを押します。こうすると、それまでに存在していなければ新しいタグとして作成され、さらに選択中の画像にそのタグがつけられます。
- Ctrlキーを押しながらTキーを押すと、ライトテーブルの中央下部に小さい入力欄が出現します。ここにタグ名を入れてEnterキーを押してください。それまでに存在していなければ新しいタグとして作成され、さらに選択中の画像にそのタグがつけられます。
- 画像をドラッグして、目的のタグの上にドロップします。複数の画像でも可能です。

ライトテーブルでマウスカーソルを画像の上に重ねると、どのタグがその画像につけられているか確認できます。 _タグ付け(tagging)_ モジュールの _付加されているタグ_ 部分か、 [画像情報(image information)](./image-information.md) モジュールの _タグ(tags)_ 属性を見てください。

## タグをはずす

選択されている画像からタグをはずす方法はいくつかあります。

- _タグ付け(tagging)_ モジュールの _付加されているタグ_ 部分でタグをクリックして選択し、 _タグをはずす(detach)_ ボタンを押します。
- _付加されているタグ_ 部分のタグをダブルクリックします。
- _付加されているタグ_ 部分のタグを右クリックしてポップアップメニューを表示させ、「タグをはずす(detach)」を選びます。

## タグの削除

タグをすべての画像から（選択されているかどうかにかかわらず）はずして、データベースから完全にタグを削除する、ということも可能です。この操作は大量の画像に影響を与えかねないので、削除しようとしているタグが現在いくつの画像につけられているかを示す警告が表示されます。この操作をアンドゥする方法はありません（バックアップからXMPサイドカーファイルやデータベースを復旧する以外には）ので、警告画面はよく確認してください。以下のような方法で、 _タグ一覧_ にあるタグを削除することができます。

- _タグ一覧_ 部分のタグを右クリックしてポップアップメニューを表示させ、「タグを削除(delete tag)」を選びます。
- _タグ一覧_ 部分の枝ノードを右クリックしてポップアップメニューを表示させ、「ノードを削除(delete node)」を選ぶと、選択されたノードを、子ノードすべてを含めて削除します。

## インポート / エクスポート

「インポート(import)」ボタンを押すと、テキストファイル（Lightroomタグテキストファイル形式であること）を選択して、内容をインポートできます。インポートしたファイルに書かれているタグで、すでに存在しているものがあれば、その情報は更新されます。そうでなければ、新しいタグが作られます。

「エクスポート(export)」ボタンを押すと、現在のタグ情報すべてが指定したテキストファイルにエクスポートされます（Lightroomタグテキストファイル形式です）。

## 操作

_タグ一覧_ 部分に表示されているタグについて、そのタグがつけられている画像を確認するには、タグ名を右クリックして表示されるポップアップメニューで「タグコレクション(go to tag collection)」を選んでください。この操作で、自動的に [コレクション(collection)](./collection.md) モジュールでそのタグを含む画像のコレクションが開きます。 _コレクション_ モジュールで別のタグをダブルクリックすれば、別のタグのコレクションになります。

タグコレクションを開く前の、元のコレクションに戻るには、最初と同じところのポップアップメニューで「元のコレクションに戻る(go back to work)」を選んでください。別のコレクションを開いたりしていない限り、これて元のコレクションに戻れます。