---
title: "editing an image: scene-referred workflow"
id: edit-scene-referred
draft: false
weight: 30
author: "people"
---

_シーン参照(scene-referred)_ ワークフローでは、画像処理をなるべくピクセルパイプライン中の線形なシーン参照部分で実行することが重視されます。こうすることで、非線形なピクセル値を処理することで起きる可能性がある歪みや色ずれを減らすことができますし、画像処理を特定のディスプレイの性質に依存させずに行いますので、編集結果を今後登場するかもしれない出力媒体（高ダイナミックレンジなモニタとか）でも利用しやすくなります。

現在、darktableを使う上ではこのワークフローが推奨されます。そこでこの節では、次の _ディスプレイ参照(display-referred)_ ワークフローの節よりもくわしく説明をしています。

# 基本

シーン参照ワークフローで基本的な画像処理を行うにあたっては、ディスプレイ上にまともな出力を得るために、少なくとも以下のような点について考える必要があります。

1. 写真の撮影

   まずカメラで適切な露光の写真を撮影してください。通常はカメラの測光機能と自動露出設定機能を使うことができます。しかし、一部の撮影シーンでは、最適な露光を得るためにカメラの露出補正ダイアルや手動設定を使う必要があります。一般的には、ハイライト部でクリッピングが起きない範囲で、できるだけ明るくなるように露出を設定してください。これは「露出を右へ(exposing to the right, ETTR)」と呼ばれる方法で、センサーのダイナミックレンジを最大限生かすことができます。たいていのカメラには「ゼブラ」とか「点滅」のような、クリッピング時に警告を表示する機能がついています。

2. [_露光(exposure)_](../../module-reference/processing-modules/exposure.md) モジュールを使って中間トーンを調整

   _露光_ モジュールのスライダーを動かして、画像の中間トーンの部分が適切な明るさになるように調整してください。この段階では、ハイライトや暗部については気にしなくて大丈夫です。あとでちゃんと対応します。

   __露光 モジュールはデフォルトでオンになっていて、さらに通常のカメラ内JPEG生成処理と同様にするため最初から +0.5EV の露出補正がなされています。カメラの測光機能にはいろいろあり、もう少し大きな露出補正（+0.8EV〜+1.5EV程度）が必要になるカメラもあります。そのような場合、必要に応じて [プリセット(preset)](../../darkroom/processing-modules/presets.md) を作成し、自動適用されるようにすることもできます。露光モジュールでは、カメラの露出補正機能が使われたかどうか検出し（上記のETTR関連など）、それに応じて露出が再調整されます。

   _露光_ モジュールで黒レベルを調整してコントラストを上げる、ということも _可能_ ではありますが、その場合は十分注意して設定する必要があります。負のRGB値が出てきてしまったりする場合があり、そうなると _フィルミックRGB(filmic rgb)_ モジュールの動作がおかしくなります。

3. [_ホワイトバランス(white balance)_](../../module-reference/processing-modules/white-balance.md) を調整

   ホワイトバランスを正しく設定するということは、続く処理のための確実な基礎を作るために重要です。カメラは通常、rawファイルに埋めこまれたメタデータにホワイトバランス情報を保存しますので、darktableはこの情報をもとに設定を始めます。より正確なホワイトバランスを得るためには、カラーピッカーで画像内の中間グレーの部分を選択する、あるいは可能ならお使いのカメラの別のホワイトバランス設定に切りかえる、といったことができます。全体のホワイトバランスの微調整には、 _色温度(temperature)_ スライダーや、 _色合い(tint)_ スライダー（こちらを使うことのほうがまれです）が使えます。 _色温度_ スライダーを左に動かすと画像がより寒色寄りに（青っぽく）なり、右に動かすとより暖色寄りに（オレンジに）なります。

   _ホワイトバランス_ モジュールでは、画像のホワイトバランスの _全体の_ 設定だけができます。 [_カラーバランス(color balance)_](../../module-reference/processing-modules/color-balance.md) モジュールなどを使うと、撮影シーンに別々の色温度の光源が複数あるような場合でも、さらに複雑な調整が可能です。

   _注意： さらに高度なホワイトバランス設定のために、 [_カラー較正(color calibration)_](../../module-reference/processing-modules/color-calibration.md) モジュールが使えるようになりました。_

4. [_フィルミックRGB(filmic rgb)_](../../module-reference/processing-modules/filmic-rgb.md) モジュールを使って白と黒の点を調整

   このモジュールは、撮影された画像の高いダイナミックレンジから、出力媒体の低いダイナミックレンジに対してトーンマッピング圧縮を行います。中間グレーのレベルは _露光_ モジュールですでに設定されています（上記参照）。フィルミックでは、 _シーン(scene)_ タブで、画像内の適切な白と黒のレベルを設定します。これは個別の撮影シーンに応じて調整する必要があるかもしれません。 _ルック(look)_ タブでは、必要に応じて中間トーンのコントラストや彩度が設定できます。

# その他のおすすめモジュール

ここまでに説明した基本的なモジュールに加えて、よりよい結果を得るために以下のモジュールを使うことを考えてもよいかもしれません。ここで説明しているモジュールは、シーン参照ワークフローでうまく働くことがわかっています。

[_クロップと回転(crop and rotate)_](../../module-reference/processing-modules/crop-rotate.md) / [_遠近法補正(perspective correction)_](../../module-reference/processing-modules/perspective-correction.md)
: わりと頻繁に、撮影シーンの一部分だけを画像として得たい場合、たとえばフレームのはしっこのほうの不要なものを消したいような場合があるでしょう。あるいは、画像の水平を合わせなおす必要があったり、遠近法的に歪んでいたりする場合もあると思います。このような問題はすべて _クロップと回転(crop and rotate)_ モジュールを使って手動で修正することができます。遠近法歪みを全自動で修正するには、かわりに _遠近法補正(perspective correction)_ モジュールを使うこともできます。

[_レタッチ(retouch)_](../../module-reference/processing-modules/retouch.md) / [_ホットピクセル(hot pixels)_](../../module-reference/processing-modules/hot-pixels.md)
: センサーについた汚れなどが原因の点を除去する必要があるとか、不要なものを周囲の内容で消したいとかいう場合もあると思います。 _レタッチ(retouch)_ モジュールは、このような修正や、あるいは肌のしみ等の消したい部分を修正するのに使えます。また、もしカメラに不良ピクセルがあったり、高ISOや長時間露光などでホットピクセルを生じる傾向があったりする場合、 _ホットピクセル(hot pixels)_ モジュールを使うと自動で修正できるかもしれません。

[_カラーバランスRGB(color balance rgb)_](../../module-reference/processing-modules/color-balance.md)
: これはいろいろな用途に使えるモジュールで、画像のコントラストや彩度をさらに調整したり、カラーグレーディング（ハリウッド映画のような「オレンジ＆ティール」にしたり、肌の赤みをとったり、暗部・中間トーン・ハイライトの色バランスをととのえたり、など）を行ったりできます。 _カラーバランスRGB_ モジュールで期待する効果が得られないような場合は、 [_カラーゾーン(color zones)_](../../module-reference/processing-modules/color-zones.md) モジュールも有効かもしれません。

[_トーン イコライザー(tone equalizer)_](../../module-reference/processing-modules/tone-equalizer.md)
: 「覆い焼き」や「焼き込み」を行って暗部やハイライト部のディテールを回復させるには、このモジュールを使ってください。このモジュールでは、画像の各部分で輝度を平均化するマスクが作られ、このマスクを使ってイコライザーで個別に輝度レベルを上げ下げすることができます。まず最初に、マスクが適切に作られているかを確認するのがお勧めです。それからスライダーやスプライン曲線を調整して、それぞれの輝度レベルを設定してください。また、画像の上にマウスカーソルを乗せると、カーソル位置でのマスクのEVレベルが確認でき、さらにマウスホイールを操作すると、そのEVレベルの部分の明るさレベルを直接調整することができます。

[_ローカルコントラスト(local contrast)_](../../module-reference/processing-modules/local-contrast.md)
: このモジュールを使うと、細部を強調して明瞭さを上げますので、画像の全体的なシャープネスを上げるのによいです。このモジュールは、 _ローカルラプラシアン(local laplacian)_ モードで使うことをお勧めします。

: もっと複雑ですがいろいろなことができる方法としては、 [_コントラストイコライザー(contrast equalizer)_](../../module-reference/processing-modules/contrast-equalizer.md) モジュールがあります。これは距離や位置が問題になるようなことの調整には大変有効です。このモジュールにはいくつかプリセット設定が最初から用意されており、使い方を理解するための出発点としても有効かと思います。

[_ノイズ削減 （プロファイル）(denoise profiled)_](../../module-reference/processing-modules/denoise-profiled.md)
: _ノイズ削減 （プロファイル）_ モジュールは、通常、画像のノイズを減らす最良の方法です。このモジュールでは、ほとんど「1クリックするだけ」のノイズ削減方法が用意されています。ユーザーの立場から見ると、この方法のノイズ削減効果はカメラの種類とISO値にのみ依存しており、そのどちらもEXIFデータから得ることができます。ほかの細かい設定はすべて、darktable開発チームが集めたノイズプロファイルのデータベースに基づいて設定されます。現在、300以上のカメラ機種についてデータがあります。このモジュールを使う一番簡単な方法は、 _非局所平均 （自動）(non-local means auto)_ モードを使うことです。またウェーブレット(wavelet)機能も、色ノイズにはかなり有効です。このモジュールは、効果を正確に確認するため、100%の拡大率（等倍）の表示にして使うことをお勧めします。

: ノイズ削減に使えるその他のモジュールとしては、 [_RAW ノイズ削減(raw denoise)_](../../module-reference/processing-modules/raw-denoise.md) 、 [_表面ぼかし(surface blur)_](../../module-reference/processing-modules/surface-blur.md) 、 [_天体写真ノイズ削減(astrophoto denoise)_](../../module-reference/processing-modules/astrophoto-denoise.md) などがあり、またウェーブレットによるものとしては [_コントラストイコライザー(contrast equalizer)_](../../module-reference/processing-modules/contrast-equalizer.md) があります。もしお使いのカメラがまだ _ノイズ削減 （プロファイル）_ でサポートされていなければ、おそらく _天体写真ノイズ削減_ が、色と輝度のノイズを別々に扱えるので、代替として最も便利かと思われます。

[_かすみ除去(haze removal)_](../../module-reference/processing-modules/haze-removal.md)
: 名前のとおりのことをします。つまり、空気中のかすみの効果を消します。

[_カラー較正(color calibration)_](../../module-reference/processing-modules/color-calibration.md)
: このモジュールは、銀塩フィルムを模した白黒画像を生成するための各種プリセットをそなえています。また、カラープロファイル行列を調整することもできますので、たとえば色域の問題に対処するのに使ったりできます。

[_レンズ補正(lens correction)_](../../module-reference/processing-modules/lens-correction.md)
: もしお使いのカメラとレンズの組み合わせがサポートされていれば、このモジュールを使うとカメラ内で補正されなかったレンズ由来の歪みを補正することができます。 [_クロップと回転(crop and rotate)_](../../module-reference/processing-modules/crop-rotate.md) や [_遠近法補正(perspective correction)_](../../module-reference/processing-modules/perspective-correction.md) モジュールも、レンズによるチルト・シフト効果をまねるために（歪みなどを補正するために）使うことができます。

# 使うときに注意が必要なモジュール

いくつか、シーン参照ワークフローに適した代替手段がまだないようなモジュールが存在します。必要であれば、この種のモジュールを控えめに、注意しつつ使ってください。

[_自然な彩度(vibrance)_](../../module-reference/processing-modules/vibrance.md)
: このモジュールを使うと色が暗くなりがちです。もっとしっかり調整するため、 [_カラー ゾーン(color zones)_](../../module-reference/processing-modules/color-zones.md) を彩度のパラメトリックマスクで使うことを検討してください。

[_カラー ゾーン(color zones)_](../../module-reference/processing-modules/color-zones.md)
: 色の遷移がきれいにならないかもしれません。 [_カラー バランス(color balance)_](../../module-reference/processing-modules/color-balance.md) をパラメトリックマスクで使うと代替となる可能性があります。

[_周辺光量補正(vignetting)_](../../module-reference/processing-modules/vignetting.md)
: このモジュールを使うと、効果の変化が急激すぎることで、不自然な見た目になる場合があります。 [_露光(exposure)_](../../module-reference/processing-modules/exposure.md) モジュールを、楕円形で遷移領域の広いマスクで使ったほうがマシになるかもしれません。さらに [_カラーバランス(color balance)_](../../module-reference/processing-modules/color-balance.md) を同じマスクで使い、境界領域で彩度を減らすことも考えられます。

---

**注意：** どのモジュールでも、 [ブレンドモード(blend modes)](../../darkroom/masking-and-blending/blend-modes.md) を使う場合、多くのモードがディスプレイ参照空間に最適化されていて、中間グレーの値として50%を想定していることに注意してください。線形のシーン参照空間においては、基本的な算術演算操作（加算・乗算・除算・減算・平均(addition, multiplication, division, subtraction, average)）、最大・最小の比較（スクリーン(screen)）、チャンネル分離（色相、カラー、彩度(hue, color, chroma)など）のモードだけを使うようにしてください。

---

# その他の芸術的効果

darktableには、芸術的効果を得るためのモジュールもいろいろあります。いくつか例をあげると以下のようなものです。

- [_透かし(watermark)_](../../module-reference/processing-modules/watermark.md) モジュールでは、画像に透かしを入れることができます。
- [_粒子(grain)_](../../module-reference/processing-modules/grain.md) モジュールでは、銀塩写真のような粒状感をまねることができます。
- [_カラーマッピング(color mapping)_](../../module-reference/processing-modules/color-mapping.md) モジュールでは、ある画像の雰囲気（色調）を別の画像にうつすことができます。
- [_ローライト ヴィジョン(lowlight vision)_](../../module-reference/processing-modules/lowlight-vision.md) モジュールでは、人間の視覚をまねることで、光が少ない場合の画像をよりそれらしいものにできます。
- [_グラデーション フィルタ(graduated density)_](../../module-reference/processing-modules/graduated-density.md) では、露光や色補正などの効果をグラデーション状にかけるためのフィルターを設定できます。

利用できるモジュールの一覧は、 [編集モジュール一覧(processing module reference)](../../module-reference/processing-modules/_index.md) を参照してください。

# 使うべきでないモジュール

モジュールの中には、シーン参照型ワークフローではもはや使用を推奨されていないものがいくつもあります。これは「使えない」という意味ではありませんが、スライダーを動かしすぎるとおかしな出力になったりしますし、より適切なモジュールが用意されてもいます。以下では、それぞれに対する簡単な説明とあわせて、代替として使うべきモジュールも紹介します。

[_ローカル トーンマッピング(local tone mapping) （非推奨）_](../../module-reference/processing-modules/tone-mapping.md)
: _[トーン イコライザー(tone equalizer)](../../module-reference/processing-modules/tone-equalizer.md)_ を使ってください。

: このモジュールは非線形マッピング（対数）にバイラテラルぼかしフィルタをかけますが、ハローや偽色帯を生じる場合があります。これは、非線形エンコーディングに対してぼかしや遮蔽をかけるときに一般的に起きる問題です。

[_グローバル トーンマップ(global tonemap) （非推奨）_](../../module-reference/processing-modules/global-tonemap.md)
: _[フィルミックRGB(filmic rgb)](../../module-reference/processing-modules/filmic-rgb.md)_ を使ってください。

: このモジュールはHDR画像をLab色空間で扱いますが、Lab色空間は高いダイナミックレンジに向いていません。 _フィルミックRGB(filmic rgb)_ モジュールでは線形空間で処理され、撮影シーンの広いダイナミックレンジの入力値を変換して、ディスプレイや印刷機で必要な狭いダイナミックレンジに対応させることが簡単にできます。

[_シャドウとハイライト(shadows and highlights)_](../../module-reference/processing-modules/shadows-and-highlights.md)
: _[トーン イコライザー(tone equalizer)](../../module-reference/processing-modules/tone-equalizer.md)_ を使ってください。

: このモジュールはLab色空間でぼかしを使うので、ハロー、ハイライト部の高いローカルコントラスト、暗部の青への色ずれなどの問題を生じます。

[_ローパス(lowpass)_](../../module-reference/processing-modules/lowpass.md)
: _[コントラスト イコライザー(contrast equalizer)](../../module-reference/processing-modules/contrast-equalizer.md) か [トーン イコライザー(tone equalizer)](../../module-reference/processing-modules/tone-equalizer.md)_ を使ってください。

: このモジュールもLab空間でぼかしをかけます。ぼかすには _コントラスト イコライザー(contrast equalizer)_ を、ローカルなダイナミックレンジ圧縮が必要なら _トーン イコライザー(tone equalizer)_ を使ってください。

[_ハイパス(highpass)_](../../module-reference/processing-modules/highpass.md)
: _[コントラスト イコライザー(contrast equalizer)](../../module-reference/processing-modules/contrast-equalizer.md) か [ローカル コントラスト(local contrast)](../../module-reference/processing-modules/tone-equalizer.md)_ を使ってください。

: Lab空間でぼかしを扱いますので、[_ローパス(lowpass)_](../../module-reference/processing-modules/lowpass.md) モジュールと同じ問題があります。細部のシャープネスには _コントラスト イコライザー(contrast equalizer)_ を、全体的なシャープネスには _ローカル コントラスト(local contrast)_ を使ってください。

[_シャープ化(sharpen)_](../../module-reference/processing-modules/sharpen.md)
: _[コントラスト イコライザー(contrast equalizer)](../../module-reference/processing-modules/contrast-equalizer.md) か [ローカル コントラスト(local contrast)](../../module-reference/processing-modules/tone-equalizer.md)_ を使ってください。

: _シャープ化_ モジュールで使っているアンシャープマスクアルゴリズムは、 _ハイパス(highpass)_ モジュールと同様の問題があり、歪みが生じやすくなります。ぼけを修正するなら _コントラスト イコライザー(contrast equalizer)_ のプリセットを、全体的なシャープネスには _ローカル コントラスト(local contrast)_ を使ってください。

[_モノクローム(monochrome)_](../../module-reference/processing-modules/monochrome.md)
: _[カラー較正(color calibration)](../../module-reference/processing-modules/color-calibration.md) （あるいは [カラーバランス(color balance)](../../module-reference/processing-modules/color-balance.md) ）_ を使ってください。

: _モノクローム(monochrome)_ モジュールはそもそもわりと使いにくいです。 _カラー較正(color calibration)_ のプリセットならフィルムで実際に起きることに近い処理になっていますし、あるいはより視覚に基づいた方法なら _カラーバランス(color balance)_ モジュールの _出力彩度(output saturation)_ スライダーを0%にする、ということもできます。

[_フィルライト(fill light) （非推奨）_](../../module-reference/processing-modules/fill-light.md)
: _[トーン イコライザー(tone equalizer)](../../module-reference/processing-modules/tone-equalizer.md) （あるいは [露光(exposure)](../../module-reference/processing-modules/exposure.md) ）_ を使ってください。

: 撮影シーンに光を追加するため、このモジュールもやはりLab空間でぼかしを使います。 _トーン イコライザー(tone equalizer)_ なら線形空間で処理しますし、あるいは _露光(exposure)_ モジュールを [描画マスク(drawn mask)](../../darkroom/masking-and-blending/masks/drawn.md) で使うことでも同様の効果が得られます。

[_ブルーム(bloom)_](../../module-reference/processing-modules/bloom.md)
: _[トーン イコライザー(tone equalizer)](../../module-reference/processing-modules/tone-equalizer.md) （あるいは [露光(exposure)](../../module-reference/processing-modules/exposure.md) ）_ を使ってください。

: このモジュールもやはりLab空間でぼかしを使います。 _トーン イコライザー(tone equalizer)_ か _露光(exposure)_ を [パラメトリックマスク(parametric mask)](../../darkroom/masking-and-blending/masks/parametric.md) で使ってください。どちらも線形空間で処理を行います。

[_ゾーンシステム(zone system) （非推奨）_](../../module-reference/processing-modules/zone-system.md)
: _[トーン イコライザー(tone equalizer)](../../module-reference/processing-modules/tone-equalizer.md) （あるいは [露光(exposure)](../../module-reference/processing-modules/exposure.md) ）_ を使ってください。

: このモジュールもLab空間で処理を行いますので、やりすぎると問題が起きます。 _トーン イコライザー(tone equalizer)_ を使うか、複数の _露光(exposure)_ モジュールのインスタンスを（各ゾーンに対応する）パラメトリックマスクで使ったほうがよいです。

[_カラー調整(color correction)_](../../module-reference/processing-modules/color-correction.md)
: _[カラーバランス(color balance)](../../module-reference/processing-modules/color-balance.md)_ を使ってください。

: _カラーバランス(color balance)_ モジュールのほうを使ってください。こちらはRGB色空間で動作しますし、ホワイトバランス調整についても、暗部は _オフセット(offset)_ 、中間トーンは _羃乗(power)_ 、ハイライトは _傾斜(slope)_ を使って簡単に設定できます。なお、線形色空間で通常使われる _オフセット_ 、 _羃乗_ 、 _傾斜_ は、それぞれ非線形ガンマエンコード色空間における _リフト(lift)_ 、 _ガンマ(gamma)_ 、 _ゲイン(gain)_ におおむね対応しています。

[_ベルビア(velvia)_](../../module-reference/processing-modules/velvia.md)
: _[カラーバランス(color balance)](../../module-reference/processing-modules/color-balance.md)_ を使ってください。

: _カラーバランス(color balance)_ モジュールの _出力彩度(output saturation)_ スライダーは、 _ベルビア(velvia)_ モジュールと同様の仕組みで動作しますし、めんどうな色合いと輝度のずれが起きないようになっています。

[_レベル(levels)_](../../module-reference/processing-modules/levels.md)/[RGB レベル(rgb levels)](../../module-reference/processing-modules/rgb-levels.md)
: _[カラーバランス(color balance)](../../module-reference/processing-modules/color-balance.md)_ を使ってください。

: この2つのモジュールは、基本的に _カラーバランス(color balance)_ モジュールの機能の一部分を実装しているにすぎず、冗長なものです。

[_トーンカーブ(tone curve)_](../../module-reference/processing-modules/tone-curve.md)/[RGB カーブ(rgb curve)](../../module-reference/processing-modules/rgb-curve.md)
: _[カラーバランス(color balance)](../../module-reference/processing-modules/color-balance.md)_ を使ってください。

: この2つのモジュールは、通常コントラストを調整するために使われます。中間グレーのレベルが50%前後であることを想定しているのですが、線形のシーン参照色空間では、中間グレーはもっと低く、18%前後になります。コントラストの調整は _カラーバランス(color balance)_ で行ったほうがよく、こちらであれば中間グレーの点を _コントラスト支点(contrast fulcrum)_ スライダーで設定することもできます。

[_コントラスト 明るさ 彩度(contrast brightness saturation)_](../../module-reference/processing-modules/contrast-brightness-saturation.md)
: _[カラーバランス(color balance)](../../module-reference/processing-modules/color-balance.md)_ を使ってください。

: このモジュールはLab色空間（とその制限下）で動作し、基本的に _カラーバランス(color balance)_ にある機能と重複しています。
